package PhyDynSys2 "Physik der dynamischen Systeme" 
  import SI = Modelica.SIunits;
  package Konnektoren "Enthaelt die Konnektoren fuer alle Teilgebiete" 
    annotation (Documentation(info="<html>
<h3>Kennektoren als Schnittstelle f&uuml;r Menge, Potential und Energie</h3>
<p>Die Konnektoren der f&uuml;nf Teilgebiete <font color=\"#FF0000\">Hydrodynamik, Elektrizit&auml;tslehre, Translationsmechanik, Rotationsmechanik und Thermodynamik</font> enthalten je eine Fluss- und eine Potentialgr&ouml;sse. Die Konnektoren werden paarweise angelegt, wobei der eine als positiv (<font color=\"#008800\">pos</font>), der andere als negative (<font color=\"#008800\">neg</font>) bezeichnet wird. Diese Bezeichnung dient der Wahl des Vorzeichens bei Stromgliedern.</p>
</html>"));
    connector Kupplung_pos "hydraulischer Anschluss" 
      SI.Pressure p "Absolutdruck in der Kupplung";
      flow SI.VolumeFlowRate IV "Volumenstromstaerke durch Kupplung";
      annotation (Icon(Ellipse(extent=[-100,100; 100,-100], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255}))), Documentation(info="<html>
<h3>Hydrodynamik: Volumen und Druck</h3>
<font color=\"#008800\">Kupplung_pos</font> sollte als Eingang eines Stromgliedes (<font color=\"#0000FF\">Widerstand</font> oder <font color=\"#0000FF\">Induktivit&auml;t</font>) sowie bei einem <font color=\"#0000FF\">Speicher</font> verwendet werden. Der <font color=\"#FF0000\">Absolutdruck</font>  <strong>p</strong> mit der Einheit Pascal (Pa) steht f&uuml;r die Potentialgr&ouml;sse. Die <font color=\"#FF0000\">Volumenstromst&auml;rke</font> <strong>IV</strong> mit der Einheit Kubikmeter pro Sekunde (m<sup>3</sup>/s) beschreibt den Transport der Grundmenge der Hydrodynamik (Stromgr&ouml;sse).
</html>"));
    end Kupplung_pos;
    
    connector Kupplung_neg "hydraulischer Anschluss" 
      SI.Pressure p "Absolutdruck in der Kupplung";
      flow SI.VolumeFlowRate IV "Volumenstromstaerke durch Kupplung";
      annotation (Icon(Ellipse(extent=[-100,100; 100,-100], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=7,
              rgbfillColor={255,255,255}))),
                                       Documentation(info="<html>
<h3>Hydrodynamik: Volumen und Druck</h3>
<font color=\"#008800\">Kupplung_neg</font> sollte als Ausgang eines Stromgliedes (<font color=\"#0000FF\">Widerstand</font> oder <font color=\"#0000FF\">Induktivit&auml;t</font>) verwendet werden. Der <font color=\"#FF0000\">Absolutdruck</font>  <strong>p</strong> mit der Einheit Pascal (Pa) steht f&uuml;r die Potentialgr&ouml;sse. Die <font color=\"#FF0000\">Volumenstromst&auml;rke</font> <strong>IV</strong> mit der Einheit Kubikmeter pro Sekunde (m<sup>3</sup>/s) beschreibt den Transport der Grundmenge der Hydrodynamik (Stromgr&ouml;sse).
</html>"));
    end Kupplung_neg;
    
    connector Stift_pos "elektrischer Anschluss" 
      SI.Voltage V "Potential beim Stift";
      flow SI.Current I "Stromstaerke durch den Stift";
      annotation (Icon(Ellipse(extent=[-100,100; 100,-100], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=2,
              rgbfillColor={0,255,0},
              fillPattern=1))), Documentation(info="<html>
<h3>Elektrodynamik: Ladung und Potential</h3>
<font color=\"#008800\">Stift_pos</font> sollte als Eingang eines Stromgliedes (<font color=\"#0000FF\">Widerstand</font>, <font color=\"#0000FF\">Kapazit&auml;t</font> oder <font color=\"#0000FF\">Induktivit&auml;t</font>) verwendet werden. Das <font color=\"#FF0000\">Potential</font>  <strong>V</strong> mit der Einheit Volt (V oder J/C) steht f&uuml;r die Potentialgr&ouml;sse. Die <font color=\"#FF0000\">elektrische Stromst&auml;rke</font> <strong>I</strong> mit der Einheit Ampere (A) beschreibt den Transport der Grundmenge der Elektrodynamik (Stromgr&ouml;sse).
</html>"));
    end Stift_pos;
    
    connector Stift_neg "elektrischer Anschluss" 
      SI.Voltage V "Potential beim Stift";
      flow SI.Current I "Stromstaerke durch den Stift";
      annotation (Icon(Ellipse(extent=[-100,100; 100,-100], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255}))),
                                       Documentation(info="<html>
<h3>Elektrodynamik: Ladung und Potential</h3>
<font color=\"#008800\">Stift_neg</font> sollte als Ausgang eines Stromgliedes (<font color=\"#0000FF\">Widerstand</font>, <font color=\"#0000FF\">Kapazit&auml;t</font> oder <font color=\"#0000FF\">Induktivit&auml;t</font>) verwendet werden. Das <font color=\"#FF0000\">Potential</font>  <strong>V</strong> mit der Einheit Volt (V oder J/C) steht f&uuml;r die Potentialgr&ouml;sse. Die <font color=\"#FF0000\">elektrische Stromst&auml;rke</font> <strong>I</strong> mit der Einheit Ampere (A) beschreibt den Transport der Grundmenge der Elektrodynamik (Stromgr&ouml;sse).
</html>"));
    end Stift_neg;
    
    connector TFlansch_pos "Flansch fuer die Translation" 
      SI.Velocity v "Geschwindigkeit des Flansch";
      flow SI.Force F "Impulsstromstaerke durch den Flansch";
      annotation (Icon(Ellipse(extent=[-100,100; 100,-100], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1))), Documentation(info="<html>
<h3>Translationsmechanik: Impuls und Geschwindigkeit</h3>
<p><font color=\"#008800\">TFlansch_pos</font> sollte als Eingang eines Stromgliedes (<font color=\"#0000FF\">Reibschicht, D&auml;mpfer oder Feder</font>) sowie bei einem Impulsspeicher (<font color=\"#0000FF\">Masse</font>) verwendet werden. Die <font color=\"#FF0000\">Geschwindigkeit</font> <strong>v</strong> mit der Einheit Meter pro Sekunde (m/s) steht f&uuml;r die mechanische Potentialgr&ouml;sse. Die <font color=\"#FF0000\">Impulsstromst&auml;rke</font> (Kraft) <strong>F</strong> mit der Einheit Newton (N) liefert die Stromgr&ouml;sse.</p>
<p>Der Begriff <font color=\"#008800\">Kraft</font> beschreibt die <font color=\"#008800\">Strom- oder Quellenst&auml;rke des Impulses bez&uuml;glich eines K&ouml;rpers</font>. Der Kraftbegriff ist somit eine reine Hilfsgr&ouml;sse, die nur dank der Gravitation und des Elektromagnetismus eine (zu) grosse Bedeutung erlangt hat.</p>
</html>"));
    end TFlansch_pos;
    
    connector TFlansch_neg "Flansch fuer die Translation" 
      SI.Velocity v "Geschwindigkeit des Flansch";
      flow SI.Force F "Impulsstromstaerke durch den Flansch";
      annotation (Icon(Ellipse(extent=[-100,100; 100,-100], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255}))),
                                     Documentation(info="<html>
<h3>Translationsmechanik: Impuls und Geschwindigkeit</h3>
<p><font color=\"#008800\">TFlansch_neg</font> sollte als Ausgang eines Stromgliedes (<font color=\"#0000FF\">Reibschicht, D&auml;mpfer oder Feder</font>) verwendet werden. Die <font color=\"#FF0000\">Geschwindigkeit</font> <strong>v</strong> mit der Einheit Meter pro Sekunde (m/s) steht f&uuml;r die mechanische Potentialgr&ouml;sse. Die <font color=\"#FF0000\">Impulsstromst&auml;rke</font> (Kraft) <strong>F</strong> mit der Einheit Newton (N) liefert die Stromgr&ouml;sse.</p>
<p>Der Begriff <font color=\"#008800\">Kraft</font> beschreibt die <font color=\"#008800\">Strom- oder Quellenst&auml;rke des Impulses bez&uuml;glich eines K&ouml;rpers</font>. Der Kraftbegriff ist somit eine reine Hilfsgr&ouml;sse, die nur dank der Gravitation und des Elektromagnetismus eine (zu) grosse Bedeutung erlangt hat.</p>
</html>"));
    end TFlansch_neg;
    
    connector RFlansch_pos "Flansch fuer die Rotation" 
      SI.AngularVelocity w "Winkelgeschwindigkeit des Flansch";
      flow SI.Torque M "Drehimpulsstromstaerke durch den Flansch";
      annotation (Icon(Ellipse(extent=[-100,100; 100,-100], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=10,
              rgbfillColor={135,135,135}))), Documentation(info="<html>
<h3>Rotationsmechanik: Drehimpuls und Winkelgeschwindigkeit</h3>
<p><font color=\"#008800\">RFlansch_pos</font> sollte als Eingang eines Stromgliedes (<font color=\"#0000FF\">Rutschkupplung, D&auml;mpfer oder Feder</font>) sowie bei einem Drehimpulsspeicher (<font color=\"#0000FF\">Massentr&auml;gheitsmoment</font>) verwendet werden. Die <font color=\"#FF0000\">Winkelgeschwindigkeit</font> <strong>w</strong> (eigentlich ein kleines Omega) mit der Einheit Radiant pro Sekunde (rad/s) steht f&uuml;r die Potentialgr&ouml;sse. Die <font color=\"#FF0000\">Dehimpulsstromst&auml;rke</font> (Drehmoment) <strong>M</strong> mit der Einheit Newtonmeter (Nm) liefert die Stromgr&ouml;sse.</p>
<p>Der Begriff <font color=\"#008800\">Drehmoment</font> beschreibt die <font color=\"#008800\">Strom- oder Quellenst&auml;rke des Drehimpulses bez&uuml;glich eines K&ouml;rpers</font>. Der Begriff Drehmoment ist somit eine reine Hilfsgr&ouml;sse, die nur dank der fr&uuml;hen Formulierung des Hebelgesetzes durch Archimedes eine (zu) grosse Bedeutung erlangt hat.</p>
</html>"));
    end RFlansch_pos;
    
    connector RFlansch_neg "Flansch fuer die Rotation" 
      SI.AngularVelocity w "Winkelgeschwindigkeit des Flansch";
      flow SI.Torque M "Drehimpulsstromstaerke durch den Flansch";
      annotation (Icon(Ellipse(extent=[-100,100; 100,-100], style(
              color=10,
              rgbcolor={136,136,136},
              fillColor=7,
              rgbfillColor={255,255,255}))),
                                           Documentation(info="<html>
<h3>Rotationsmechanik: Drehimpuls und Winkelgeschwindigkeit</h3>
<p><font color=\"#008800\">RFlansch_neg</font> sollte als Ausgang eines Stromgliedes (<font color=\"#0000FF\">Rutschkupplung, D&auml;mpfer oder Feder</font>) verwendet werden. Die <font color=\"#FF0000\">Winkelgeschwindigkeit</font> <strong>w</strong> mit der Einheit Radiant pro Sekunde (rad/s) steht f&uuml;r die Potentialgr&ouml;sse. Die <font color=\"#FF0000\">Dehimpulsstromst&auml;rke</font> (Drehmoment) <strong>M</strong> mit der Einheit Newtonmeter (Nm) liefert die Stromgr&ouml;sse.</p>
<p>Der Begriff <font color=\"#008800\">Drehmoment</font> beschreibt die <font color=\"#008800\">Strom- oder Quellenst&auml;rke des Drehimpulses bez&uuml;glich eines K&ouml;rpers</font>. Der Begriff Drehmoment ist somit eine reine Hilfsgr&ouml;sse, die nur dank der fr&uuml;hen Formulierung des Hebelgesetzes durch Archimedes eine (zu) grosse Bedeutung erlangt hat.</p>
</html>"));
    end RFlansch_neg;
    
    connector Kontakt_pos "Thermischer Anschluss" 
      SI.Temperature T "thermodynamische Temperatur";
      flow SI.ThermalConductance IS "Entropiestromstaerke";
      annotation (Icon(Ellipse(extent=[-100,100; 100,-100], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=1,
              rgbfillColor={255,0,0},
              fillPattern=1))), Documentation(info="<html>
<h3>Thermodynamik: Entropie und Temperatur</h3>
<p><font color=\"#008800\">Kontakt_pos</font> sollte als Eingang eines Stromgliedes (<font color=\"#0000FF\">W&auml;rmeleitung, Strahlung</font>) sowie bei einem Speicher (<font color=\"#0000FF\">fester, fl&uuml;ssiger oder gasf&ouml;rmiger Stoff</font>) verwendet werden. Die <font color=\"#FF0000\">absolute Temperatur</font> <strong>T</strong> mit der Einheit Kelvin (K) steht f&uuml;r die Potentialgr&ouml;sse. Die <font color=\"#FF0000\">Entropiestromst&auml;rke</font> <strong>IS</strong> mit der Einheit Watt pro Kelvin (W/K) beschreibt den Transport der Grundmenge der Thermodynamik (Stromgr&ouml;sse).</p>
<p>Die Gr&ouml;sse, welche bei \"W&auml;rmeabgabe oder W&auml;rmeaufnahme\" zusammen mit der Energie als \"Energietr&auml;ger\" ausgetauscht wird, heisst Entropie. Weil die Entropie in etwa dem entspricht, was wir in der Umgangssprache mit W&auml;rme im Sinne von Menge umschreiben (W&auml;rmezu- und -abfuhr, W&auml;rmespeicherung und W&auml;rmeproduktion), sollte man W&auml;rme statt Entropie sagen. Leider ist das Wort <font color=\"#FF0000\">W&auml;rme</font> im neunzehnten Jahrhundert - in Unkenntnis der eigentlichen Struktur der Thermodynamik - der thermisch ausgetauschten Energie zugewiesen und in einem Lehrsatz (1. Hauptsatz der Thermodynamik) definiert worden. Wir m&uuml;ssen heute akzeptieren, dass in der Physik die falsche Gr&ouml;sse mit dem Wort W&auml;rme umschrieben wird: die Physiker bezeichnen die zusammen mit der <font color=\"#008800\">Entropie ausgetauschte Energie</font> als <font color=\"#008800\">W&auml;rme</font>, obwohl die <font color=\"#008800\">Entropie</font> die <font color=\"#008800\">eigentliche W&auml;rmemenge</font> ist.</p>
<p> Der Zusammenhang <font color=\"#FF0000\">Energiestromst&auml;rke = absolute Temperatur * Entropiestromst&auml;rke</font> ersetzt die m&uuml;hsame und quasistatische Definition der Entropie mittels Carnotzyklus und erlaubt eine direkte Formulierung dynamischer Prozesse.
</html>"));
    end Kontakt_pos;
    
    connector Kontakt_neg "Thermischer Anschluss" 
      SI.Temperature T "thermodynamische Temperatur";
      flow SI.ThermalConductance IS "Entropiestromstaerke";
      annotation (Icon(Ellipse(extent=[-100,100; 100,-100], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=7,
              rgbfillColor={255,255,255}))),
                                       Documentation(info="<html>
<h3>Thermodynamik: Entropie und Temperatur</h3>
<p><font color=\"#008800\">Kontakt_neg</font> sollte als Ausgang eines Stromgliedes (<font color=\"#0000FF\">W&auml;rmeleitung, Strahlung</font>) sowie bei einem Entropieproduzenten (<font color=\"#0000FF\">Reibungselement, Widerstand</font>) verwendet werden. Die <font color=\"#FF0000\">absolute Temperatur</font> <strong>T</strong> mit der Einheit Kelvin (K) steht f&uuml;r die Potentialgr&ouml;sse. Die <font color=\"#FF0000\">Entropiestromst&auml;rke</font> <strong>IS</strong> mit der Einheit Watt pro Kelvin (W/K) beschreibt den Transport der Grundmenge der Thermodynamik (Stromgr&ouml;sse).</p>
<p>Die Gr&ouml;sse, welche bei \"W&auml;rmeabgabe oder W&auml;rmeaufnahme\" zusammen mit der Energie als \"Energietr&auml;ger\" ausgetauscht wird, heisst Entropie. Weil die Entropie in etwa dem entspricht, was wir in der Umgangssprache mit W&auml;rme im Sinne von Menge umschreiben (W&auml;rmezu- und -abfuhr, W&auml;rmespeicherung und W&auml;rmeproduktion), sollte man W&auml;rme statt Entropie sagen. Leider ist das Wort <font color=\"#FF0000\">W&auml;rme</font> im neunzehnten Jahrhundert - in Unkenntnis der eigentlichen Struktur der Thermodynamik - der thermisch ausgetauschten Energie zugewiesen und in einem Lehrsatz (1. Hauptsatz der Thermodynamik) definiert worden. Wir m&uuml;ssen heute akzeptieren, dass in der Physik die falsche Gr&ouml;sse mit dem Wort W&auml;rme umschrieben wird: die Physiker bezeichnen die zusammen mit der <font color=\"#008800\">Entropie ausgetauschte Energie</font> als <font color=\"#008800\">W&auml;rme</font>, obwohl die <font color=\"#008800\">Entropie</font> die <font color=\"#008800\">eigentliche W&auml;rmemenge</font> ist.</p>
<p> Der Zusammenhang <font color=\"#FF0000\">Energiestromst&auml;rke = absolute Temperatur * Entropiestromst&auml;rke</font> ersetzt die m&uuml;hsame und quasistatische Definition der Entropie mittels Carnotzyklus und erlaubt eine direkte Formulierung dynamischer Prozesse.
</html>"));
    end Kontakt_neg;
    
  partial model VolStromglied 
      "Element mit den Anschluessen h_p und h_n, Volumenstrom von h_p nach h_n" 
      SI.Pressure dp "Druckdifferenz ueber dem Element";
      SI.VolumeFlowRate IV "Volumenstromstaerke durch Element";
      SI.Power P "Prozessleistung ueber dem Element";
      Konnektoren.Kupplung_pos h_p "Eingang" 
                                           annotation (extent=[-100,-10; -80,10]);
      Konnektoren.Kupplung_neg h_n "Ausgang" 
                                           annotation (extent=[80,-10; 100,10]);
      annotation (Diagram, Icon(Rectangle(extent=[-80,40; 80,-40], style(color=3,
                rgbcolor={0,0,255}))),
        Documentation(info="<html>
<h3>Stromglied f&uuml;r den Volumenstrom</h3>
<p>Das <font color=\"#FF0000\">partial model</font> <font color=\"#008800\">VolStromglied</font> dient als Basis f&uuml;r die Elemente <font color=\"#0000FF\">LaminarerWiderstand</font>, <font color=\"#0000FF\">TurbulenterWiderstand</font>, <font color=\"#0000FF\">Induktivitaet</font>, <font color=\"#0000FF\">Pumpe_IV</font>, <font color=\"#0000FF\">Pumpe_dp</font>, <font color=\"#0000FF\">TemperaturWiderstand</font>, <font color=\"#0000FF\">Ueberdruckventil</font>, <font color=\"#0000FF\">DiodenVentil</font> und <font color=\"#0000FF\">Schaltventil</font>. Aus der Druckdifferenz <strong>dp</strong> und der Volumenstromst&auml;rke <strong>IV</strong> wird die Leistung <strong>P</strong> berechnet.</p>
<p><font color=\"#FF0000\">Vorzeichenregel:</font> die Druckdifferenz <strong>dp</strong> ist gleich Druck am Eingang <strong>h_p.p</strong> minus Druck am Ausgang <strong>h_n.p</strong>. Die Volumenstromst&auml;rke ist positiv, wenn der Strom vom Eingang <strong>h_p</strong> zum Ausgang <strong>h_n</strong> fliesst. Als Folge dieser Konvention ist die Prozessleistung <strong>P</strong> positiv, wenn der Volumenstrom Energie freisetzt. d.h. bei einer Pumpe ist die Prozessleistung negativ.</p>
</html>"));
  equation 
      dp = h_p.p - h_n.p;
      0 = h_p.IV + h_n.IV;
      IV = h_p.IV;
      P = dp*IV;
  end VolStromglied;
    
  partial model Zweipol 
      "Element mit den Anschluessen p und n, elektrischer Strom von p  nach n" 
      SI.Voltage U "Spannung ueber dem Element";
      SI.Current I "elektrische Stromstaerke durch Element";
      SI.Power P "Prozessleistung ueber dem Element";
      Stift_pos p annotation (extent=[-100,-10; -80,10]);
      Stift_neg n annotation (extent=[80,-10; 100,10]);
      annotation (Icon(Rectangle(extent=[-80,40; 80,-40], style(color=2, rgbcolor=
                 {0,255,0}))), Documentation(info="<html>
<h3>Stromglied f&uuml;r den elektrischen Strom</h3>
<p>Das <font color=\"#FF0000\">partial model</font> <font color=\"#008800\">Zweipol</font> dient als Basis f&uuml;r die Elemente <font color=\"#0000FF\">Kondensator</font>, <font color=\"#0000FF\">Widerstand</font>, <font color=\"#0000FF\">Induktivitaet</font>, <font color=\"#0000FF\">Diode</font>, <font color=\"#0000FF\">Stromquelle</font>, <font color=\"#0000FF\">Spannungsquelle</font> und <font color=\"#0000FF\">Schalter</font>. Aus der Spannung <strong>U</strong> und der elektrischen Stromst&auml;rke <strong>I</strong> wird die Leistung <strong>P</strong> berechnet.</p>
<p><font color=\"#FF0000\">Vorzeichenregel:</font> die Spannung <strong>U</strong> ist gleich Potential am Eingang <strong>p.V</strong> minus Potential am Ausgang <strong>n.V</strong>. Die Stromst&auml;rke ist positiv, wenn der elektrische Strom vom Eingang <strong>p</strong> zum Ausgang <strong>n</strong> fliesst. Als Folge dieser Konvention ist die Prozessleistung <strong>P</strong> positiv, wenn der elektrische Strom Energie freisetzt. d.h. bei einer Strom- oder Spannungsquelle ist die Prozessleistung negativ.</p>
</html>"),
        Diagram);
  equation 
      U = p.V - n.V;
      0 = p.I + n.I;
      I = p.I;
      P = U*I;
  end Zweipol;
    
  partial model Verformbar 
      "Element mit den Anschluessen tr_p und tr_n, Impulsstrom von tr_p nach tr_n" 
      parameter SI.Length L = 1 "Anfangslaenge des Elements";
      SI.Length s "Laenge des Elements";
      parameter SI.Length dxa = 0 "Anfangsverformung";
      SI.Velocity dv "Geschwindigkeitsdifferenz ueber dem Element";
      SI.Length dx(start = dxa, fixed = true) "Verformung des Elements";
      SI.Force F "Impulsstromstaerke (Kraft) durch Element";
      SI.Power P "Prozessleistung ueber dem Element";
      Konnektoren.TFlansch_pos tr_p 
                                  annotation (extent=[-100,-10; -80,10]);
      Konnektoren.TFlansch_neg tr_n 
                                  annotation (extent=[80,-10; 100,10]);
      annotation (Icon(Rectangle(extent=[-80,40; 80,-40], style(color=0, rgbcolor=
                 {0,0,0}))),                 Diagram,
        Documentation(info="<html>
<h3>Stromglied f&uuml;r den Impulsstrom</h3>

<p>Das <font color=\"#FF0000\">partial model</font> <font color=\"#008800\">Verformbar</font> dient als Basis f&uuml;r die Elemente <font color=\"#0000FF\">LinDaempfer</font>, <font color=\"#0000FF\">LinFeder</font>, <font color=\"#0000FF\">Reibung</font>, <font color=\"#0000FF\">Elastomer</font>, <font color=\"#0000FF\">Faden</font>, <font color=\"#0000FF\">Pumpe_Ip</font>, <font color=\"#0000FF\">Pumpe_dv</font>, <font color=\"#0000FF\">LinFederT</font>, <font color=\"#0000FF\">ReibungT</font>, <font color=\"#0000FF\">Huelse</font> und <font color=\"#0000FF\">Luftwiderstand</font>. Aus der Geschwindigkeitsdifferenz <strong>dv</strong> und der Impulsstromst&auml;rke <strong>F</strong> wird die Leistung <strong>P</strong> berechnet. Die Geschwindigkeitsdifferenz wird zur Verformung <strong>dx</strong> aufintegriert. Die L&auml;nge <strong>s</strong> des Elementes ist gleich Anfangsl&auml;nge <strong>L</strong> minus die Verformung <strong>dx</strong>.</p>

<p><font color=\"#FF0000\">Vorzeichenregel:</font> Die positive Richtung zeigt nach rechts. Folglich enth&auml;lt ein sich nach rechts bewegender K&ouml;rper einen Impuls&uuml;berschuss. Impuls, der in positive Richtung (nach rechts) durch ein Element fliesst, belastet dieses auf Druck. Die Geschwindigkeitsdifferenz <strong>dv</strong> (Potentialdifferenz) ist gleich Geschwindigkeit am Eingang <strong>tr_p.v</strong> minus Geschwindigkeit am Ausgang <strong>tr_n.v</strong>. Die Impulsstromst&auml;rke ist positiv, wenn der Impuls vom Eingang <strong>tr_p</strong> zum Ausgang <strong>tr_n</strong> fliesst. Aus dieser Konvention folgt, dass die Prozessleistung <strong>P</strong> positiv gez&auml;hlt wird, sobald der Impulsstrom Energie freisetzt. Passive Glieder haben demnach eine positive, aktive eine negative Prozessleistung. Die L&auml;nge eines Elementes <strong>s</strong> soll trotz dieser prozessorientierten Vorzeichenwahl gr&ouml;sser als Null sein. Deshalb wird zur Berechnung der L&auml;nge <strong>s</strong> die Verformung <strong>dx</strong> von der Anfangsl&auml;nge <strong>L</strong> abgezogen. Es wird dringend empfohlen, alle Elemente in positive Richtung orientiert (von links nach rechts) aufzureihen, wobei der positive Flansch <strong>tr_p</strong> gegen und der negative <strong>tr_n</strong> in Bezugsrichtung zeigt (der positive Flansch <strong>tr_p</strong> auf der linken Seite und der negative <strong>tr_n</strong>auf der rechten zu liegen kommt).</p>

<p><font color=\"#FF0000\">Impulsstrom und Kraft:</font> Eine Kraft ist eine Impulsstromst&auml;rke bez&uuml;glich eines K&ouml;rpers. Fliesst Impuls zu, zeigt der Kraftpfeil in die positive Richtung (also nach rechts). Dabei spielt es keine Rolle, ob der Impuls von der positiven (Zug) oder von der negativen (Druck) Seite her zustr&ouml;mt.</p>
</html>"));
  equation 
      dv = tr_p.v - tr_n.v;
      dv = der(dx);
      s = L - dx;
      0 = tr_p.F + tr_n.F;
      F = tr_p.F;
      P = dv*F;
  end Verformbar;
    
  partial model Verdrehbar 
      "Element mit den Anschluessen ro_p und ro_n, Drehimpulsstrom von ro_p nach ro_n" 
     parameter SI.Angle dphia = 1 "Anfangsverdrehwinkel des Elements";
     SI.Length dphi( start = dphia, fixed = true) 
        "Verdrehwinkel ueber dem Element";
     SI.AngularVelocity dw "Winkelgeschwindigkeitsdifferenz ueber dem Element";
     SI.Torque M "Drehimpulsstromstaerke durch Element";
     SI.Power P "Prozessleistung ueber dem Element";
      annotation (Icon(Rectangle(extent=[-80,40; 80,-40], style(color=10,
                rgbcolor={135,135,135}))),   Diagram,
        Documentation(info="<html>
<h3>Stromglied f&uuml;r den Drehimpulsstrom</h3>

<p>Das <font color=\"#FF0000\">partial model</font> <font color=\"#008800\">Verdrehbar</font> dient als Basis f&uuml;r die Elemente <font color=\"#0000FF\">Drehdaempfer</font>, <font color=\"#0000FF\">Drehfeder</font>, <font color=\"#0000FF\">Drehreibung</font>, <font color=\"#0000FF\">Pumpe_IL</font>, <font color=\"#0000FF\">Pumpe_dL</font>, <font color=\"#0000FF\">Kupplung</font>, <font color=\"#0000FF\">DrehdaempferT</font> und <font color=\"#0000FF\">Drehreibung</font>. Aus der Winkelgeschwindigkeitsdifferenz <strong>dw</strong> und der Drehimpulsstromst&auml;rke <strong>M</strong> wird die Leistung <strong>P</strong> berechnet. Die Winkelgeschwindigkeitsdifferenz wird zum Verdrehwinkel <strong>dphi</strong> aufintegriert.</p>

<p><font color=\"#FF0000\">Vorzeichenregel:</font> Die positive Richtung zeigt nach rechts, der zugeh&ouml;rige Drehsinn gehorcht der <font color=\"#FF0000\">rechten Hand Regel</font>. Blickt man in positive Richtung auf ein im Uhrzeigersinn drehendes Schwungrad, speichert dieses einen Drehimpuls&uuml;berschuss. Drehmpuls, der nach rechts (positive Richtung) durch eine Achse fliesst, verdreht diese zu einer <font color=\"#FF0000\">Linksschraube</font>. Die Differenz der Winkelgeschwindigkeit <strong>dw</strong> ist gleich Winkelgeschwindigkeit am Eingang <strong>ro_p.w</strong> minus Winkelgeschwindigkeit am Ausgang <strong>ro_n.w</strong>. Die Stromst&auml;rke ist positiv, wenn der Drehimpuls vom Eingang <strong>tr_p</strong> zum Ausgang <strong>tr_n</strong> fliesst. Als Folge dieser Konvention ist die Prozessleistung <strong>P</strong> positiv, wenn der Impulsstrom Energie freisetzt. Bei einem Antriebselement ist die Prozessleistung negativ.</p>

<p><font color=\"#FF0000\">Drehimpulsstrom und Drehmoment:</font> Ein reines Drehmoment ist eine Drehimpulsstromst&auml;rke bez&uuml;glich eines K&ouml;rpers. Fliesst Drehimpuls zu, zeigt der Drehmomentenpfeil in die positive Richtung (also nach rechts). Dabei spielt es keine Rolle, ob der Drehmpuls von der positiven (Rechtsschraube) oder von negativen (Linksschraube) Seite her zustr&ouml;mt. Es wird empfohlen, alle Elemente von links nach rechts aufzureihen.</p>
</html>"));
      RFlansch_pos ro_p annotation (extent=[-100,-12; -80,8]);
      RFlansch_neg ro_n annotation (extent=[80,-10; 100,10]);
  equation 
     dw = ro_p.w - ro_n.w;
     dw = der(dphi);
     0 = ro_p.M + ro_n.M;
     M = ro_p.M;
     P = dw*M;
  end Verdrehbar;
    
  partial model Energiestromglied 
      "Element mit den Anschluessen th_p und th_n, Energieerhaltung" 
      SI.Temperature dT "Temperaturdifferenz ueber dem Element";
      SI.HeatFlowRate IW "Energiestromstaerke durch Element";
      SI.ThermalConductance PiS "Entropieproduktionsrate";
      Konnektoren.Kontakt_pos th_p annotation (extent=[-100,-10; -80,10]);
      Konnektoren.Kontakt_neg th_n annotation (extent=[80,-10; 100,10]);
       annotation (Icon(Rectangle(extent=[-80,40; 80,-40], style(color=5,
                rgbcolor={255,0,255}))), Documentation(info="<html>
<h3>Stromglied f&uuml;r den Energiestrom</h3>
<p>Das <font color=\"#FF0000\">partial model</font> <font color=\"#008800\">Energiestromglied</font> dient als Basis f&uuml;r die Elemente <font color=\"#0000FF\">Waermeleitung</font>, <font color=\"#0000FF\">Prisma</font>, <font color=\"#0000FF\">Uebergang</font> und <font color=\"#0000FF\">Waermestrahlung</font>. In diesen Elementen bleibt der durchfliessende Energiestrom (zugeordneter Energiestrom gleich <strong>th_p.T</strong> mal <strong>th_p.IS</strong> sowie <strong>th_n.T</strong> mal <strong>th_n.IS</strong>) erhalten und der Entropiestrom schwillt maximal an. Aus Energiestromst&auml;rke <strong>IW</strong> und Temperaturdifferenz <strong>dT</strong> wird  die Entropieproduktionsrate <strong>PiS</strong> ermittelt.</p>
<p><font color=\"#FF0000\">Vorzeichenregel:</font> die Temperaturdifferenz <strong>dT</strong> ist gleich Temperatur am Eingang <strong>th_p.T</strong> minus Temperatur am Ausgang <strong>th_n.T</strong>. Die Energiestromst&auml;rke ist positiv, wenn der Strom vom Eingang <strong>th_p</strong> zum Ausgang <strong>th_n</strong> fliesst.</p>
</html>"));
  equation 
      dT = th_p.T - th_n.T;
      0 = th_p.T*th_p.IS + th_n.T*th_n.IS;
      IW = th_p.T*th_p.IS;
      PiS = dT*th_p.IS/th_n.T;
  end Energiestromglied;
    
  partial model Entropiestromglied 
      "Element mit den Anschluessen th_p und th_n, Entropiestrom von th_p nach th_n" 
      SI.Temperature dT "Temperaturdifferenz ueber dem Element";
      SI.ThermalConductance IS "Entropiestromstaerke durch Element";
      SI.Power P "Prozessleistung ueber Element";
      Konnektoren.Kontakt_pos th_p annotation (extent=[-100,-10; -80,10]);
      Konnektoren.Kontakt_neg th_n annotation (extent=[80,-10; 100,10]);
       annotation (Icon(Rectangle(extent=[-80,40; 80,-40], style(color=1, rgbcolor={
                  255,0,9}))), Documentation(info="<html>
<h3>Stromglied f&uuml;r den Entropiestrom</h3>
<p>Das <font color=\"#FF0000\">partial model</font> <font color=\"#008800\">EntropieStromglied</font> dient als Basis f&uuml;r das Elemente <font color=\"#0000FF\">Pumpe_IS</font>, <font color=\"#0000FF\">Pumpe_dT</font> und <font color=\"#0000FF\">Schalter</font>. Aus der Temperaturdifferenz <strong>dT</strong> und der Entropiestromst&auml;rke <strong>IS</strong> wird die Leistung <strong>P</strong> berechnet.</p>
<p><font color=\"#FF0000\">Vorzeichenregel:</font> die Temperaturdifferenz <strong>dT</strong> ist gleich Temperatur am Eingang <strong>th_p.T</strong> minus Temperatur am Ausgang <strong>th_n.T</strong>. Die Entropiestromst&auml;rke ist positiv, wenn der Strom vom Eingang <strong>th_p</strong> zum Ausgang <strong>th_n</strong> fliesst. Als Folge dieser Konvention ist die Prozessleistung <strong>P</strong> positiv, wenn der Entropiestrom Energie freisetzt, d.h. bei einer Pumpe ist die Prozessleistung negativ.</p>
</html>"),
        Diagram);
  equation 
      dT = th_p.T - th_n.T;
      0 = th_p.IS + th_n.IS;
      IS = th_p.IS;
      P = dT*IS;
  end Entropiestromglied;
    
  end Konnektoren;
  
  package Hydrodynamik "einfache Hydrodynamik" 
    model HydroErde "Verbindung zur Umwelt" 
      parameter SI.Pressure pamb = 1e5 "Umgebungsdruck";
      SI.Power IW "Staerke des Energiestromes an die Umwelt";
      SI.Energy Waus(start=0, fixed=true) "Energieaustausch mit der Umwelt";
      annotation (defaultComponentName="Erde", Diagram,
        Icon(
          Line(points=[0,80; 0,40],style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Line(points=[-80,40; 80,40],
                                     style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Line(points=[-60,20; 60,20],   style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Line(points=[-40,0; 40,0],     style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Text(
            extent=[-100,0; 100,-100],
            style(color=3, rgbcolor={0,0,255}),
            string="pamb=%pamb")),
        Documentation(info="<html>
Mit der <font color=\"#008800\">HydroErde</font> kann unbeschr&auml;nkt Volumen bei einem Druck von <strong>pamb</strong> = 1e5 Pa ausgetauscht werden. Der an die Umwelt abfliessende, zugeordnete Energiestrom sowie die mit der Umwelt ausgetauschte Energie werden ermittelt. Das Bezugsniveau f&uuml;r diese Energieberechnungen ist Vakuum.
</html>"));
      Konnektoren.Kupplung_neg h_e annotation (extent=[-10,80; 10,100]);
    equation 
      h_e.p = pamb;
      IW = h_e.p*h_e.IV;
      IW = der(Waus);
    end HydroErde;
    
    model Federspeicher "linearer Speicher mit Anfangsdruck p0" 
      parameter Real CV(
        final unit="m3/Pa",
        final min=0)= 1e-8 "hydraulische Kapazitaet";
      parameter SI.Pressure p0 = 5e5 "Druck bei leerem Speicher";
      parameter SI.Volume Va = 0.001 "Anfangsvolumen";
      SI.Volume V(start=Va, fixed=true) "Inhalt des Federspeichers";
      SI.Power IW "zugeordneter Energiestrom";
      SI.Energy W(start=Wa, fixed=true) "Energieinhalt gegen Vakuum";
    protected 
      parameter SI.Energy Wa = p0*Va+Va^2/(2*CV) "Anfangsenergie";
    public 
      Konnektoren.Kupplung_pos h_p 
                                 annotation (extent=[-10,80; 10,100]);
    equation 
      V = CV*(h_p.p - p0);
      h_p.IV = der(V);
      IW = h_p.p*h_p.IV;
      IW = der(W);
      annotation (defaultComponentName="CV",
        Icon(
          Line(points=[0,20; 80,0; -80,-40; 80,-80; 0,-100], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Rectangle(extent=[-80,40; 80,20], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Rectangle(extent=[-80,80; 80,40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1))), Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Federspeicher</font> nimmt Volumen auf, sobald der angelegte Druck &uuml;ber den Schwellenwert <strong>p0</strong> steigt. Sinkt der angelegte Druck unter den Schwellenwert, wird das gespeicherte Volumen negativ. Um dies zu verhindern, m&uuml;sste ein Ventil eingebaut werden. Das Verh&auml;ltnis von Volumenzunahme und Druckanstieg bezeichnet man als hydraulische Kapazit&auml;t <strong>CV</strong> des Speichers.</p>
<p>Mit dem Element <font color=\"#008800\">Federspeicher</font> kann auch das Kompressionsverhalten der Fl&uuml;ssigkeit oder die Ausdehnung des umh&uuml;llenden Rohres modelliert werden.</p>
</html>"));
    end Federspeicher;
    
    model Blasenspeicher "Speicher mit Gasfuellung (isotherme Kompression)" 
      parameter SI.Pressure p0 = 5e5 "Druck bei leerem Speicher";
      parameter SI.Volume V0 = 0.01 "Geamtvolumen";
      parameter SI.Volume Va = 0 "Anfangsvolumen";
      parameter SI.Energy Wa = p0*V0*ln((V0-Va)/V0) "Anfangsenergie";
      SI.Pressure p "Absolutdruck";
      SI.Volume V(start=Va, fixed=true) "Inhalt des Federspeichers";
      SI.Power IW "zugeordneter Energiestrom";
      SI.Energy W(start=Wa, fixed=true) "Energieinhalt gegen Vakuum";
      Konnektoren.Kupplung_pos h_p 
                                 annotation (extent=[-10,80; 10,100]);
    equation 
      p = h_p.p;
      p =p0*(V0/(V0-V));
      h_p.IV = der(V);
      IW = h_p.p*h_p.IV;
      IW = der(W);
      annotation (defaultComponentName="BSp",
        Icon(Ellipse(extent=[-80,80; 80,-100], style(
              color=0,
              rgbcolor={0,0,9},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)), Ellipse(extent=[-38,46; 42,-100],style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=6,
              rgbfillColor={255,255,0}))),
                                Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Blasenspeicher</font> nimmt Volumen auf, sobald der angelegte Druck &uuml;ber den Schwellenwert <strong>p0</strong> steigt. Sinkt der angelegte Druck unter den Schwellenwert, wird das gespeicherte Volumen negativ. Um dies zu verhindern, m&uuml;sste ein Ventil eingebaut werden. Der Druck steigt umso st&auml;rker an, je mehr Volumen schon gespeichert ist. N&auml;hert sich das Volumen dem Grenzwert <strong>V0</strong>, kann der Druck beliebig hoch werden.</p>
</html>"));
    end Blasenspeicher;
    
    model LaminarerWiderstand "Druckabfall proportional zu Volumenstromstaerke" 
      extends Konnektoren.VolStromglied;
      parameter Real RV(
        final unit="Pa.s/m3",
        final min=0) = 1e8 "Stroemungswiderstand";
      SI.Energy Wdiss(start=0, fixed=true) "dissipierte Energie";
      annotation (defaultComponentName="RV",
        Icon(Text(
            extent=[-80,100; 80,40],
            style(color=3, rgbcolor={0,0,255}),
            string="%name"), Text(
            extent=[-80,-40; 80,-100],
            style(color=3, rgbcolor={0,0,255}),
            string="RV=%RV"),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=7,
              rgbfillColor={255,255,255}))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">LaminarerWiderstand</font> modelliert das linear Widerstandsverhalten bei einer Laminarstr&ouml;mung.</p>
<p>Der Str&ouml;mungswiderstand <strong>RV</strong> kann am realen Objekt gemessen oder berechnet werden. f&uuml;r ein langes Rohr gilt das Gesetz von Hagen-Poiseuille</p>
<p><i>RV = 128*Viskosit&auml;t*L&auml;nge/(pi*d^4)</i></p>
</html>"));
    equation 
      dp = RV*IV;
      P = der(Wdiss);
    end LaminarerWiderstand;
    
    model TurbulenterWiderstand 
      "Turbulenter Widerstand bei starker Stroemung, laminarer Widerstand bei schwacher Stroemung" 
      extends Konnektoren.VolStromglied;
      parameter SI.Density Rho=850 "Dichte der Fluessigkeit";
      parameter SI.Length d=0.02 
        "hydraulischer Durchmesser der Eintrittsoeffnung";
      parameter Real Zeta = 1 "Verlustziffer";
      parameter SI.VolumeFlowRate IVkrit=1e-6 "kritische Volumenstromstaerke";
      parameter Real kV(
        final unit="Pa.s2/m6",
        final min=0) = Rho*Zeta*8/(Modelica.Constants.pi*d^2)^2 
        "Beschreibt den turbulenten Widerstand";
      SI.Energy Wdiss(start=0, fixed=true) "dissipierte Energie";
      Boolean turbulent;
      annotation (defaultComponentName="Wid",
        Icon(
          Text(
            extent=[-80,100; 80,40],
            style(color=3, rgbcolor={0,0,255}),
            string="%name"),
          Text(
            extent=[-80,-40; 80,-100],
            style(color=3, rgbcolor={0,0,255}),
            string="Zeta=%Zeta"),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Line(points=[-52,-40; 8,0; -4,20; 68,40; 22,-20; 8,0], style(color=3,
                rgbcolor={0,0,255}))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">TurbulenterWiderstand</font> modelliert das Widerstandsverhalten einer turbulenten Str&ouml;mung.</p>
<p>Die Werte f&uuml;r die Verlustziffer <strong>Zeta</strong> k&ouml;nnen der Literatur entnommen werden. Liegt der Betrag der Volumenstromst&auml;rke unter dem Wert <strong>IVkrit</strong>, wird das Str&ouml;mungsverhalten laminar, das Widerstandsverhalten linear.</p>
<p>Die Umrechnung von der <font color=\"#FF0000\">kritischen Reynoldschen Zahl</font> auf die hier verwendete kritische Volumenstromst&auml;rke geschieht &uuml;ber die folgende Beziehung</p>
<p><i>IVkrit = pi*Rekrit*Viskosit&auml;t*d/(4*Dichte)</i></p>
</html>"));
    equation 
      turbulent = abs(IV) > IVkrit;
      dp = if turbulent then kV*IV*abs(IV) else kV*IV*IVkrit;
      P = der(Wdiss);
    end TurbulenterWiderstand;
    
    model Induktivitaet "hydraulische Induktivitaet eines langen Rohres" 
      extends Konnektoren.VolStromglied;
      parameter SI.Density Rho = 850 "Dichte der Fluessigkeit";
      parameter SI.Length d = 0.02 "mittlerer Durchmesser des Rohres";
      parameter SI.Length L = 10 "Laenge des Rohres";
      parameter SI.Acceleration g = 9.81 "Gravitationsfeldstaerke";
      parameter Real alpha(
         final unit="deg") = 0 "Neigungswinkel";
      SI.Energy W(start=0, fixed=true);
    protected 
      parameter Real LV(
        final unit="kg/m4",
        final min=0) = 4*Rho*L/(Modelica.Constants.pi*d^2) 
        "Beschreibt die hydraulische Induktivitaet des Rohres";
      annotation (defaultComponentName="LV",
        Icon(
          Text(
            extent=[-80,100; 80,40],
            style(color=3, rgbcolor={0,0,255}),
            string="%name"),
          Text(
            extent=[-80,-40; 80,-100],
            style(color=3, rgbcolor={0,0,255}),
            string="d=%d"),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255}))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Induktivitaet</font> bildet das tr&auml;ge und schwere Verhalten der Fl&uuml;ssigkeit in einem Rohr nach. Die Tr&auml;gheit wirkt induktiv und die Schwere sorgt f&uuml;r einen zus&auml;tzlichen Druckaufbau.</p>
<p>Die Neigung gegen die Horizontale <strong>alpha</strong> kann in Grad eingegeben werden. <font color=\"#FF0000\">Der Neigungswinkel ist positiv, wenn der Ausgang <strong>h_n</strong> tiefer liegt als der Eingang <strong>h_p</strong></font>.</p>
</html>"));
    equation 
      dp = LV*der(IV) + Rho*g*L*sin(alpha*Modelica.Constants.pi/180.0);
       P = der(W);
    end Induktivitaet;
    
    model Pumpe_IV "Eingangssignal steuert Volumenstromstaerke" 
      extends Konnektoren.VolStromglied;
      Modelica.Blocks.Interfaces.RealInput IV_in 
        annotation (extent=[-10,-100; 10,-80],
                                             rotation=-270);
      annotation (defaultComponentName="P_IV", Diagram,
        Icon(
          Line(points=[0,-80; 0,-40], style(color=3, rgbcolor={0,0,255})),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
            Polygon(points=[80,0; 40,30; 40,10; -80,10; -80,-10; 40,-10; 40,-30;
                80,0], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Text(
            extent=[-100,100; 100,40],
            style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="%name")),
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Pumpe_IV</font> f&ouml;rdert einen Volumenstrom nach Vorgabe des Signaleingangs <strong>IV_in</strong>. Der Strom wird begrenzt, sobald der Betrag der Leistung den Wert <strong>Pmax</strong> &uuml;bersteigt.</p>
<p>Die Volumenstromst&auml;rke ist positiv, wenn das Volumen vom Eingang <strong>h_p</strong> zum Ausgang <strong>h_n</strong> fliesst. <font color=\"#FF0000\">Die Leistung <strong>P</strong> ist negativ, falls die Pumpe einen Volumenstrom von einem Ort mit kleinem zu einem Ort mit grossem Druck f&ouml;rdert.</font></p>
</html>"));
    equation 
      IV = IV_in;
    end Pumpe_IV;
    
    model Pumpe_dp "Eingangssignal steuert Druckdifferenz" 
      extends Konnektoren.VolStromglied;
      annotation (defaultComponentName="P_dp",
        Icon(
          Rectangle(extent=[-80,40; 80,-40], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-100,100; 100,40],
            string="%name",
            style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Line(points=[0,-80; 0,-40], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=2,
              rgbfillColor={0,255,0},
              fillPattern=1)),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Line(points=[40,0; 40,-20; 80,0; 40,20; 40,0; -40,0; -40,20; -80,0;
                -40,-20; -40,0], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1))),        Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Pumpe_dp</font> erzeugt eine Druckdifferenz nach Vorgabe des Signaleingangs <strong>dp_in</strong>. Der Volumenstrom wird nicht begrenzt.</p>
<p>Ein positiver Signaleingang <strong>dp_in</strong> erzeugt eine <font color=\"#FF0000\">negative</font> Druckdifferenz (der Druck am Eingang <strong>h_p.p</strong> liegt dann tiefer als am Ausgang <strong>h_n.p</strong>). Die Volumenstromst&auml;rke ist wie bei den passiven Elementen positiv, wenn das Volumen vom Eingang <strong>h_p</strong> zum Ausgang <strong>h_n</strong> fliesst. <font color=\"#FF0000\">Die Leistung <strong>P</strong> ist negativ, falls die Pumpe Energie auf den Volumenstrom &uuml;bertr&auml;gt</font>.</p>
</html>"));
      Modelica.Blocks.Interfaces.RealInput dp_in 
        annotation (extent=[-10,-100; 10,-80], rotation=90);
    equation 
      dp = -dp_in;
    end Pumpe_dp;
    
    model WiderstandT 
      "Druckabfall proportional zu Volumenstromstaerke, Entropiebilanz" 
      extends Konnektoren.VolStromglied;
      parameter SI.Temperature T0 = 283 "Referenztemperatur";
      parameter Real Beta = 1.1e11 "Faktor im Exponent";
      parameter Real n = -4.2 "Exponent der Temperatur";
      parameter Real RV0(
        final unit="Pa.s/m3",
        final min=0) = 1e8 "Stroemungswiderstand bei Referenztemperatur";
      Real RV(
        final unit="Pa.s/m3",
        final min=0) "Stroemungswiderstand";
      SI.ThermalConductance PiS "Entropieproduktionsrate";
      SI.Temperature T "absolute Temperatur";
      annotation (defaultComponentName="RV_T",
       Icon(Text(
            extent=[-80,100; 80,40],
            style(color=3, rgbcolor={0,0,255}),
            string="%name"), Line(points=[0,-40; 0,-80], style(color=1,
                rgbcolor={255,0,0})),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=1,
              rgbfillColor={255,0,0}))),
                                       Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">WiderstandT</font> modelliert das linear Widerstandsverhalten bei einer Laminarstr&ouml;mung.</p>
<p>Der Str&ouml;mungswiderstand <strong>RV</strong> h&auml;ngt von der Temperatur ab</p>
<p><i>log(log(RV/RV0)) = n*log(T/T0)</i></p>
<p>Die im Prozess produzierte Entropie wird &uuml;ber den Anschluss <strong>th_n</strong> abgef&uuml;hrt. <font color=\"#FF0000\">Der Anschluss <strong>th_n</strong> muss an ein thermisches Element (notfalls an ThermoErde) angeschlossen werden.</font></p>
</html>"));
      Konnektoren.Kontakt_neg th_n 
        annotation (extent=[-10,-100; 10,-80]);
    equation 
      dp = RV*IV;
      RV = RV0*exp(Beta*(T^n-T0^n));
      PiS = P/T;
      T = th_n.T;
      PiS = -th_n.IS;
    end WiderstandT;
    
    model Ueberdruckventil 
      "Ventil  gegen Druckdifferenze oder gegen Absolutdruck mit Hysterse" 
      extends Konnektoren.VolStromglied;
      parameter SI.Density Rho = 850 "Dichte des Hydraulikoels";
      parameter SI.Length d = 0.01 "hydraulischer Durchmesser des Ventils";
      parameter Real Zeta = 1 "Verlustziffer";
      parameter SI.VolumeFlowRate IVkrit=1e-6 "kritische Volumenstromstaerke";
      parameter SI.Pressure pschliess = 100 "untere Schwelle fr Hysterese";
      parameter SI.Pressure poeff = 5000 "obere Schwelle fr Hysterese";
      SI.Pressure pkrit "entweder gleich poeff oder gleich pschliess";
      SI.Energy Wdiss(start=0, fixed=true) "dissipierte Energie";
    protected 
      parameter Real kV(
        final unit="Pa.s2/m6",
        final min=0) = Rho*Zeta*8/(Modelica.Constants.pi*d^2)^2 
        "Beschreibt den turbulenten Widerstand";
      parameter Real GV(
        final unit="m3/Pa.s",
        final min=0) = 1e-12 "Leitwert bei geschlossenem Ventil";
      Boolean offen(start=false);
      annotation (defaultComponentName="Ven",
        Icon(
          Rectangle(extent=[-80,40; 80,-40], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Line(points=[-40,40; -80,0; -40,-40],style(color=0)),
          Ellipse(extent=[-68,20; -28,-20],   style(color=0, fillColor=0)),
          Line(points=[-28,0; -8,0; 12,40; 52,-40; 72,0; 80,0], style(color=0,
                rgbcolor={0,0,0}))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Ueberdruckventil</font> verh&auml;lt sich in im Zustand <strong>offen</strong> wie ein turbulenter Str&ouml;mungswiderstand. Sobald die angelegte Druckdifferenz unter <strong>pschliess</strong> sinkt, wird der Volumenstrom unterbrochen. Das Ventil &ouml;ffnet erst wieder, wenn die Druckdifferenz &uuml;ber den Wert <strong>poeff</strong> steigt.</p>
<p>Die Durchlassrichtung zeigt von <strong>h_p</strong> nach <strong>h_n</strong>.</p>
</html>"));
    equation 
      offen = dp > pkrit;
      pkrit = if offen then pschliess else poeff;
      IV = if offen then (dp/kV)^0.5 else GV*dp;
      P = der(Wdiss);
    end Ueberdruckventil;
    
    model DiodenVentil "analog zur elektrischen Diode" 
      extends Konnektoren.VolStromglied;
      parameter Real RVein(
        final unit="Pa.s/m3",
        final min=0) = 1 "Widerstand in Durchlassrichtung";
      parameter Real GVaus(
        final unit="m3/Pa.s",
        final min=0) = 1e-12 "Leitwert in Sperrrichtung";
      parameter SI.Pressure dpknie(final min=0) = 0 "Schwellenwert";
      Boolean aus(start=true) "Schalterstellung";
    protected 
      Real s "Hilfsvariable: gleich Strom bei ein, gleich Spannung bei aus";
      annotation (defaultComponentName="Ven_D",
        Icon(
          Text(
            extent=[-100,100; 100,40],
            string="%name",
            style(color=3, rgbcolor={0,0,255})),
          Rectangle(extent=[-80,40; 80,-40], style(color=3, rgbcolor={0,0,255})),
          Polygon(points=[0,0; -40,40; -40,-40; 0,0], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=3,
              rgbfillColor={0,0,255})),
          Line(points=[-80,0; 80,0], style(color=3, rgbcolor={0,0,255})),
          Rectangle(extent=[0,40; 20,-40], style(
              color=2,
              rgbcolor={0,255,0},
              pattern=0,
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">DiodenVentil</font> ist als idealer Schalter modelliert und arbeitet wie eine elektrische Diode. Um Singularit&auml;ten zu vermeiden wirkt in Durchlassrichtung ein kleiner Widerstand <strong>RVein</strong> und in Sperrrichtung ein kleiner Leitwert <strong>GVaus</strong>. Mit der Druckdifferenz <strong>dpknie</strong> kann der Ansprechwert verschoben werden.</p>
</html>"));
    equation 
      aus = s < 0;
      dp = s*(if aus then 1 else RVein) + dpknie;
      IV = s*(if aus then GVaus else 1) + GVaus*dpknie;
    end DiodenVentil;
    
    model Schaltventil "ideales Schaltventil" 
      extends Konnektoren.VolStromglied;
      parameter Real RVein(
        final unit="Pa.s/m3",
        final min=0) = 1 "Widerstand bei geschlossenem Schalter";
      parameter Real GVaus(
        final unit="m3/Pa.s",
        final min=0) = 1e-12 "Leitwert bei offenem Schalter";
    protected 
      Real h "Hilfsvariable";
      Boolean aus;
      annotation (defaultComponentName="Ven_S",
        Icon(
          Rectangle(extent=[-80,40; 80,-40], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Line(points=[-80,0; -20,0; 40,32], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Line(points=[80,0; 40,0], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Ellipse(extent=[-26,6; -16,-4], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Line(points=[0,80; 0,10], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Schaltventil</font> ist als idealer Schalter modelliert. Um Singularit&auml;ten zu vermeiden wirkt bei geschlossenem Schalter ein kleiner Widerstand <strong>RVein</strong> und bei offenem Schalter (<strong>aus</strong>) ein kleiner Leitwert <strong>GVaus</strong>.</p>
</html>"));
    public 
      Modelica.Blocks.Interfaces.BooleanInput Schalt 
        annotation (extent=[-10,80; 10,100], rotation=-90);
    equation 
      aus = Schalt;
      dp = h*(if aus then 1 else RVein);
      IV = h*(if aus then GVaus else 1);
    end Schaltventil;
    
    model Druck "Misst den Absolutdruck" 
      extends Modelica.Icons.RotationalSensor;
      Konnektoren.Kupplung_pos h_p annotation (extent=[-100,-10; -80,10]);
      annotation (defaultComponentName="M_p", Diagram,
        Icon(
          Line(points=[-80,0; -70,0], style(color=3, rgbcolor={0,0,255})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-48,-10; 52,-70],
            style(color=3, rgbcolor={0,0,255}),
            string="%name")),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Druck</font> gibt den Wert des absoluten Drucks am Signalausgang <strong>p_aus</strong> an.
</html>"));
      Modelica.Blocks.Interfaces.RealOutput p_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
    equation 
      h_p.IV = 0;
      h_p.p = p_aus;
    end Druck;
    
    model Volumenstrom "Misst durchfliessenden Volumenstrom" 
      extends Modelica.Icons.RotationalSensor;
      Konnektoren.Kupplung_pos h_p annotation (extent=[-100,-10; -80,10]);
      annotation (defaultComponentName="M_IV",Diagram,
        Icon(
          Line(points=[-80,0; -70,0], style(color=3, rgbcolor={0,0,255})),
          Line(points=[70,0; 80,0], style(color=3, rgbcolor={0,0,255})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-48,-10; 52,-70],
            style(color=3, rgbcolor={0,0,255}),
            string="%name")),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Volumenstrom</font> gibt die St&auml;rke des durchfliessenden Volumenstromes am Signalausgang <strong>IV_aus</strong> an. Die Stromst&auml;rke ist positiv, wenn das Volumen vom Eingang <strong>h_p</strong> zum Ausgang <strong>h_n</strong> fliesst.
</html>"));
      Modelica.Blocks.Interfaces.RealOutput IV_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
      Konnektoren.Kupplung_neg h_n annotation (extent=[80,-10; 100,10]);
    equation 
      h_p.p = h_n.p;
      h_p.IV + h_n.IV = 0;
      h_p.IV = IV_aus;
    end Volumenstrom;
    
    model Druckdifferenz "Misst die Druckdifferenz zwischen zwei Punkten" 
      extends Modelica.Icons.RotationalSensor;
      Konnektoren.Kupplung_pos h_p annotation (extent=[-100,-10; -80,10]);
      annotation (defaultComponentName="M_dp", Diagram,
        Icon(
          Line(points=[-80,0; -70,0], style(color=3, rgbcolor={0,0,255})),
          Line(points=[70,0; 80,0], style(color=3, rgbcolor={0,0,255})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-48,-10; 50,-70],
            style(color=3, rgbcolor={0,0,255}),
            string="%name")),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Druckdifferenz</font> gibt die Druckdifferenz am Signalausgang <strong>dp_aus</strong> an. Die Druckdifferenz ist positiv, wenn der Druck am Eingang <strong>h_p</strong> gr&ouml;sser als am Ausgang <strong>h_n</strong> ist.
</html>"));
      Modelica.Blocks.Interfaces.RealOutput dp_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
      Konnektoren.Kupplung_neg h_n annotation (extent=[80,-10; 100,10]);
    equation 
      h_p.IV = 0;
      h_n.IV = 0;
      h_p.p - h_n.p = dp_aus;
    end Druckdifferenz;
    
    annotation (Documentation(info="<html>
<h3>Volumen als bilanzierf&auml;hige Gr&ouml;sse</h3>
<p>Das <font color=\"#FF0000\">Eigenvolumen</font> einer Fl&uuml;ssigkeit bildet die mengenartige oder bilanzierf&auml;hige Gr&ouml;sse der Hydrodynamik, der <font color=\"#FF0000\">Druck</font> ist das zugeh&ouml;rige Potential.</p>
<p>In den Speicherelementen wird die <font color=\"#FF0000\">Volumenbilanz</font> gebildet. Widerst&auml;nde sind <font color=\"#FF0000\">Stromglieder</font>, die Energie dissipieren bzw. Entropie erzeugen. Die Tr&auml;gheit der Fl&uuml;ssigkeit wirkt induktiv. Das Kompressionsverhalten der Fl&uuml;ssigkeit kann mit Hilfe von Kapazit&auml;ten (Federspeicher) modelliert werden.</p>
<p>Die St&auml;rke des <font color=\"#FF0000\">zugeordneten Energiestromes</font> ist gleich Druck mal Volumenstromst&auml;rke. Der zugeordnete Energiestrom beschreibt den Energieaustausch eines Speichers. Die <font color=\"#FF0000\">Prozessleistung</font> (Druckdifferenz mal Volumenstromst&auml;rke) liefert den Energieumsatz &uuml;ber einem Stromglied. Setzt der Volumenstrom Energie <font color=\"#FF0000\">frei</font>, ist die Prozessleistung <font color=\"#FF0000\">positiv</font>.</p>
</html>"));
  end Hydrodynamik;
  
  package Elektrodynamik "Netzwerkmodelle" 
    
    model ElektroErde "Verbindung zur Umwelt" 
      parameter SI.Voltage Vamb = 0 "Potential der Umgebung";
      SI.Power IW "Staerke des Energiestromes an die Umwelt";
      SI.Energy Waus(start=0, fixed=true) "Energieaustausch mit der Umwelt";
      annotation (defaultComponentName="Erde", Diagram,
        Icon(
          Line(points=[0,80; 0,40], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Line(points=[-80,40; 80,40], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Line(points=[-60,20; 60,20], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Line(points=[-40,0; 40,0], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Text(
            extent=[-100,0; 100,-100],
            style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=1,
              rgbfillColor={255,0,0}),
            string="Vamb=%Vamb")),
        Documentation(info="<html>
Mit der <font color=\"#008800\">HydroErde</font> kann unbeschr&auml;nkt Volumen bei einem Druck von <strong>pamb</strong> = 1e5 Pa ausgetauscht werden. Der an die Umwelt abfliessende, zugeordnete Energiestrom sowie die mit der Umwelt ausgetauschte Energie werden ermittelt. Das Bezugsniveau f&uuml;r diese Energieberechnungen ist Vakuum.
</html>"));
      Konnektoren.Stift_neg e annotation (extent=[-10,80; 10,100]);
    equation 
      e.V = Vamb;
      IW = e.V*e.I;
      IW = der(Waus);
    end ElektroErde;
    
    model Kondensator "konstante Kapazitaet" 
      extends Konnektoren.Zweipol;
      parameter SI.Capacitance C = 1 "Kapazitaet";
      SI.Energy W(start=0, fixed=true) "Energie des Kondensators";
      annotation (defaultComponentName="C",
        Icon(
          Rectangle(extent=[-30,40; -10,-40], style(
              color=2,
              rgbcolor={0,255,0},
              pattern=0,
              fillColor=2,
              rgbfillColor={0,255,0},
              fillPattern=1)),
          Text(
            extent=[-100,100; 100,40],
            style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="%name"),
          Text(
            extent=[-100,-40; 100,-100],
            style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="C=%C"),
          Rectangle(extent=[10,40; 30,-40],   style(
              color=2,
              rgbcolor={0,255,0},
              pattern=0,
              fillColor=2,
              rgbfillColor={0,255,0},
              fillPattern=1)),
          Line(points=[-80,0; -30,0], style(color=2, rgbcolor={0,255,0})),
          Line(points=[30,0; 80,0], style(color=2, rgbcolor={0,255,0}))),
          Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Kondensator</font> modelliert das lineare Verhalten einer Kapazit&auml;t. Zudem wird die im elektrischen Feld gespeicherte Energie (kapazitive Energie) berechnet.</p>
</html>"));
    equation 
      I = C*der(U);
      P = der(W);
    end Kondensator;
    
    model Widerstand "Ohm'scher Widerstand" 
      extends Konnektoren.Zweipol;
      parameter SI.Resistance R = 1 "Widerstand";
      SI.Energy Wdiss(start=0, fixed=true) "Energie des Kondensators";
      annotation (defaultComponentName="R",
        Icon(
          Rectangle(extent=[-80,40; 80,-40], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Text(
            extent=[-100,100; 100,40],
            style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="%name"),
          Text(
            extent=[-100,-40; 100,-100],
            style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="R=%R")), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Widerstand</font> modelliert das lineare Verhalten eines Ohmschen Widerstandes. Die dissipierte Energie wird zus&auml;tzlich berechnet.</p>
</html>"));
    equation 
      U = R*I;
      P = der(Wdiss);
    end Widerstand;
    
    model Induktivitaet "Induktivitaet" 
      extends Konnektoren.Zweipol;
      parameter SI.Inductance L = 1 "Widerstand";
      SI.Energy W(start=0, fixed=true) "Energie des Kondensators";
      annotation (defaultComponentName="L",
        Icon(
          Rectangle(extent=[-80,40; 80,-40], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=2,
              rgbfillColor={0,255,0})),
          Text(
            extent=[-100,100; 100,40],
            style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="%name"),
          Text(
            extent=[-98,-40; 100,-100],
            style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="L=%L")), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Induktivitaet</font> modelliert das Verhalten einer idealen Spule. Zudem wird die im Magnetfeld gespeicherte Energie (induktive Energie) berechnet.</p>
</html>"));
    equation 
      U = L*der(I);
      P = der(W);
    end Induktivitaet;
    
    model Diode "Ohm'scher Widerstand" 
      extends Konnektoren.Zweipol;
      parameter SI.Resistance Rein(final min=0) = 1.e-5 
        "Diodenwiderstand in Durchlassrichtung";
      parameter SI.Conductance Gaus(final min=0) = 1.e-5 
        "Diodenleitwert in Sperrrichtung";
      parameter SI.Voltage Uknie(final min=0) = 0 "Schwellenwert der Spannung";
      Boolean aus(start=true) "Schalterstellung";
    protected 
      Real s "Hilfsvariable: gleich Strom bei ein, gleich Spannung bei aus";
      annotation (defaultComponentName="Dio",
        Icon(
          Text(
            extent=[-100,100; 100,40],
            style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="%name"),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Polygon(points=[0,0; -40,40; -40,-40; 0,0], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=2,
              rgbfillColor={0,255,0})),
          Line(points=[-80,0; 80,0], style(color=2, rgbcolor={0,255,0})),
          Rectangle(extent=[0,40; 20,-40],    style(
              color=2,
              rgbcolor={0,255,0},
              pattern=0,
              fillColor=2,
              rgbfillColor={0,255,0},
              fillPattern=1))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Diode</font> ist als idealer Schalter modelliert. Um Singularit&auml;ten zu vermeiden wirkt in Durchlassrichtung ein kleiner Widerstand <strong>Rein</strong> und in Sperrrichtung ein kleiner Leitwert <strong>Gaus</strong>. Mit der Spannung <strong>Uknie</strong> kann der Ansprechwert verschoben werden.</p>
</html>
</html>"));
    equation 
      aus = s < 0;
      U = s*(if aus then 1 else Rein) + Uknie;
      I = s*(if aus then Gaus else 1) + Gaus*Uknie;
    end Diode;
    
    model Kugel "Speicherverhalten einer isoliert aufgehaengten Metallkugel" 
      parameter SI.Length r = 1 "Kugelradius";
    protected 
      parameter SI.Capacitance C = 4*Modelica.Constants.pi*Modelica.Constants.epsilon_0*r 
        "Kapazitaet der Kugel";
      SI.Charge Q "Ladung der Kugel";
      SI.Voltage V "Potential der Kugel";
      SI.Power IW "zugeordneter Energiestrom";
      SI.Energy W "elektrische Energie der Kugel";
    public 
      Konnektoren.Stift_pos p annotation (extent=[-10,-100; 10,-80]);
      annotation (Icon(Ellipse(extent=[-80,80; 80,-80], style(
              color=2,
              rgbcolor={0,255,0},
              gradient=3,
              fillColor=2,
              rgbfillColor={0,255,0}))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Kugel</font> modelliert das Speicherverhalten einer isoliert aufgeh&auml;ngten Kugel mit Radius <strong>r</strong>. Zudem wird die im elelektrischen Feld gespeicherte Energie (\"potentielle\" Energie) berechnet.</p>
</html>
"));
    equation 
       p.I = der(Q);
       p.V = V;
       V = Q/C;
       IW = V*p.I;
       IW = der(W);
    end Kugel;
    
  model Stromquelle "Eingangssignal steuert Strom" 
      extends Konnektoren.Zweipol;
      annotation (defaultComponentName="P_I",
        Icon(
          Rectangle(extent=[-80,40; 80,-40], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Text(
            extent=[-100,100; 100,40],
            style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="%name"),
          Line(points=[0,-80; 0,-40], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=2,
              rgbfillColor={0,255,0},
              fillPattern=1)),
          Polygon(points=[80,0; 40,30; 40,10; -80,10; -80,-10; 40,-10; 40,-30;
                80,0], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=2,
              rgbfillColor={0,255,0},
              fillPattern=1))), Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Stromquelle</font> f&ouml;rdert einen elektrischen Strom nach Vorgabe des Signaleingangs <strong>I_in</strong>. Der Strom wird begrenzt, sobald der Betrag der Leistung den Wert <strong>Pmax</strong> &uuml;bersteigt.</p>
<p>Die Stromst&auml;rke ist positiv, wenn die elektrische Ladung vom Eingang <strong>p</strong> zum Ausgang <strong>n</strong> fliesst. <font color=\"#FF0000\">Die Leistung <strong>P</strong> ist negativ, falls die Quelle den Strom gegen die Spannung f&ouml;rdert.</font></p>
</html>"));
      Modelica.Blocks.Interfaces.RealInput I_in 
        annotation (extent=[-10,-100; 10,-80], rotation=90);
  equation 
      I = I_in;
  end Stromquelle;
    
    model Spannungsquelle "Eingangssignal steuert Spannung" 
      extends Konnektoren.Zweipol;
      annotation (defaultComponentName="P_U",
        Icon(
          Rectangle(extent=[-80,40; 80,-40], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Text(
            extent=[-100,100; 100,40],
            style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="%name"),
          Line(points=[0,-80; 0,-40], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=2,
              rgbfillColor={0,255,0},
              fillPattern=1)),
          Line(points=[40,0; 40,-20; 80,0; 40,20; 40,0; -40,0; -40,20; -80,0;
                -40,-20; -40,0], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Spannungsquelle</font> erzeugt eine Spannung nach Vorgabe des Signaleingangs <strong>U_in</strong>. Der elektrische Strom wird nicht begrenzt.</p>
<p>Ein positiver Signaleingang <strong>U_in</strong> erzeugt eine <font color=\"#FF0000\">negative</font> Spannung (das Potential am Eingang <strong>p.V </strong>liegt dann tiefer als am Ausgang <strong>n.V</strong>). Die elektrische Stromst&auml;rke ist wie bei den passiven Elementen positiv, wenn das Volumen vom Eingang <strong>p</strong> zum Ausgang <strong>n</strong> fliesst. <font color=\"#FF0000\">Die Leistung <strong>P</strong> ist negativ, falls die Quelle Energie auf den elektrischen Strom &uuml;bertr&auml;gt</font>.</p>
</html>"));
      Modelica.Blocks.Interfaces.RealInput U_in 
        annotation (extent=[-10,-100; 10,-80], rotation=90);
    equation 
      U = -U_in;
    end Spannungsquelle;
    
    model Schalter "ideales Schaltventil" 
      extends Konnektoren.Zweipol;
      parameter SI.Resistance Rein(
        final min=0) = 1e-5 "Widerstand bei geschlossenem Schalter";
      parameter SI.Conductance Gaus(
        final min=0) = 1e-5 "Leitwert bei offenem Schalter";
    protected 
      Real h "Hilfsvariable";
      Boolean aus;
      annotation (defaultComponentName="S",
        Icon(
          Rectangle(extent=[-80,40; 80,-40], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Line(points=[-80,0; -20,0; 40,32], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Line(points=[80,0; 40,0], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Ellipse(extent=[-26,6; -16,-4], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Line(points=[0,80; 0,10], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Schalter</font> ist als idealer Schalter modelliert. Um Singularit&auml;ten zu vermeiden wirkt bei geschlossenem Schalter ein kleiner Widerstand <strong>Rein</strong> und bei offenem Schalter (<strong>aus</strong>) ein kleiner Leitwert <strong>Gaus</strong>.</p>
</html>"));
    public 
      Modelica.Blocks.Interfaces.BooleanInput Schalt 
        annotation (extent=[-10,80; 10,100], rotation=-90);
    equation 
      aus = Schalt;
      U = h*(if aus then 1 else Rein);
      I = h*(if aus then Gaus else 1);
    end Schalter;
    
    model WiderstandT "Ohm'scher Widerstand" 
      extends Konnektoren.Zweipol;
      parameter SI.Resistance R0 = 1 "Widerstand";
      parameter SI.Temperature T0 = 293 "Referenztemperatur";
      parameter Real alpha(
         final unit="1/K",
         final min=0) = 4.11e-3 "linearer Temperaturkoeffizient";
      parameter Real beta(
         final unit="1/K`2",
         final min=0) = 9.62e-7 "quadratischer Temperaturkoeffizient";
      SI.ThermalConductance PiS "Entropieproduktionsrate";
      SI.Temperature T "absolute Temperatur";
      SI.Resistance R "temperaturabhaengiger Widerstand";
      annotation (defaultComponentName="R_T",
        Icon(
          Rectangle(extent=[-80,40; 80,-40], style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=1,
              rgbfillColor={255,0,0},
              fillPattern=1)),
          Text(
            extent=[-100,100; 100,40],
            style(
              color=2,
              rgbcolor={0,255,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="%name"),
          Line(points=[0,-80; 0,-40], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=1,
              rgbfillColor={255,0,0},
              fillPattern=1))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">WiderstandT</font> modelliert den temperaturabh&auml;ngigen Widerstand.</p>
<p>Die Werte f&uuml;r den linearen <strong>alpha</strong> und den quadratischen <strong>beta</strong> Temperaturkoeffizienten sind materialabh&auml;ngig und den Tabellen zu entnehmen. Die hier gesetzten Werte gelten f&uuml;r Wolfram.</p>
<p>Die im Prozess produzierte Entropie wird &uuml;ber den Anschluss <strong>th_n</strong> abgef&uuml;hrt. <font color=\"#FF0000\">Der Anschluss <strong>th_n</strong> muss an ein thermisches Element (notfalls an ThermoErde) angeschlossen werden.</font></p>
</html>"));
      Konnektoren.Kontakt_neg th_n annotation (extent=[-10,-100; 10,-80]);
    equation 
      U = R*I;
      R = R0*(1 + alpha*(T-T0) + beta*(T-T0)^2);
      PiS = P/T;
      T = th_n.T;
      PiS = -th_n.IS;
    end WiderstandT;
    
    model Potential "Misst das elektrische Potential" 
      extends Modelica.Icons.RotationalSensor;
      annotation (defaultComponentName="M_V", Diagram,
        Icon(
          Line(points=[-80,0; -70,0], style(color=2, rgbcolor={0,255,0})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-48,-10; 52,-70],
            string="%name",
            style(color=2, rgbcolor={0,255,0}))),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Potential</font> gibt den Wert des Potentials am Signalausgang <strong>V_aus</strong> an.
</html>"));
      Modelica.Blocks.Interfaces.RealOutput V_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
      Konnektoren.Stift_pos p annotation (extent=[-100,-10; -80,10]);
    equation 
      p.I = 0;
      p.V = V_aus;
    end Potential;
    
    model Strom "Misst den durchliessenden Strom" 
      extends Modelica.Icons.RotationalSensor;
      annotation (defaultComponentName="M_I", Diagram,
        Icon(
          Line(points=[-80,0; -70,0], style(color=2, rgbcolor={0,255,0})),
          Line(points=[70,0; 80,0], style(color=2, rgbcolor={0,255,0})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-48,-10; 52,-70],
            string="%name",
            style(color=2, rgbcolor={0,255,0}))),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Strom</font> gibt die St&auml;rke des elektrischen Stromes am Signalausgang <strong>I_aus</strong> an. Die Stromst&auml;rke ist positiv, wenn die elektrische Ladung vom Eingang <strong>p</strong> zum Ausgang <strong>n</strong> fliesst.
</html>"));
      Modelica.Blocks.Interfaces.RealOutput I_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
      Konnektoren.Stift_pos p annotation (extent=[-100,-10; -80,10]);
      Konnektoren.Stift_neg n annotation (extent=[80,-10; 100,10]);
    equation 
      p.V = n.V;
      p.I + n.I = 0;
      p.I = I_aus;
    end Strom;
    
    model Spannung "Misst die Spannung zwischen zwei Punkten" 
      extends Modelica.Icons.RotationalSensor;
      annotation (defaultComponentName="M_U", Diagram,
        Icon(
          Line(points=[-80,0; -70,0], style(color=2, rgbcolor={0,255,0})),
          Line(points=[70,0; 80,0], style(color=2, rgbcolor={0,255,0})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-46,-10; 52,-70],
            string="%name",
            style(color=2, rgbcolor={0,255,0}))),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Spannung</font> gibt die Spannung am Signalausgang <strong>U_aus</strong> an. Die Spannung ist positiv, wenn das Potential am Eingang <strong>p</strong> gr&ouml;sser als am Ausgang <strong>n</strong> ist.
</html>"));
      Modelica.Blocks.Interfaces.RealOutput U_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
      Konnektoren.Stift_pos p annotation (extent=[-100,-10; -80,10]);
      Konnektoren.Stift_neg n annotation (extent=[80,-10; 100,10]);
    equation 
      p.I = 0;
      n.I = 0;
      p.V - n.V = U_aus;
    end Spannung;
    
    annotation (Documentation(info="<html>
<h3>Elektrische Ladung als bilanzierf&auml;hige Gr&ouml;sse</h3>
<p>Die <font color=\"#FF0000\">elektrische Ladung</font> bildet die mengenartige oder bilanzierf&auml;hige Gr&ouml;sse der Elektrodynamik, das <font color=\"#FF0000\">elektrische Potential</font> ist das zugeh&ouml;rige Potential.</p>
<p>Widerstand,Kapazit&auml;t und Induktivit&auml;t sind <font color=\"#FF0000\">Stromglieder</font>, die Energie dissipieren (Entropie erzeugen) oder Energie speichern. Elektrische Ladung wird nur im Element <font color=\"#008800\">Kugel</font> wirklich gespeichert.</p>
<p>Die St&auml;rke des <font color=\"#FF0000\">zugeordneten Energiestromes</font> ist gleich Potential mal Stromst&auml;rke. Weil der zugeordnete Energiestrom den Energieaustausch eines echten Speichers beschreibt, spielt dieser Begriff in der Elektrodynamik nur eine untergeordnete Rolle. Die <font color=\"#FF0000\">Prozessleistung</font> (Spannung mal Stromst&auml;rke) liefert den Energieumsatz &uuml;ber einem Stromglied. Setzt der elektrische Strom Energie <font color=\"#FF0000\">frei</font>, ist die Prozessleistung <font color=\"#FF0000\">positiv</font>.</p>
</html>"));
  end Elektrodynamik;
  
  package Translation "eindimensionale Translation" 
    model TransErde "unbeschraenkter Entropieaustausch mit der Umwelt" 
      parameter SI.Velocity vamb = 0 "Geschwindigkeit des Bezugssystems";
      SI.Power IW "Staerke des Energiestromes an die Umwelt";
      SI.Energy Waus(start=0, fixed=true) "Energieaustausch mit der Umwelt";
     annotation (defaultComponentName="Erde",
        Icon(
          Line(points=[0,80; 0,40],style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Line(points=[-80,40; 80,40],
                                     style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Line(points=[-60,20; 60,20],   style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Line(points=[-40,0; 40,0],     style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Text(
            extent=[-100,-20; 100,-100],
            string="vamb=%vamb",
            style(color=0, rgbcolor={0,0,0}))),
        Documentation(info="<html>
Mit <font color=\"#008800\">TransErde</font> kann unbeschr&auml;nkt Impuls bei einer Geschwindigkeit von <strong>vamb</strong> ausgetauscht werden. Der an das Bezugssystem abfliessende, zugeordnete Energiestrom sowie die mit dem Bezugssystem ausgetauschte Energie werden ermittelt. Das Bezugsniveau f&uuml;r diese Energieberechnungen ist ein zweites, hypotetisches Bezugssystem (absoluter Raum). Normalerweise setzt man die Geschwindigkeit des Bezugssystems gleich Null (<strong>vamb = 0</strong>). Damit sind auch der Energiestrom und die ausgetauschte Energie gleich Null.
</html>"),
        Diagram);
      Konnektoren.TFlansch_neg tr_e annotation (extent=[-10,80; 10,100]);
    equation 
      tr_e.v = vamb;
      IW = tr_e.v*tr_e.F;
      IW = der(Waus);
    end TransErde;
    
    model Masse 
      "beschreibt das Speicherverhalten der traegen und das quellenverhalten der schweren Masse" 
       parameter SI.Mass m = 1 "schwere und traege Masse";
       parameter SI.Acceleration g = 9.81 "Gravitationsfeldstaerke";
       parameter Real Beta(
         final unit="deg") = 0 
        "Winkel zwischen Horizontalen und gewaehlter Bewegungsrichtung in Grad";
       parameter SI.Velocity va = 0 
        "Anfangsgeschwindigkeit des Massenmittelpunkts";
       SI.Momentum p(start=pa, fixed=true) "Impulsinhalt";
       SI.Velocity v "Geschwindigkeit des Massenmittelpunkts";
       SI.Acceleration a "Beschleunigung des Massenmittelpunkts";
       SI.Power IW "zugeordneter Energiestrom";
       SI.Energy Wkin(start=Wkina, fixed=true) "kinetische Energie";
    protected 
       parameter SI.Momentum pa = m*va "Anfangsimpuls";
       parameter SI.Energy Wkina = 0.5*va*pa "Anfangsenergie";
       parameter SI.Acceleration gt = -g*sin(Beta*Modelica.Constants.pi/180.0) 
        "Wirksame Komponente der Gravitationsfeldstaerke";
      annotation (defaultComponentName="m",
        Icon(Rectangle(extent=[-80,80; 80,0], style(
              color=0,
              rgbcolor={0,0,0},
              gradient=3,
              fillColor=0,
              rgbfillColor={0,0,0})), Text(
            extent=[-100,0; 100,-100],
            style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=7),
            string="m=%m")),   DymolaStoredErrors,
        Diagram,
        Documentation(info="<html>
<p>Im Element <font color=\"#008800\">Masse</font> wird die <font color=\"#FF0000\">Impulsbilanz</font> (Zufluss und Quellenterm <strong>mg</strong> gleich &Auml;nderungsrate des Inhalts) gebildet. Die Geschwindigkeit des Massenmittelpunktes ist gleich Impuls durch Masse. Zur Information des Benutzers und ohne Bedeutung f&uuml;r die Dynamik werden die Beschleunigung <strong>a</strong> und die kinetische Energie <strong>Wkin</strong> berechnet.</p>
<p><font color=\"#FF0000\">Vorzeichenregel:</font> Die positive Richtung zeigt nach rechts. Folglich enth&auml;lt ein sich nach rechts bewegender K&ouml;rper einen Impuls&uuml;berschuss. Die Bezugsrichtung kann mit <strong>Beta</strong> im Gegenuhrzeigersinn gedreht werden. Bei <strong>Beta = 90&deg;</strong> zeigt die Bezugsrichtung nach oben. Dann bildet das Gravitationsfeld zusammen mit der Masse eine Impulssenke. Bei <strong>Beta = 270&deg;</strong> wird <strong>m*g</strong> zu einer Impulsquelle.</p>
</html>"));
    public 
      Konnektoren.TFlansch_pos tr_p 
                                  annotation (extent=[-12,80; 10,100]);
    equation 
       tr_p.F + m*gt = der(p);
       tr_p.v = v;
       v = p/m;
       a = der(v);
       IW = tr_p.v*tr_p.F + v*m*gt;
       IW = der(Wkin);
    end Masse;
    
    model LinDaempfer "Linearer Daempfer" 
      extends Konnektoren.Verformbar;
      parameter Real k(
        final unit="(N.s)/m",
        final min=0) = 1 "Daempfungskonstante";
      SI.Energy Wdiss(start=0, fixed=true) "dissipierte Energie";
      annotation (defaultComponentName="Daem",
        Icon(Text(
            extent=[-100,100; 100,40],
            style(
              color=0,
              rgbcolor={0,0,0},
              fillPattern=7),
            string="%name"), Text(
            extent=[-100,-40; 100,-100],
            style(
              color=0,
              rgbcolor={0,0,0},
              fillPattern=7),
            string="k=%k"),
          Rectangle(extent=[-80,40; 80,-40], style(color=0, rgbcolor={0,0,0})),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Rectangle(extent=[-20,40; 20,-40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Rectangle(extent=[-80,14; -20,-14], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1))),
                             Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">LinDaempfer</font> modelliert das Verhalten einer viskosen Grenzschicht oder eines D&auml;mpfers mit linearem Verhalten. Die dissipierte Energie wird zus&auml;tzlich berechnet.</p>
</html>"));
    equation 
      F = k*dv;
      P = der(Wdiss);
    end LinDaempfer;
    
    model LinFeder "Linearer Feder" 
      extends Konnektoren.Verformbar;
      parameter Real D(
        final unit="N/m",
        final min=0) = 1 "Federkonstante";
      SI.Energy W(start=0.5*D*dxa^2, fixed=true) "Federenergie";
    annotation (defaultComponentName="Fed",
      Icon(Text(
            extent=[-100,100; 100,40],
            style(
              color=0,
              rgbcolor={0,0,0},
              fillPattern=7),
            string="%name"), Text(
            extent=[-100,-40; 100,-100],
            style(
              color=0,
              rgbcolor={0,0,0},
              fillPattern=7),
            string="D=%D"),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Line(points=[-80,0; -60,0; -40,-40; -20,40; 0,-40; 20,40; 40,-40; 60,
                0; 80,0], style(
              color=0,
              rgbcolor={0,0,0},
              fillPattern=1))),
                             Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">LinFeder</font> modelliert das Verhalten einer idealen Feder. Zudem wird die elastisch gespeicherte Energie (Teil der inneren Energie der Feder) aufintegriert.</p>
</html>"));
    equation 
      F = D*dx;
      P = der(W);
    end LinFeder;
    
    model Reibung 
      "Grenzflaeche mit Gleit- oder Haftreibung sowie viskoser Reibung" 
      extends Konnektoren.Verformbar;
      parameter SI.Force F_Coul=1 "Coulombkraft";
      parameter SI.Force F_Stri=1 
        "Stribeckkraft, Kraftzunahme kurz vor Stillstand";
      parameter Real k_Stri(
        final unit="s/m",
        final min=0) = 1 "Stribeck-Exponential-Koeffizient";
      parameter Real k_Visk(
        final unit="kg/s",
        final min=0) = 1 "Koeffizient der viskosen Reibung";
      parameter SI.Velocity v_klein=1e-3;
      SI.Acceleration da "Relativbeschleunigung zwischen tr_p und tr_n";
      SI.Force F0 "Gesamtkraft von Coulomb und Stribeck";
      SI.Force F0_max "ein Promille groesser als F0";
      SI.Energy Wdiss "vom Impulsstrom dissipierte Energie";
    protected 
      Real sa "Wegparameter fuer F(da)";
      constant Integer Vor=1;
      constant Integer Rueck=-1;
      constant Integer Still=0;
      Integer mode;
      Boolean startVor;
      Boolean startRueck;
      Boolean blockiert;
      annotation (defaultComponentName="Reib",
        Icon(
          Rectangle(extent=[-80,80; -20,-80], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Rectangle(extent=[20,80; 80,-80], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Rectangle(extent=[-30,80; 30,-80], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=6,
              rgbfillColor={255,255,0},
              fillPattern=1))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Reibung</font> modelliert das Verhalten einer Grenzschicht mit Gleit- oder Haftreibung sowie viskoser Reibung. Die dissipierte Energie wird zus&auml;tzlich berechnet.</p>
<p>Dieses Element ist der Modelica-Standardbibliothek entnommen und ist von Prof. Dr. Martin Otter entwickelt worden.</p>
<dd><a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a><br>
    Deutsches Zentrum f&uuml;r Luft und Raumfahrt e.V. (DLR)<br>
    Institut f&uuml;r Robotik und Mechatronik<br>
    Postfach 11 16<br>
    D-82230 Wessling<br>
    Germany<br>
    email: <A HREF=\"mailto:Martin.Otter@dlr.de\">Martin.Otter@dlr.de</A><br></dd>
</html>"));
    equation 
      da = der(dv);
      F0 = (F_Coul + F_Stri);
      F0_max = F0*1.001;
      startVor = pre(mode) == Still and (sa > F0_max or pre(startVor) and sa >
        F0) or pre(mode) == Rueck and dv > v_klein or initial() and (dv
         > 0);
      startRueck = pre(mode) == Still and (sa < -F0_max or pre(startRueck) and 
        sa < -F0) or pre(mode) == Vor and dv < -v_klein or initial() and (
        dv < 0);
      blockiert = not (pre(mode) == Vor or startVor or pre(mode) == Rueck or 
        startRueck);
      mode = (if (pre(mode) == Vor or startVor) and dv > 0 then Vor else if 
        (pre(mode) == Rueck or startRueck) and dv < 0 then Rueck else Still);
      da = if blockiert then 0 else if startVor then sa - F0 else if 
        startRueck then sa + F0 else if pre(mode) == Vor then sa - F0 else sa
         + F0;
      F = if blockiert then sa else (if startVor then k_Visk*dv + F0 else 
        if startRueck then k_Visk*dv - F0 else if pre(mode) == Vor then 
        k_Visk*dv + F_Coul + F_Stri*exp(-k_Stri*abs(dv)) else k_Visk*
        dv - F_Coul - F_Stri*exp(-k_Stri*abs(dv)));
       P = der(Wdiss);
    end Reibung;
    
    model Elastomer "Elastomerfeder mit fuenf Parameter" 
      extends Konnektoren.Verformbar;
       parameter Real D(
        final unit="N/m",
        final min=0) = 1 "Federkonstante";
      parameter Real Dv(
        final unit="N/m",
        final min=0) = 1 "Federkonstante beim Daempfer";
      parameter Real k(
        final unit="Ns/m",
        final min=0) = 0.01 "Daempferkonstante";
      parameter SI.Length x2=0.002 
        "relative Auslenkung um die Kraft FCoul aufzubauen";
      parameter Real FCoulmax = 1 "maximale Coulombkraft";
      SI.Distance dx1(start=dxa, fixed=true) "Verformung der Daempferfeder";
      SI.Distance dx2 "Verformung des Daempfers";
      SI.Velocity dv2 "Relativgeschwindigkeit des Daempfers";
      SI.Force FCoul "Coulombkraft";
      SI.Force FCouls "Referenzcoulombkraft im Umkehrpunkt";
      SI.Length dxs "Verformung beim Umkehrpunkt";
      SI.Energy W(start=0, fixed=true) "Energieaufnahme von Impulsstrom";
      Integer Vorzeichen;
    annotation (defaultComponentName="Elas",
      Icon(Text(
            extent=[-100,100; 100,40],
            style(
              color=0,
              rgbcolor={0,0,0},
              fillPattern=7),
            string="%name"), Text(
            extent=[-100,-40; 100,-100],
            style(
              color=0,
              rgbcolor={0,0,0},
              fillPattern=7),
            string="D=%D"),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=10))),
                             Diagram,
        Documentation(info="<html>
<p>Dieses D&auml;mpfer-Feder-Element besteht aus einer <font color=\"#FF0000\">linearen Feder</font> (Federkonstante <strong>D</strong>), einem <font color=\"#FF0000\">linearen viskoelastischen D&auml;mpfer</font> (Federkonstante <strong>Dv</strong> und D&auml;mpferkonstante <strong>k</strong> ) und einer <font color=\"#FF0000\">gegl&auml;tteten Coulombkraft</font>, die mit zwei Parameter (maximale Kraft <strong>FRmax</strong> und Auslenkungskonstante <strong>x2</strong> ) beschrieben werden kann. Bei jedem Umkehrpunkt werden Ort und Coulombkraft festgehalten (Referenz). Die Coulombkraft ver&auml;ndert sich dann mit der Distanz zu diesem Ort.</p>
<p>Modell und Parameter von <strong>Prof. Dr. Mats Berg</strong>, Department of Aeronautical and Vehicle Engineering, 
Division of Railway Technology, Royal Institute of Technology, SE-100 44 Stockholm, Sweden</p>
<strong>Berg, M:</strong> A Non-Linear Rubber Spring Model for Rail Vehicle Dynamics Analysis. Vehicle System Dynamics, Swets&Zeitlinger Publishers, 30 (1998), pp 197 - 212.
</html>"));
    equation 
      dx = dx1 + dx2;
      dv2 = der(dx2);
      k*dv2 = Dv*dx1;
      Vorzeichen = sign(dv);
      F = D*dx + Dv*dx1 + FCoul;
      FCoul = FCouls + (dx - dxs)*(FCoulmax - Vorzeichen*FCouls)/(x2*(1 - Vorzeichen*
        FCouls/FCoulmax) + Vorzeichen*(dx - dxs));
      when change(Vorzeichen) then
        dxs = pre(dx);
        FCouls = pre(FCoul);
      end when;
      der(W) = P;
    end Elastomer;
    
  model Faden "Faden" 
      extends Konnektoren.Verformbar;
      parameter SI.Force F0 = 100 "Hoechstzugkraft";
      parameter Real Epsilon= 0.05 "Dehnung";
      parameter Real k(
        final unit="(N.s)/m",
        final min=0) = 20 "Daempfungskonstante";
      SI.Energy W "Fadenergie";
    protected 
      parameter Real D(
        final unit="N/m",
        final min=0) = F0/(Epsilon*L) "Federkonstante";
      parameter Real kbruch(
        final unit="(N.s)/m",
        final min=0) = 1e-6 "Daempfungskonstante bei losem Faden";
      Boolean bruch;
    annotation (defaultComponentName="Fad",
      Icon(Text(
            extent=[-100,100; 100,40],
            style(
              color=0,
              rgbcolor={0,0,0},
              fillPattern=7),
            string="%name"), Text(
            extent=[-100,-40; 100,-100],
            style(
              color=0,
              rgbcolor={0,0,0},
              fillPattern=7),
            string="F0=%F0"),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Line(points=[-80,0; 80,0], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=6,
              rgbfillColor={255,255,0},
              fillPattern=1)),
          Line(points=[-20,40; 0,22; -20,0; 20,-40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=6,
              rgbfillColor={255,255,0},
              fillPattern=1))),
                             Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Faden</font> modelliert das Verhalten eines Fadens mittels linearer Feder und parallel geschaltetem D&auml;mpfer. Bei Druck oder nach erreichen der Reisskraft <strong>F0</strong> wirkt nur noch eine kleine D&auml;mpfung <strong>kbruch</strong>. Die vom Faden aufgenommene Energie wird extra aufintegriert.</p>
<p>Dieses Modell kann in Bezug auf Reibverhalten und Stabilit&auml;t noch verbessert werden.</p>
</html>"));
  equation 
      F = if bruch or dx>0 then kbruch*dv else D*dx + k*dv;
      when D*dx + k*dv < -F0 then
       bruch = true;
       end when;
      P = der(W);
  end Faden;
    
    model Pumpe_Ip "Eingangssignal steuert Impulsstrom" 
      extends Konnektoren.Verformbar;
      Modelica.Blocks.Interfaces.RealInput F_in 
        annotation (extent=[-10,-100; 10,-80],
                                             rotation=-270);
      annotation (defaultComponentName="P_Ip", Diagram,
        Icon(
          Line(points=[0,-80; 0,-40], style(color=3, rgbcolor={0,0,255})),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
            Polygon(points=[80,0; 40,30; 40,10; -80,10; -80,-10; 40,-10; 40,-30;
                80,0], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Text(
            extent=[-100,100; 100,40],
            string="%name",
            style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1))),
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Pumpe_Ip</font> f&ouml;rdert einen Impulsstrom nach Vorgabe des Signaleingangs <strong>F_in</strong>. Der Impulsstrom (Kraft) wird begrenzt, sobald der Betrag der Leistung den Wert <strong>Pmax</strong> &uuml;bersteigt.</p>
<p>Die Impulsstromst&auml;rke (Kraft) ist positiv, wenn der Impuls vom Eingang <strong>tr_p</strong> zum Ausgang <strong>tr_n</strong> fliesst. <font color=\"#FF0000\">Die Leistung <strong>P</strong> ist negativ, falls die Pumpe den Impuls von einem K&ouml;rper mit kleiner zu einem K&ouml;rper mit grosser Geschwindigkeit f&ouml;rdert</font> (gross und klein beziehen sich auf die rellen Zahlen und nicht auf deren Betr&auml;ge).</p>
</html>"));
    equation 
      F = F_in;
    end Pumpe_Ip;
    
    model Pumpe_dv "Eingangssignal gibt Geschwindigkeit vor" 
      extends Konnektoren.Verformbar;
      Modelica.Blocks.Interfaces.RealInput dv_in 
        annotation (extent=[-10,-80; 10,-100], rotation=-90);
      annotation (defaultComponentName="P_dv",
        Icon(Line(points=[0,-40; 0,-80], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Line(points=[40,0; 40,-20; 80,0; 40,20; 40,0; -40,0; -40,20; -80,0;
                -40,-20; -40,0], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Text(
            extent=[-100,100; 100,40],
            string="%name",
            style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1))),        Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Pumpe_dv</font> erzeugt eine Geschwindigkeitsdifferenz nach Vorgabe des Signaleingangs <strong>dv_in</strong>. Der Impulsstrom (Kraft) wird nicht begrenzt.</p>
<p>Ein positiver Signaleingang <strong>dv_in</strong> erzeugt eine <font color=\"#FF0000\">negative</font> Geschwindigkeitsdifferenz (die Geschwindigkeit am Eingang <strong>tr_p.v</strong> liegt tiefer als am Ausgang <strong>tr_n.v</strong>, das Element <font color=\"#008800\">Pumpe_dv</font> verl&auml;ngert sich). Die Impulsstromst&auml;rke ist wie bei den passiven Elementen positiv, wenn der Impuls vom Eingang <strong>tr_p</strong> zum Ausgang <strong>tr_n</strong> fliesst. <font color=\"#FF0000\">Die Leistung <strong>P</strong> ist negativ, falls die Pumpe Energie auf den Impulsstrom &uuml;bertr&auml;gt</font>.</p>
</html>"));
    equation 
      dv = -dv_in;
    end Pumpe_dv;
    
    model LinDaempferT "Linearer Daempfer" 
      extends Konnektoren.Verformbar;
      parameter SI.Temperature T0 = 283 "Referenztemperatur";
      parameter Real Beta = 1.1e11 "Faktor im Exponent";
      parameter Real n = -4.2 "Exponent der Temperatur";
      parameter Real k0(
        final unit="(N.s)/m",
        final min=0) = 1 "Daempfungskonstante";
      Real k(
        final unit="(N.s)/m",
        final min=0) "Leitwert bezueglich Impulsstrom";
      SI.ThermalConductance PiS "Entropieproduktionsrate";
      SI.Temperature T "absolute Temperatur";
      Konnektoren.Kontakt_neg th_n annotation (extent=[-10,-60; 10,-40]);
      annotation (defaultComponentName="Daem_T",
        Icon(Text(
            extent=[-100,100; 100,40],
            style(
              color=0,
              rgbcolor={0,0,0},
              fillPattern=7),
            string="%name"),
          Rectangle(extent=[-80,40; 80,-40], style(color=0, rgbcolor={0,0,0})),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Rectangle(extent=[-20,40; 20,-40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Rectangle(extent=[-80,14; -20,-14], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Rectangle(extent=[20,40; 80,-40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=1,
              rgbfillColor={255,0,0}))),
                             Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">LinDaempferT</font> modelliert ein Reibelement mit linearem Impulsstrom-Geschwindigkeitsverhalten.</p>
<p>Der D&auml;mpfwert <strong>k</strong> (Leitwert bez&uuml;glich Impulsstrom) h&auml;ngt von der Temperatur ab</p>
<p><i>log(log(k/k0)) = n*log(T/T0)</i></p>
<p>Die im Prozess produzierte Entropie wird &uuml;ber den Anschluss <strong>th_n</strong> abgef&uuml;hrt. <font color=\"#FF0000\">Der Anschluss <strong>th_n</strong> muss an ein thermisches Element (notfalls an ThermoErde) angeschlossen werden.</font></p>
</html>"));
    equation 
      F = k*dv;
      k = k0*exp(Beta*(T^n-T0^n));
      PiS = P/T;
      T = th_n.T;
      PiS = -th_n.IS;
    end LinDaempferT;
    
    model ReibungT 
      "Grenzflaeche mit Gleit- oder Haftreibung sowie viskoser Reibung, Entropiebilanz" 
      extends Konnektoren.Verformbar;
      parameter SI.Force F_Coul=1 "Coulombkraft";
      parameter SI.Force F_Stri=1 "Stribeckkraft";
      parameter Real k_Stri(
        final unit="s/m",
        final min=0) = 1 "Stribeck-Exponential-Koeffizient";
      parameter Real k_Visk(
        final unit="kg/s",
        final min=0) = 1 "Koeffizient der viskosen Reibung";
      SI.Energy Wdiss "vom Impulsstrom dissipierte Energie";
      SI.ThermalConductance PiS "Entropieproduktionsrate";
      SI.Temperature T "absolute Temperatur";
    protected 
      Real h "Kraftvariable";
      Real r "Parametrisierungsvariable";
      constant Integer Vor=1;
      constant Integer Rueck=-1;
      constant Integer Still=0;
      Integer Mode;
      parameter Real kv=1e-3;
    annotation (defaultComponentName="Reib_T",
      Icon(
          Rectangle(extent=[-80,80; -30,-80], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Rectangle(extent=[32,80; 80,-80], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Rectangle(extent=[-30,80; 32,-80], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=1,
              rgbfillColor={255,0,0},
              fillPattern=1))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">ReibungT</font> modelliert das Verhalten einer Grenzschicht mit Gleit- oder Haftreibung sowie viskoser Reibung. <font color=\"#008800\">ReibungT</font> ist einfacher modelliert als <font color=\"#008800\">Reibung</font> und zeigt deshalb im Haftreibungsfall einen gr&ouml;sseren Schlupf. Die dissipierte Energie wird zus&auml;tzlich berechnet.</p>
<p>Die im Prozess produzierte Entropie wird &uuml;ber den Anschluss <strong>th_n</strong> abgef&uuml;hrt. <font color=\"#FF0000\">Der Anschluss <strong>th_n</strong> muss an ein thermisches Element (notfalls an ThermoErde) angeschlossen werden.</font></p>
</html>"));
    public 
      Konnektoren.Kontakt_neg th_n annotation (extent=[-10,-100; 10,-80]);
    equation 
      der(Wdiss) = P;
      Mode = if r > 1 then Vor else if r < -1 then Rueck else Still;
      dv = if Mode == Vor then r*(1 + kv) - 1 else if Mode == Rueck then r*(
        1 + kv) + 1 else kv*r;
      h = if Mode == Vor then 1 else if Mode == Rueck then -1 else r;
      F = h*(F_Coul + F_Stri*exp(-k_Stri*Mode*dv)) + k_Visk*dv;
      PiS = P/T;
      T = th_n.T;
      PiS = -th_n.IS;
    end ReibungT;
    
    model Huelse "Basishuelse mit Reibung, Zug und Druckanschlag" 
      extends Konnektoren.Verformbar;
      parameter SI.Length dx_druck = 1 "maximaler Druckhub";
      parameter SI.Length dx_zug = 1 "maximaler Zughub";
      parameter SI.Force Fvor = 2 "Reibkraft beim Zusammenfahren";
      parameter SI.Force Frueck = 1 "Reibkraft beim Zurueckfahren";
      parameter Real k(
        final unit="Ns/m",
        final min=0) = 0.01 "Leitwert fuer viskose Reibung";
      SI.Force F_Huels "Impulsstrom infolge Gleitreibung und Anschlag";
      SI.Energy W(start=0, fixed=true) "Energieaufnahme von Impulsstrom";
    protected 
      parameter Real D2(
        final unit="N/m",
        final min=0) = 1e9 "Federkonstante bei Block und beim Vorspannen";
      parameter SI.Force Fm=(Fvor - Frueck)/2 "mittlere Reibkraft";
      parameter SI.Force dFR=(Fvor + Frueck)/2 
        "Abweichung der Reibkrfte von der mittleren Reibkraft";
      parameter Real hg= 1e-3 
        "Hilfsgrsse zur Berechnung der statischen Hysterese";
      parameter SI.Length dL=dFR/D2 
        "Verformung beim Uebergang von Druck auf Zug";
      parameter Real dmax=Fm/dFR 
        "maximale relative Aenderung der Federkonstante";
      parameter Real kSpann(
        final unit="N/m",
        final min=0) = Fm/dL "Steigungsfaktor beim Umschalten";
      constant Integer BlockZ=-2;
      constant Integer Zug=-1;
      constant Integer Spann=0;
      constant Integer Druck=1;
      constant Integer BlockD=2;
      constant Integer Vor=1;
      constant Integer Still=0;
      constant Integer Rueck=-1;
      Integer mode_s "Verformung der Hulse";
      Integer mode_v "Bewegungszustand der Hulse";
      Real d "relative Aenderung der Federkonstante";
      Real sv "interner Parameter zur Beschreibung des d-x-Verhaltens";
    annotation (defaultComponentName="Huel",
      Icon(Rectangle(extent=[-80,60; 80,-60], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0})), Rectangle(extent=[-60,40; 60,-40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Huelse</font> modelliert das Verhalten einer F&uuml;hrung mit einfachem Gleitreibungsverhalten sowie zwei Anschl&auml;gen. Die dissipierte Energie wird zus&auml;tzlich berechnet.</p>
<p>Das Element <font color=\"#008800\">Huelse</font> wird parallel zu andern Stromgliedern wie <font color=\"#0000FF\">LinDaempfer</font> oder <font color=\"#0000FF\">LinDaempfer</font> geschaltet. <font color=\"#FF0000\">Der Wert f&uuml;r <strong>Frueck</strong> muss kleiner sein als f&uuml;r <strong>Fvor</strong></font>.</p>
</html>"));
    equation 
      mode_s = if dx < -(dx_zug + dL) then BlockZ else if dx < -
        dL then Zug else if dx < dL then Spann else if dx < (
        dx_druck + dL) then Druck else BlockD;
      mode_v = if sv > dmax then Vor else if sv < -dmax then Rueck else Still;
      d = if mode_v == Rueck then -dmax else if mode_v == Vor then dmax else sv;
      dv = if mode_v == Rueck then sv + (1 - hg)*dmax else if mode_v == Vor then 
              sv - (1 - hg)*dmax else hg*sv;
      F_Huels = if mode_s == BlockZ then D2*(1 - d)*(dx + dx_zug) else if 
        mode_s == Zug then -Fm + dFR*d/dmax else if mode_s == Spann then dFR*
        d/dmax + kSpann*dx else if mode_s == Druck then Fm + dFR*d/dmax else 
              D2*(1 + d)*(dx - dx_druck);
      F = F_Huels + k*dv;
      der(W) = P;
    end Huelse;
    
    model RelMasse 
      "beschreibt das Speicherverhalten der Masse bei hoher Geschwindigkeit" 
       parameter SI.Mass m0 = 1e-6 "Ruhemasse";
       parameter SI.Velocity va = 0 "Anfangsgeschwindigkeit";
       SI.Mass m(start=ma, fixed=true) "momentane Masse";
       SI.Momentum p(start=pa, fixed=true) "Impulsinhalt";
       SI.Velocity v "Geschwindigkeit";
       SI.Acceleration a "Beschleunigung";
       SI.Power IW "zugeordneter Energiestrom";
       SI.Energy Wkin "kinetische Energie";
       SI.Time Tau "Eigenzeit";
    protected 
       constant SI.Velocity c = Modelica.Constants.c;
       parameter SI.Mass ma = m0*(1-(va/c)^2)^(-0.5) "Masse am Anfang";
       parameter SI.Momentum pa = ma*va "Anfangsimpuls";
      annotation (defaultComponentName="m_rel",
        Icon(Rectangle(extent=[-80,80; 80,0], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255})),
                                      Text(
            extent=[-100,0; 100,-100],
            style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=7),
            string="m0=%m0"),
          Polygon(points=[-80,0; -80,20; 80,80; 80,0; -80,0], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1))),DymolaStoredErrors,
        Diagram,
        Documentation(info="<html>
<p>Im Element <font color=\"#008800\">RelMasse</font> wird die <font color=\"#FF0000\">Impulsbilanz</font> (Zufluss gleich &Auml;nderungsrate des Inhalts) und die <font color=\"#FF0000\">Masse-Energie-Bilanz</font> (zufliessender Energiestrom durch Lichtgeschwindigkeit im Quadrat gleich &Auml;nderungsrate der Masse) gebildet. Die Geschwindigkeit des Massenmittelpunktes ist gleich Impuls durch Masse. Zur Information des Benutzers und ohne Bedeutung f&uuml;r die Dynamik werden die Beschleunigung <strong>a</strong> und die kinetische Energie <strong>Wkin</strong> berechnet.</p> 
<p>Die kinetische Energie kann nicht mehr isoliert von der Gesamtenergie (totalen Masse) berechnet werden. Der Beschleunigung kommt keine direkte Bedeutung mehr zu. Im mitbewegten System entspricht diese Gr&ouml;sse nicht mehr der Feldst&auml;rke des Tr&auml;gheitsfeldes.</p>
<p>Die <font color=\"#FF0000\">Eigenzeit <strong>Tau</strong></font>, die Zeit die eine mitgef&uuml;hrte Uhr messen w&uuml;rde, wird zus&auml;tzlich berechnet.</p>
</html>"));
    public 
      Konnektoren.TFlansch_pos tr_p 
                                  annotation (extent=[-12,80; 10,100]);
    equation 
       tr_p.F = der(p);
       tr_p.v = v;
       v = p/m;
       IW = v*tr_p.F;
       IW/c^2 = der(m);
    /* Die nachfolgenden Gleichungen haben keinen Einfluss auf die Dynamik des Systems.
   Auf die Begriffe kinetische Energie und Beschleunigung koennte man verzichten.*/
       Wkin = (m - m0)*c^2;
       a = der(v);
       (1-(v/c)^2)^0.5 = der(Tau);
    end RelMasse;
    
    model Rakete "Beschreibt das Antriebsmodul einer Rakete" 
      parameter SI.Time ta = 0 "Start des Triebwerkes";
      parameter SI.Length h0 = 400 "Starthoehe ueber Meer";
      parameter SI.Mass m0 = 2000 "Taramasse";
      parameter SI.Mass mB = 8000 "Brennstoffmasse";
      parameter SI.MassFlowRate Im0 = 40 "Betrag Massenstromstaerke";
      parameter SI.Velocity c = 4000 "Ausstroemgeschwindigkeit";
      parameter SI.Acceleration g0 = 9.81 "Gravitationsfeldstaerke beim Start";
      parameter SI.Length r0 = 6.37e6 "Erdradius";
      SI.Mass m(start=m0+mB, fixed=true) "Masse";
      SI.MassFlowRate Im "Massenstromstaerke bezueglich Rakete";
      SI.Length h(start=h0, fixed=true) "Hoehe ueber Meer";
      SI.Velocity v "Geschwindigkeit";
      SI.Acceleration a "Beschleunigung";
      SI.Acceleration g "Gravitationsfeldstaerke";
      Real gStrich "Belastung in gErde";
      SI.Momentum p "Impuls";
      Konnektoren.TFlansch_pos tr_p annotation (extent=[-10,80; 10,100]);
      annotation (defaultComponentName="Rak",
        Icon(Rectangle(extent=[-80,80; 80,0], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)), Polygon(points=[-20,0; -80,-80; 80,-80; 20,0; -20,
                0], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=6,
              rgbfillColor={255,255,0},
              fillPattern=1))), Documentation(info="<html>
<p>Im Element <font color=\"#008800\">Rakete</font> wird die <font color=\"#FF0000\">Impulsbilanz</font> (leitungsartiger Zufluss, Quellenst&auml;rke und konvektiver Strom gleich &Auml;nderungsrate des Inhalts) sowie die <font color=\"#FF0000\">Massebilanz</font> (Zufluss gleich &Auml;nderungsrate) gebildet. Die Geschwindigkeit des Massenmittelpunktes ist gleich Impuls durch Masse. Das Gravitationsfeld nimmt entsprechend dem <strong>1/r^2-Gesetz</strong> ab.</p> 
<p>Die im mitbewegten System erfahrbare St&auml;rke des Gravitationsfeldes <strong>gStrich</strong> wird berechnet und im Verh&auml;ltnis zur Normfeldst&auml;rke (9.81 N/kg) angegeben.</p>
</html>"));
    equation 
      tr_p.F - g*m + Im*(v-c) = der(p);
      tr_p.v = v;
      v = p/m;
      Im = if time>ta and time<ta+mB/Im0 then -Im0 else 0;
      Im = der(m);
      v = der(h);
      g = g0*(r0+h0)^2/(r0+h)^2;
      a = der(v);
      gStrich = (a + g)/9.81;
    algorithm 
      when h < h0-10 then
        terminate("Die Rakete ist aufgeschlagen");
      end when;
    end Rakete;
    
    model Luftwiderstand "Luftwiderstand eines Koerpers" 
      extends Konnektoren.Verformbar;
      SI.Energy Wdiss(start=0, fixed=true) "dissipierte Energie";
    public 
      Modelica.Blocks.Interfaces.RealInput Rho_in 
        annotation (extent=[-70,100; -50,80], rotation=90);
      Modelica.Blocks.Interfaces.RealInput cWA_in 
        annotation (extent=[50,100; 70,80], rotation=90);
      annotation (defaultComponentName="Wid",
        Icon(
          Rectangle(extent=[-80,80; 80,-80], style(
              color=7,
              rgbcolor={255,255,255},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Text(
            extent=[-98,80; -38,40],
            style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="Rho"),
          Text(
            extent=[14,80; 100,40],
            style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="cWA"),
          Line(points=[82,20; 60,40; 20,50; 0,50; -20,40; -30,20; -20,4; 0,0;
                12,20; 0,40; -20,28; -20,20; -10,20], style(color=0, rgbcolor={
                  0,0,0})),
          Line(points=[-80,-20; -60,-40; -20,-50; 0,-50; 20,-40; 32,-20; 20,-4;
                0,0; -12,-20; 0,-40; 20,-30; 20,-20; 10,-20], style(color=0,
                rgbcolor={0,0,0}))),
                           Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Luftwiderstand</font> modelliert die Reibungskraft auf einen turbulent umstr&ouml;mten K&ouml;rper. Die dissipierte Energie wird zus&auml;tzlich berechnet.</p>
<p><font color=\"#FF0000\">Die Dichte der Luft <strong>Rho</strong> und die Gr&ouml;sse Widerstandsbeiwert mal Querschnittfl&auml;che <strong>cWA</strong> m&uuml;ssen &uuml;ber die Signaleing&auml;nge (<strong>Rho_in</strong> und <strong>cW_in</strong>) gesetzt werden<font>.</p>
</html>"));
    equation 
      F = 0.5*cWA_in*Rho_in*dv*abs(dv);
      P = der(Wdiss);
    end Luftwiderstand;
    
    model Atmosphaere "Dichte in Funktion der Hoehe" 
      parameter SI.Density Rho0 = 1.29 "Dichte am Boden";
      parameter SI.Pressure p0 = 1.013e5 "Druck am Boden";
    protected 
      parameter SI.Length h0 = p0/(Rho0*9.81) "Referenzhoehe";
      Boolean atm "wahr bis zur Grenze der Atmosphaere";
    public 
      Modelica.Blocks.Interfaces.RealInput h_in 
        annotation (extent=[-100,-10; -80,10]);
      Modelica.Blocks.Interfaces.RealOutput Rho_aus 
        annotation (extent=[80,-10; 100,10]);
      annotation (defaultComponentName="Atm", Diagram,
        Icon(Rectangle(extent=[-80,80; 80,-80], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)), Text(
            extent=[-80,80; 80,-80],
            style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=10,
              rgbfillColor={135,135,135},
              fillPattern=1),
            string="isentrope Atmosphaere")),
        Documentation(info="<html>
<p>Die Funktion <font color=\"#008800\">Atmosph&auml;re</font> ordnet der H&ouml;he eine Dichte zu.</p>
<p>Im Gleichgewicht ist die Atmosph&auml;re <font color=\"#FF0000\">isentrop</font> und nicht etwa isotherm. Folglich l&auml;sst sich die Dichte der trockenen Luft in Abh&auml;ngigkeit der H&ouml;he mit Hilfe der isentropen Zustandsgleichung berechnen</p>
<p><i>dp = - Rho*g*dz</i></p>
<p>mit <i>p/p0 = (Rho/Rho0)^Kappa</i></p>
<p>folg <i>Kappa*p0*Rho^(Kappa-1)*dRho/Rho0^Kappa = - Rho*g*dz</i></p>
<p>Surch Separation und Integration gewinnt man die hier implementierte Gleichung.</p>
</html>"));
    equation 
      atm = (h_in) < (3.499*h0);
      Rho_aus = if atm then Rho0*(1-(2/7)*(h_in/h0))^2.5 else 0;
    end Atmosphaere;
    
    model Geschwindigkeit "Misst die Geschwindigkeit" 
      extends Modelica.Icons.RotationalSensor;
      annotation (defaultComponentName="M_v", Diagram,
        Icon(
          Line(points=[-80,0; -70,0], style(color=0, rgbcolor={0,0,0})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-50,-10; 50,-70],
            string="%name",
            style(color=0, rgbcolor={0,0,0}))),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Geschwindigkeit</font> gibt den Wert der absoluten Geschwindigkeit am Signalausgang <strong>v_aus</strong> an.
</html>"));
      Modelica.Blocks.Interfaces.RealOutput v_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
      Konnektoren.TFlansch_pos tr_p annotation (extent=[-100,-10; -80,10]);
    equation 
      tr_p.F = 0;
      tr_p.v = v_aus;
    end Geschwindigkeit;
    
    model Kraft "Misst die Staerke des durchfliessenden Impulsstromes" 
      extends Modelica.Icons.RotationalSensor;
      annotation (defaultComponentName="M_F", Diagram,
        Icon(
          Line(points=[-80,0; -70,0], style(color=0, rgbcolor={0,0,0})),
          Line(points=[70,0; 80,0], style(color=0, rgbcolor={0,0,0})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-50,-10; 50,-70],
            string="%name",
            style(color=0, rgbcolor={0,0,0}))),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Kraft</font> gibt die St&auml;rke des durchfliessenden Impulsstromes am Signalausgang <strong>F_aus</strong> an. Die Stromst&auml;rke ist positiv, wenn der Impuls vom Eingang <strong>tr_p</strong> zum Ausgang <strong>tr_n</strong> fliesst.
</html>"));
      Modelica.Blocks.Interfaces.RealOutput F_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
      Konnektoren.TFlansch_pos tr_p annotation (extent=[-100,-10; -80,10]);
      Konnektoren.TFlansch_neg tr_n annotation (extent=[80,-10; 100,10]);
    equation 
      tr_p.v = tr_n.v;
      tr_p.F + tr_n.F = 0;
      tr_p.F = F_aus;
    end Kraft;
    
    model Delta_v "Misst die Geschwindigkeitsdifferenz" 
      extends Modelica.Icons.RotationalSensor;
      annotation (defaultComponentName="M_dv", Diagram, Icon(
          Line(points=[-80,0; -70,0], style(color=0, rgbcolor={0,0,0})),
          Line(points=[70,0; 80,0], style(color=0, rgbcolor={0,0,0})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-48,-10; 50,-70],
            string="%name",
            style(color=0, rgbcolor={0,0,0}))),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Delta_v</font> gibt die Geschwindigkeitsdifferenz am Signalausgang <strong>dv_aus</strong> an. Die Geschwindigkeitsdifferenz ist positiv, wenn die Geschwindigkeit am Eingang <strong>tr_p</strong> gr&ouml;sser als am Ausgang <strong>tr_n</strong> ist.
</html>"));
      Modelica.Blocks.Interfaces.RealOutput dv_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
      Konnektoren.TFlansch_pos tr_p annotation (extent=[-100,-10; -80,10]);
      Konnektoren.TFlansch_neg tr_n annotation (extent=[80,-10; 100,10]);
    equation 
      tr_p.F = 0;
      tr_n.F = 0;
      tr_p.v - tr_n.v = dv_aus;
    end Delta_v;
    
    model Strecke "Misst die Strecke zwischen zwei Punkten" 
      extends Modelica.Icons.RotationalSensor;
      parameter SI.Length sa = 0 "Anfangsstrecke";
      SI.Velocity dv "Geschwindigkeitsdifferenz";
      SI.Length s(start=sa, fixed=true) "Strecke";
      annotation (defaultComponentName="M_s", Diagram,
        Icon(
          Line(points=[-80,0; -70,0], style(color=0, rgbcolor={0,0,0})),
          Line(points=[70,0; 80,0], style(color=0, rgbcolor={0,0,0})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-48,-10; 50,-70],
            string="%name",
            style(color=0, rgbcolor={0,0,0}))),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Strecke</font> gibt die Distanz der beiden Bezugspunkte am Signalausgang <strong>s_aus</strong> an. Die Strecke ist positiv, wenn sich der Ausgang <strong>tr_n</strong> vom Eingang <strong>tr_p</strong> in positive Richtung entfernt hat, wenn die Strecke l&auml;nger geworden ist. <font color=\"#FF0000\">Das Vorzeichen der Strecke verh&auml;lt sich umgekehrt wie das Vorzeichen der Geschwindigkeitsdifferenz</font>.
</html>"));
      Modelica.Blocks.Interfaces.RealOutput s_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
      Konnektoren.TFlansch_pos tr_p annotation (extent=[-100,-10; -80,10]);
      Konnektoren.TFlansch_neg tr_n annotation (extent=[80,-10; 100,10]);
    equation 
      tr_p.F = 0;
      tr_n.F = 0;
      dv = tr_p.v - tr_n.v;
      dv = der(s);
      s = s_aus;
    end Strecke;
    annotation (Documentation(info="<html>
<h3>Impuls als bilanzierf&auml;hige Gr&ouml;sse</h3>
<p>Der <font color=\"#FF0000\">Impuls</font> bildet die mengenartige oder bilanzierf&auml;hige Gr&ouml;sse der Translationsmechanik, die <font color=\"#FF0000\">Geschwindigkeit</font> ist das zugeh&ouml;rige Potential. Ein raumfestes Koordinatensystem (<font color=\"#FF0000\">Weltsystem</font>) teilt den Impuls in drei getrennt zu bilanzierende \"Sorten\" auf und spaltet die Geschwindigkeit in drei Potentiale. Eine Kraft ist eine Impulsstromst&auml;rke bez&uuml;glich eines K&ouml;rpers. Fliesst Impuls zu, zeigt der Kraftpfeil in die positive Richtung. Dabei spielt es keine Rolle, ob der Impuls von der positiven Seite (Zug) oder von der negativen (Druck) her zustr&ouml;mt. Diese Zuordnungsregel gilt f&uuml;r alle drei Komponenten des Impulses.</p>
<p>Im Element <font color=\"#008800\">Masse</font> wird die <font color=\"#FF0000\">Impulsbilanz</font> gebildet. Reibelemente sind <font color=\"#FF0000\">Stromglieder</font>, die Energie dissipieren bzw. Entropie erzeugen. Federelemente wirken induktiv, werden aber in der Regel &uuml;ber die Verformung definiert.</p>
<p>Die St&auml;rke des <font color=\"#FF0000\">zugeordneten Energiestromes</font> ist gleich Geschwindigkeit mal Impulsstromst&auml;rke (Kraft). Den zugeordneten Energiestrom nennt man auch Leistung einer Kraft. Die <font color=\"#FF0000\">Prozessleistung</font> (Geschwindigkeitsdifferenz mal Impulsstromst&auml;rke) liefert den Energieumsatz &uuml;ber einem Stromglied. Setzt der Impulsstrom Energie <font color=\"#FF0000\">frei</font>, ist die Prozessleistung <font color=\"#FF0000\">positiv</font>. Der Begriff Prozessleistung ist in der klassischen Formulierung der Mechanik, die sich prim&auml;r als Bewegungslehre versteht, unbekannt.</p>
<p>Zwischen Geschwindigkeitsdifferenz und Verformung sowie L&auml;nge eines Elementes muss das Vorzeichen gedreht werden. Mehr dazu in <font color=\"#0000FF\">Konnektoren.Verformbar</font>.</p>
</html>"));
  end Translation;
  
  package Rotation "Rotation auf gemeinsamer Achse" 
    model RotErde "unbeschraenkter Drehimpulsaustausch mit der Umwelt" 
      parameter SI.AngularVelocity wamb = 0 
        "Winkelgeschwindigkeit des Bezugssystems";
      SI.Power IW "Staerke des Energiestromes an die Umwelt";
      SI.Energy Waus(start=0, fixed=true) "Energieaustausch mit der Umwelt";
     annotation (defaultComponentName="Erde",
        Icon(
          Line(points=[0,80; 0,40], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Line(points=[-80,40; 80,40], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Line(points=[-60,20; 60,20], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Line(points=[-40,0; 40,0], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Text(
            extent=[-100,-20; 100,-100],
            string="wamb=%wamb",
            style(color=10, rgbcolor={135,135,135}))),
        Documentation(info="<html>
Mit <font color=\"#008800\">TransErde</font> kann unbeschr&auml;nkt Impuls bei einer Geschwindigkeit von <strong>vamb</strong> ausgetauscht werden. Der an das Bezugssystem abfliessende, zugeordnete Energiestrom sowie die mit dem Bezugssystem ausgetauschte Energie werden ermittelt. Das Bezugsniveau f&uuml;r diese Energieberechnungen ist ein zweites, hypotetisches Bezugssystem (absoluter Raum). Normalerweise setzt man die Geschwindigkeit des Bezugssystems gleich Null (<strong>vamb = 0</strong>). Damit sind auch der Energiestrom und die ausgetauschte Energie gleich Null.
</html>"),
        Diagram);
      Konnektoren.RFlansch_neg ro_e annotation (extent=[-10,80; 10,100]);
    equation 
      ro_e.w = wamb;
      IW = ro_e.w*ro_e.M;
      IW = der(Waus);
    end RotErde;
    
    model Traegheit "Koerper auf einer Achse" 
      parameter SI.MomentOfInertia J = 1;
      parameter SI.AngularVelocity wa = 0 "Anfangswinkelgeschwindigkeit";
      SI.AngularMomentum L(start=La, fixed=true) "Drehimpulsinhalt";
      SI.AngularVelocity w "Winkelgeschwindigkeit";
      SI.Power IW "zugeordneter Energiestrom";
      SI.Energy Wrot(start=Wrota, fixed=true) "Rotationsenergie";
    protected 
      parameter SI.AngularMomentum La = J*wa "Anfangsdrehimpuls";
      parameter SI.Energy Wrota = 0.5*wa*La "Anfangsenergie";
    public 
      Konnektoren.RFlansch_pos ro_p annotation (extent=[-10,80; 10,100]);
      annotation (defaultComponentName="J",
        Icon(Ellipse(extent=[-60,80; 60,-40], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=10,
              rgbfillColor={135,135,135},
              fillPattern=1)), Text(
            extent=[-100,-40; 100,-100],
            style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=10,
              rgbfillColor={135,135,135},
              fillPattern=1),
            string="J=%J")), Documentation(info="<html>
<p>Im Element <font color=\"#008800\">Traegheit</font> wird die <font color=\"#FF0000\">Drehimpulsbilanz</font> (Zufluss gleich &Auml;nderungsrate des Inhalts) gebildet. Die Winkelgeschwindigkeit ist gleich Drehimpuls durch Massentr&auml;gheit. Die Rotationsenergie <strong>Wrot</strong> wird zus&auml;tzlich berechnet.</p>
</html>"));
    equation 
       ro_p.M = der(L);
       ro_p.w = w;
       w = L/J;
       IW = ro_p.w*ro_p.M;
       IW = der(Wrot);
    end Traegheit;
    
    model Unwucht "Rolle mit Achse und zwei Wickelradien" 
      parameter SI.Mass m = 1 "schwere und traege Masse";
      parameter SI.MomentOfInertia J0 = 1 "Eigentraegheitsmoment";
      parameter SI.Length r0 = 1 "Abstand Schwerpunkt-Drehachse";
      parameter SI.Acceleration g = 9.81 "Gravitationsfeldstaerke";
      parameter SI.Angle phia = 1 "Anfangswinkel in Radiant";
      parameter SI.AngularVelocity wa = 0 "Anfangswinkelgeschwindigkeit";
      SI.AngularMomentum L(start=La, fixed=true) "Bahn- und Eigendrehimpuls";
      SI.Momentum pz "Vertikalimpuls";
      SI.AngularVelocity w "Winkelgeschwindigkeit";
      SI.Angle phi(start=phia, fixed=true) "Winkel";
      SI.Velocity vz "Geschwindigkeit in vertikaler Richtung";
      SI.Power IW "zugeordneter Energiestrom";
      SI.Energy WBew(start=WBewa, fixed=true) "Bewegungsenergie";
    protected 
      parameter SI.MomentOfInertia J = J0 + m*r0^2 "Gesamttraegheitsmoment";
      parameter SI.AngularMomentum La = J*wa "Anfangsdrehimpuls";
      parameter SI.Energy WBewa = 0.5*wa*La "Bewegungsenergie am Anfang";
      annotation (defaultComponentName="J_s",
        Diagram(
          Ellipse(extent=[40,-40; -40,40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Rectangle(extent=[-58,46; -28,-42], style(
              color=7,
              rgbcolor={255,255,255},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Polygon(points=[8,-80; -8,-80; 0,-100; 8,-80], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0})),
          Polygon(points=[-32,34; -40,16; -24,26; -32,34], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Line(points=[0,58; 0,-80], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1))),
        Icon(Ellipse(extent=[-60,80; 60,-80], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=10,
              rgbfillColor={135,135,135})), Ellipse(extent=[-20,52; 20,12], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Line(points=[-80,0; -60,0], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1))),
        DymolaStoredErrors,
        Documentation(info="<html>
<p>Im Element <font color=\"#008800\">Unwucht</font> wird die <font color=\"#FF0000\">Drehimpulsbilanz</font> (Zufluss und Quellenterm gleich &Auml;nderungsrate des Inhalts) und die <font color=\"#FF0000\">Impulsbilanz</font> f&uuml;r die vertikale Komponente (Zufluss und Quellenterm <strong>m*g</strong> gleich &Auml;nderungsrate des Inhalts) gebildet. Der gespeicherte Drehimpuls setzt sich aus Eigen- und Bahndrehimpuls bez&uuml;glich der festen Achse zusammen. Dementsprechend wird auch das Tr&auml;gheitsmoment um den Term <strong>m*r0^2</strong> erweitert. Der zwischen Schwerpunkt und Drehachse seitw&auml;rts fliessende Vertikalimpuls bildet die Drehimpulsquelle. Die Winkelgeschwindigkeit ist gleich Drehimpuls durch Massentr&auml;gheit. Die Vertikalgeschwindigkeit des Massenmittelpunktes ist gleich Vertikalimpuls durch Masse. Die Bewegungsenergie <strong>WBew</strong> wird zus&auml;tzlich berechnet.</p>
 
<p><font color=\"#FF0000\">Vorzeichenregel:</font> Die positive Drehrichtung weist gegen den Drehsinn der Uhrzeiger, der zugeh&ouml;rige Vektor zeigt aus dem Bildschirm heraus. Die positive Bezugsrichtung f&uuml;r den Impuls zeigt gegen unten (bei den zusammen mit dem Element <font color=\"#008800\">Unwucht</font> verwendeten <font color=\"#008800\">Massen</font> muss <strong>Beta = -90&deg;</strong> gesetzt werden). Bei <strong>phi = 0</strong> liegt der Schwerpunkt am weitesten unten.</p>
 
<p>Eine am Flansch <strong>th_p</strong> fixierte Unwucht bildet ein physisches Pendel.</p>
</html>"));
    public 
      Konnektoren.TFlansch_pos tr_p annotation (extent=[-10,80; 10,100]);
      Konnektoren.RFlansch_pos ro_p annotation (extent=[-100,-10; -80,10]);
    equation 
      tr_p.F + m*g = der(pz);
      ro_p.M - m*g*r0*sin(phi) = der(L);
      ro_p.w = w;
      vz = tr_p.v - r0*w*sin(phi);
      w = L/J;
      vz = pz/m;
      w = der(phi);
      IW = vz*m*g + tr_p.v*tr_p.F + ro_p.w*ro_p.M;
      IW = der(WBew);
    end Unwucht;
    
    model VarTraegheit "Koerper auf einer Achse" 
      parameter SI.MomentOfInertia J = 1 
        "fester Anteil des Massentraegheitsmoments";
      parameter SI.AngularVelocity wa = 0 "Anfangswinkelgeschwindigkeit";
      SI.AngularMomentum L "Drehimpulsinhalt";
      SI.AngularVelocity w(start=wa, fixed=true) "Winkelgeschwindigkeit";
      SI.Power IW "zugeordneter Energiestrom";
      SI.Energy Wrot "Rotationsenergie";
      SI.Energy Wex(start=0, fixed=true) "externe Arbeit";
    protected 
      parameter SI.AngularMomentum La = J*wa "Anfangsdrehimpuls";
      parameter SI.Energy Wrota = 0.5*wa*La "Anfangsenergie";
    public 
      Konnektoren.RFlansch_pos ro_p annotation (extent=[-10,80; 10,100]);
      annotation (defaultComponentName="J_var",
        Icon(Ellipse(extent=[-80,80; 80,-80], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=10,
              rgbfillColor={135,135,135},
              fillPattern=1)),
          Ellipse(extent=[-40,40; 40,-40], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Polygon(points=[-40,2; -20,22; -20,10; 0,10; 0,-8; -20,-8; -20,-18; -40,
                2], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Polygon(points=[40,2; 20,22; 20,10; 0,10; 0,-8; 20,-8; 20,-18; 40,2],
              style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1))), Diagram,
        Documentation(info="<html>
<p>Im Element <font color=\"#008800\">VarTraegheit</font> wird die <font color=\"#FF0000\">Drehimpulsbilanz</font> (Zufluss gleich &Auml;nderungsrate des Inhalts) gebildet. Die Winkelgeschwindigkeit ist gleich Drehimpuls durch Massentr&auml;gheit. Die Massentr&auml;gheit wird &uuml;ber den Signaleingang <strong>J_ex</strong> gesteuert (Massentr&auml;gheit = J + J_ex). Die Rotationsenergie <strong>Wrot</strong> und die externe Arbeit <strong>Wex</strong> werden zus&auml;tzlich berechnet.</p>
</html>"));
      Modelica.Blocks.Interfaces.RealInput J_ex 
        annotation (extent=[-100,-10; -80,10]);
    equation 
       ro_p.M = der(L);
       ro_p.w = w;
       w = L/(J+J_ex);
       IW = ro_p.w*ro_p.M;
       IW = der(Wex);
       Wrot = 0.5*w*L;
    end VarTraegheit;
    
    model Rolle "Rolle mit Achse und zwei Wickelradien" 
      parameter SI.Mass m = 1 "schwere und traege Masse";
      parameter SI.MomentOfInertia J = 1;
      parameter SI.Length r_p = 1 "Wickelradius bei tr_p";
      parameter SI.Length r_n = 1 "Wickelradius bei tr_n";
      parameter SI.Acceleration g = 9.81 "Gravitationsfeldstaerke";
      parameter Real Beta(
         final unit="deg") = 0 
        "Winkel zwischen Horizontalen und gewaehlter Bewegungsrichtung in Grad";
      parameter SI.Velocity va = 0 
        "Anfangsgeschwindigkeit des Massenmittelpunkts";
      parameter SI.AngularVelocity wa = 0 "Anfangswinkelgeschwindigkeit";
      SI.Momentum p(start=pa, fixed=true) "Impulsinhalt";
      SI.AngularMomentum L(start=La, fixed=true) "Drehimpulsinhalt";
      SI.Velocity v "Geschwindigkeit des Massenmittelpunkts";
      SI.AngularVelocity w "Winkelgeschwindigkeit";
      SI.Acceleration a "Beschleunigung des Massenmittelpunkts";
      SI.Power IW "zugeordneter Energiestrom";
      SI.Energy WBew(start=WBewa, fixed=true) "Bewegungsenergie";
    protected 
      parameter SI.Momentum pa = m*va "Anfangsimpuls";
      parameter SI.AngularMomentum La = J*wa "Anfangsdrehimpuls";
      parameter SI.Energy WBewa = 0.5*(va*pa+wa*La) 
        "Bewegungsenergie am Anfang";
      parameter SI.Acceleration gt = -g*sin(Beta*Modelica.Constants.pi/180.0) 
        "Wirksame Komponente der Gravitationsfeldstaerke";
    public 
      Konnektoren.RFlansch_pos ro_p annotation (extent=[-10,-10; 10,10]);
      Konnektoren.TFlansch_pos tr_p annotation (extent=[-10,-100; 10,-80]);
      Konnektoren.TFlansch_neg tr_n annotation (extent=[-10,80; 10,100]);
      Konnektoren.TFlansch_pos tr_m annotation (extent=[-100,-10; -80,10]);
      annotation (defaultComponentName="Rol", Diagram(
          Polygon(points=[98,0; 76,6; 76,-6; 98,0], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0})),
          Line(points=[0,0; 80,0], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1)),
          Ellipse(extent=[40,-40; -40,40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Rectangle(extent=[-56,46; -26,-42], style(
              color=7,
              rgbcolor={255,255,255},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Polygon(points=[-28,36; -36,18; -20,28; -28,36], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1))),
        Icon(Ellipse(extent=[-80,80; 80,-80], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=10,
              rgbfillColor={135,135,135})), Ellipse(extent=[-40,40; 40,-40],
              style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=0,
              rgbfillColor={0,0,0},
              fillPattern=1))),
        Documentation(info="<html>
<p>Im Element <font color=\"#008800\">Rolle</font> wird die <font color=\"#FF0000\">Drehimpulsbilanz</font> (Zufluss und Quellenterme gleich &Auml;nderungsrate des Inhalts) und die <font color=\"#FF0000\">Impulsbilanz</font> f&uuml;r die vertikale Komponente (Zufluss und Quellenterm <strong>m*g</strong> gleich &Auml;nderungsrate des Inhalts) gebildet. Die zwischen den beiden Wickelradien mit Flansch <strong>ro_p</strong> sowie Flansch <strong>ro_n</strong> und der festen Achse querfliessenden Impulsstr&ouml;me bilden die Drehimpulsquellen. Die Winkelgeschwindigkeit ist gleich Drehimpuls durch Massentr&auml;gheit. Die Geschwindigkeit des Massenmittelpunktes ist gleich Impuls durch Masse. Die Bewegungsenergie <strong>WBew</strong> wird zus&auml;tzlich berechnet.</p>

<p><font color=\"#FF0000\">Vorzeichenregel:</font> Die positive Drehrichtung weist gegen den Drehsinn der Uhrzeiger, der zugeh&ouml;rige Vektor zeigt aus dem Bildschirm heraus. Die positive Bezugsrichtung f&uuml;r den Impuls zeigt bei <strong>Beta = 0&deg;</strong> gegen rechts.</p>
</html>"));
    equation 
      tr_p.F + tr_m.F + tr_n.F + m*gt = der(p);
      ro_p.M + tr_p.F*r_p - tr_n.F*r_n = der(L);
      tr_m.v = v;
      tr_p.v = v + w*r_p;
      tr_n.v = v - w*r_n;
      ro_p.w = w;
      v = p/m;
      w = L/J;
      a = der(v);
      IW = v*m*gt + tr_p.v*tr_p.F + tr_m.v*tr_m.F + tr_n.v*tr_n.F + ro_p.w*ro_p.M;
      IW = der(WBew);
    end Rolle;
    
    model Drehdaempfer "Linearer Daempfer" 
      extends Konnektoren.Verdrehbar;
      parameter Real k(
        final unit="N.s",
        final min=0) = 1 "Daempfungskonstante";
      SI.Energy Wdiss(start=0, fixed=true) "dissipierte Energie";
      annotation (defaultComponentName="RDaem",
        Icon(Text(
            extent=[-100,100; 100,40],
            string="%name",
            style(
              color=10,
              rgbcolor={135,135,135},
              fillPattern=7)),
                             Text(
            extent=[-100,-40; 100,-100],
            string="k=%k",
            style(
              color=10,
              rgbcolor={135,135,135},
              fillPattern=7)),
          Rectangle(extent=[-80,40; 80,-40], style(color=0, rgbcolor={0,0,0})),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Rectangle(extent=[-20,40; 20,-40], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=10,
              rgbfillColor={135,135,135},
              fillPattern=1)),
          Rectangle(extent=[-80,14; -20,-14], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=10,
              rgbfillColor={135,135,135}))),
                             Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Drehdaempfer</font> modelliert das Verhalten einer viskosen Grenzschicht oder eines D&auml;mpfers mit linearem Verhalten. Die dissipierte Energie wird zus&auml;tzlich berechnet.</p>
</html>"));
    equation 
      M = k*dw;
      P = der(Wdiss);
    end Drehdaempfer;
    
    model Drehfeder "lineare Torsionsfeder" 
      extends Konnektoren.Verdrehbar;
      parameter Real D(
        final unit="N.m",
        final min=0) = 1 "Drehfederkonstante";
      SI.Energy W(start=0.5*D*dphia^2, fixed=true) "Federenergie";
    annotation (defaultComponentName="RFed",
      Icon(Text(
            extent=[-100,100; 100,40],
            string="%name",
            style(
              color=10,
              rgbcolor={135,135,135},
              fillPattern=7)),
                             Text(
            extent=[-100,-40; 100,-100],
            string="D=%D",
            style(
              color=10,
              rgbcolor={135,135,135},
              fillPattern=7)),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Line(points=[-80,0; -60,0; -40,-40; -20,40; 0,-40; 20,40; 40,-40; 60,
                0; 80,0], style(
              color=10,
              rgbcolor={135,135,135},
              fillPattern=1))),
                             Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Drehfeder</font> modelliert das Verhalten einer idealen Feder. Zudem wird die elastisch gespeicherte Energie (Teil der inneren Energie der Feder) aufintegriert.</p>
</html>"));
    equation 
      M = D*dphi;
      P = der(W);
    end Drehfeder;
    
    model Drehreibung 
      "Grenzflaeche mit Gleit- oder Haftreibung sowie viskoser Reibung" 
      extends Konnektoren.Verdrehbar;
      parameter SI.Torque M_Coul=1 "Coulombmoment";
      parameter SI.Torque M_Stri=1 
        "Stribeckmoment, zunahme des Drehmomentes kurz vor Stillstand";
      parameter SI.Time k_Stri(
        final min=0) = 1 "Stribeck-Exponential-Koeffizient";
      parameter Real k_Visk(
        final unit="N.m.s",
        final min=0) = 1 "Koeffizient der viskosen Reibung";
      parameter SI.AngularVelocity w_klein=1e-3;
      SI.AngularAcceleration dalpha 
        "relative Winkelbeschleunigung zwischen ro_p und ro_n";
      SI.Torque M0 "Gesamtdrehmoment von Coulomb und Stribeck";
      SI.Force M0_max "ein Promille groesser als M0";
      SI.Energy Wdiss "vom Drehimpulsstrom dissipierte Energie";
    protected 
      Real sa "Wegparameter fuer M(dalpha)";
      constant Integer Vor=1;
      constant Integer Rueck=-1;
      constant Integer Still=0;
      Integer mode;
      Boolean startVor;
      Boolean startRueck;
      Boolean blockiert;
      annotation (defaultComponentName="RReib",
        Icon(
          Rectangle(extent=[-80,80; -20,-80], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=10,
              rgbfillColor={135,135,135})),
          Rectangle(extent=[20,80; 80,-80], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Rectangle(extent=[-30,80; 30,-80], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=6,
              rgbfillColor={255,255,0},
              fillPattern=1))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Drehreibung</font> modelliert das Verhalten einer Grenzschicht zwischen zwei rotierenden K&ouml;rpern mit Gleit- oder Haftreibung sowie viskoser Reibung. Die dissipierte Energie wird zus&auml;tzlich berechnet.</p>
<p>Dieses Element ist der Modelica-Standardbibliothek entnommen und ist von Prof. Dr. Martin Otter entwickelt worden.</p>
<dd><a href=\"http://www.robotic.dlr.de/Martin.Otter/\">Martin Otter</a><br>
    Deutsches Zentrum f&uuml;r Luft und Raumfahrt e.V. (DLR)<br>
    Institut f&uuml;r Robotik und Mechatronik<br>
    Postfach 11 16<br>
    D-82230 Wessling<br>
    Germany<br>
    email: <A HREF=\"mailto:Martin.Otter@dlr.de\">Martin.Otter@dlr.de</A><br></dd>
</html>"));
    equation 
      dalpha = der(dw);
      M0 = (M_Coul + M_Stri);
      M0_max = M0*1.001;
      startVor = pre(mode) == Still and (sa > M0_max or pre(startVor) and sa >
        M0) or pre(mode) == Rueck and dw > w_klein or initial() and (dw
         > 0);
      startRueck = pre(mode) == Still and (sa < -M0_max or pre(startRueck) and 
        sa < -M0) or pre(mode) == Vor and dw < -w_klein or initial() and (
        dw < 0);
      blockiert = not (pre(mode) == Vor or startVor or pre(mode) == Rueck or 
        startRueck);
      mode = (if (pre(mode) == Vor or startVor) and dw > 0 then Vor else if 
        (pre(mode) == Rueck or startRueck) and dw < 0 then Rueck else Still);
      dalpha = if blockiert then 0 else if startVor then sa - M0 else if 
        startRueck then sa + M0 else if pre(mode) == Vor then sa - M0 else sa
         + M0;
      M = if blockiert then sa else (if startVor then k_Visk*dw + M0 else 
        if startRueck then k_Visk*dw - M0 else if pre(mode) == Vor then 
        k_Visk*dw + M_Coul + M_Stri*exp(-k_Stri*abs(dw)) else k_Visk*
        dw - M_Coul - M_Stri*exp(-k_Stri*abs(dw)));
       P = der(Wdiss);
    end Drehreibung;
    
    model Pumpe_IL "Eingangssignal steuert Drehimpulsstrom" 
      extends Konnektoren.Verdrehbar;
      Modelica.Blocks.Interfaces.RealInput M_in 
        annotation (extent=[-10,-100; 10,-80],
                                             rotation=-270);
      annotation (defaultComponentName="P_IL", Diagram,
        Icon(
          Line(points=[0,-80; 0,-40], style(color=3, rgbcolor={0,0,255})),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
            Polygon(points=[80,0; 40,30; 40,10; -80,10; -80,-10; 40,-10; 40,-30;
                80,0], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=10,
              rgbfillColor={135,135,135},
              fillPattern=1)),
          Text(
            extent=[-100,100; 100,40],
            string="%name",
            style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1))),
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Pumpe_IL</font> f&ouml;rdert einen Drehimpulsstrom nach Vorgabe des Signaleingangs <strong>M_in</strong>. Der Drehimpulsstrom (Drehmoment) wird begrenzt, sobald der Betrag der Leistung den Wert <strong>Pmax</strong> &uuml;bersteigt.</p>
<p>Die Drehimpulsstromst&auml;rke (Drehmoment) ist positiv, wenn der Drehimpuls vom Eingang <strong>ro_p</strong> zum Ausgang <strong>ro_n</strong> fliesst. <font color=\"#FF0000\">Die Leistung <strong>P</strong> ist negativ, falls die Pumpe den Drehimpuls von einem K&ouml;rper mit kleiner zu einem K&ouml;rper mit grosser Winkelgeschwindigkeit f&ouml;rdert </font>(gross und klein beziehen sich auf die rellen Zahlen und nicht auf deren Betr&auml;ge).</p>
</html>"));
    equation 
      M = M_in;
    end Pumpe_IL;
    
    model Pumpe_dw "Eingangssignal gibt Geschwindigkeit vor" 
      extends Konnektoren.Verdrehbar;
      Modelica.Blocks.Interfaces.RealInput dw_in 
        annotation (extent=[-10,-80; 10,-100], rotation=-90);
      annotation (defaultComponentName="P_dw",
        Icon(Line(points=[0,-40; 0,-80], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Line(points=[40,0; 40,-20; 80,0; 40,20; 40,0; -40,0; -40,20; -80,0;
                -40,-20; -40,0], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Text(
            extent=[-100,100; 100,40],
            string="%name",
            style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1))),        Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Pumpe_dw</font> erzeugt eine Winkelgeschwindigkeitsdifferenz nach Vorgabe des Signaleingangs <strong>dw_in</strong>. Der Drehimpulsstrom (Drehmoment) wird nicht begrenzt.</p>
<p>Ein positiver Signaleingang <strong>dw_in</strong> erzeugt eine <font color=\"#FF0000\">negative</font> Winkelgeschwindigkeitsdifferenz (die Winkelgeschwindigkeit am Eingang <strong>ro_p.w</strong> liegt tiefer als am Ausgang <strong>ro_n.w</strong>). Die Drehimpulsstromst&auml;rke ist wie bei den passiven Elementen positiv, wenn der Drehimpuls vom Eingang <strong>h_p</strong> zum Ausgang <strong>h_n</strong> fliesst. <font color=\"#FF0000\">Die Leistung <strong>P</strong> ist negativ, falls die Pumpe Energie auf den Drehmpulsstrom &uuml;bertr&auml;gt</font>.</p>
</html>"));
    equation 
      dw = -dw_in;
    end Pumpe_dw;
    
    model Kupplung "ideales Schaltventil" 
      extends Konnektoren.Verdrehbar;
      parameter Real RLein(
        final min=0) = 1e-5 
        "reziproke Daempferkonstante bei geschlossenem Schalter";
      parameter Real GLaus(
        final unit="N.s",
        final min=0) = 1e-5 "Daempferkonstante bei offener Kupplung";
    protected 
      Real h "Hilfsvariable";
      Boolean aus;
      annotation (defaultComponentName="Kup",
        Icon(
          Rectangle(extent=[-80,40; 80,-40], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Line(points=[-80,0; -20,0; 40,32], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Line(points=[80,0; 40,0], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Ellipse(extent=[-26,6; -16,-4], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Line(points=[0,80; 0,10], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Kupplung</font> ist als idealer Schalter modelliert. Um Singularit&auml;ten zu vermeiden wirkt bei geschlossenem Schalter ein kleiner Widerstand <strong>RLein</strong> und bei offenem Schalter (<strong>aus</strong>) ein kleiner Leitwert <strong>GLaus</strong>.</p>
</html>"));
    public 
      Modelica.Blocks.Interfaces.BooleanInput Schalt 
        annotation (extent=[-10,80; 10,100], rotation=-90);
    equation 
      aus = Schalt;
      dw = h*(if aus then 1 else RLein);
      M = h*(if aus then GLaus else 1);
    end Kupplung;
    
    model DrehdaempferT "Linearer Daempfer" 
      extends Konnektoren.Verdrehbar;
      parameter SI.Temperature T0 = 283 "Referenztemperatur";
      parameter Real Beta = 1.1e11 "Faktor im Exponent";
      parameter Real n = -4.2 "Exponent der Temperatur";
      parameter Real k0(
        final unit="N.m.s",
        final min=0) = 1 "Daempfungskonstante";
      Real k(
        final unit="N.m.s",
        final min=0) "Leitwert bezueglich Drehimpulsstrom";
      SI.ThermalConductance PiS "Entropieproduktionsrate";
      SI.Temperature T "absolute Temperatur";
      Konnektoren.Kontakt_neg th_n annotation (extent=[-10,-60; 10,-40]);
      annotation (defaultComponentName="RDaem_T",
        Icon(Text(
            extent=[-100,100; 100,40],
            string="%name",
            style(
              color=10,
              rgbcolor={135,135,135},
              fillPattern=7)),
          Rectangle(extent=[-80,40; 80,-40], style(color=0, rgbcolor={0,0,0})),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Rectangle(extent=[-20,40; 20,-40], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=10,
              rgbfillColor={135,135,135},
              fillPattern=1)),
          Rectangle(extent=[-80,14; -20,-14], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=10,
              rgbfillColor={135,135,135},
              fillPattern=1)),
          Rectangle(extent=[20,40; 80,-40], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=1,
              rgbfillColor={255,0,0}))),
                             Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">DrehdaempferT</font> modelliert eine Kupplung mit linearem Drehimpulsstrom-Winkelgeschwindigkeitsverhalten.</p>
<p>Der D&auml;mpfwert <strong>k</strong> (Leitwert bez&uuml;glich Drehimpulsstrom) h&auml;ngt von der Temperatur ab</p>
<p><i>log(log(k/k0)) = n*log(T/T0)</i></p>
<p>Die im Prozess produzierte Entropie wird &uuml;ber den Anschluss <strong>th_n</strong> abgef&uuml;hrt. <font color=\"#FF0000\">Der Anschluss <strong>th_n</strong> muss an ein thermisches Element (notfalls an ThermoErde) angeschlossen werden.</font></p>
</html>"));
    equation 
      M = k*dw;
      k = k0*exp(Beta*(T^n-T0^n));
      PiS = P/T;
      T = th_n.T;
      PiS = -th_n.IS;
    end DrehdaempferT;
    
    model DrehreibungT 
      "Grenzflaeche mit Gleit- oder Haftreibung sowie viskoser Reibung, Entropiebilanz" 
      extends Konnektoren.Verdrehbar;
      parameter SI.Torque M_Coul=1 "Coulombmoment";
      parameter SI.Force M_Stri=1 "Stribeckmoment";
      parameter SI.Time k_Stri(
        final min=0) = 1 "Stribeck-Exponential-Koeffizient";
      parameter Real k_Visk(
        final unit="N.m.s",
        final min=0) = 1 "Koeffizient der viskosen Reibung";
      SI.Energy Wdiss "vom Drehimpulsstrom dissipierte Energie";
      SI.ThermalConductance PiS "Entropieproduktionsrate";
      SI.Temperature T "absolute Temperatur";
    protected 
      Real h "Kraftvariable";
      Real r "Parametrisierungsvariable";
      constant Integer Vor=1;
      constant Integer Rueck=-1;
      constant Integer Still=0;
      Integer Mode;
      parameter Real kw=1e-3;
    annotation (defaultComponentName="RReib_T",
      Icon(
          Rectangle(extent=[-80,80; -30,-80], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=10,
              rgbfillColor={135,135,135})),
          Rectangle(extent=[32,80; 80,-80], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Rectangle(extent=[-30,80; 32,-80], style(
              color=10,
              rgbcolor={135,135,135},
              fillColor=1,
              rgbfillColor={255,0,0},
              fillPattern=1))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">DrehreibungT</font> modelliert das Verhalten einer Grenzschicht zwischen zwei rotierenden K&ouml;rpern mit Gleit- oder Haftreibung sowie viskoser Reibung. <font color=\"#008800\">DrehreibungT</font> ist einfacher modelliert als <font color=\"#008800\">Reibung</font> und zeigt deshalb im Haftreibungsfall einen gr&ouml;sseren Schlupf. Die dissipierte Energie wird zus&auml;tzlich berechnet.</p>
<p>Die im Prozess produzierte Entropie wird &uuml;ber den Anschluss <strong>th_n</strong> abgef&uuml;hrt. <font color=\"#FF0000\">Der Anschluss <strong>th_n</strong> muss an ein thermisches Element (notfalls an ThermoErde) angeschlossen werden.</font></p>
</html>"));
    public 
      Konnektoren.Kontakt_neg th_n annotation (extent=[-10,-100; 10,-80]);
    equation 
      der(Wdiss) = P;
      Mode = if r > 1 then Vor else if r < -1 then Rueck else Still;
      dw = if Mode == Vor then r*(1 + kw) - 1 else if Mode == Rueck then r*(
        1 + kw) + 1 else kw*r;
      h = if Mode == Vor then 1 else if Mode == Rueck then -1 else r;
      M = h*(M_Coul + M_Stri*exp(-k_Stri*Mode*dw)) + k_Visk*dw;
      PiS = P/T;
      T = th_n.T;
      PiS = -th_n.IS;
    end DrehreibungT;
    
    model Winkelgeschwindigkeit "Misst die Winkelgeschwindigkeit" 
      extends Modelica.Icons.RotationalSensor;
      annotation (defaultComponentName="M_w", diagram,
        Icon(
          Line(points=[-80,0; -70,0], style(color=10, rgbcolor={135,135,135})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-48,-10; 52,-70],
            string="%name",
            style(color=10, rgbcolor={135,135,135}))),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Winkelgeschwindigkeit</font> gibt den Wert der Winkelgeschwindigkeit am Signalausgang <strong>w_aus</strong> an.
</html>"));
      
      Modelica.Blocks.Interfaces.RealOutput w_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
      Konnektoren.RFlansch_pos ro_p annotation (extent=[-100,-10; -80,10]);
    equation 
      ro_p.M = 0;
      ro_p.w = w_aus;
    end Winkelgeschwindigkeit;
    
    model Drehmoment "Misst den durchfliessenden Drehimpulsstrom" 
      extends Modelica.Icons.RotationalSensor;
      annotation (defaultComponentName="M_M", Diagram,
        Icon(
          Line(points=[-80,0; -70,0], style(color=10, rgbcolor={135,135,135})),
          Line(points=[70,0; 80,0], style(color=10, rgbcolor={135,135,135})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-48,-10; 52,-70],
            string="%name",
            style(color=10, rgbcolor={135,135,135}))),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Drehmoment</font> gibt die St&auml;rke des durchfliessenden Drehimpulsstromes am Signalausgang <strong>M_aus</strong> an. Die Stromst&auml;rke ist positiv, wenn der Drehimpuls vom Eingang <strong>ro_p</strong> zum Ausgang <strong>ro_n</strong> fliesst.
</html>"));
      
      Modelica.Blocks.Interfaces.RealOutput M_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
      Konnektoren.RFlansch_pos ro_p annotation (extent=[-100,-10; -80,10]);
      Konnektoren.RFlansch_neg ro_n annotation (extent=[80,-10; 100,10]);
    equation 
      ro_p.w = ro_n.w;
      ro_p.M + ro_n.M = 0;
      ro_p.M = M_aus;
    end Drehmoment;
    
    model Delta_Omega "Misst die Differenz der Winkelgeschwindigkeit" 
      extends Modelica.Icons.RotationalSensor;
      annotation (defaultComponentName="M_dw", Diagram,
        Icon(
          Line(points=[-80,0; -70,0], style(color=10, rgbcolor={135,135,135})),
          Line(points=[70,0; 80,0], style(color=10, rgbcolor={135,135,135})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-46,-10; 52,-70],
            string="%name",
            style(color=10, rgbcolor={135,135,135}))),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Delta_Omega</font> gibt die Winkelgeschwindigkeitsdifferenz am Signalausgang <strong>dw_aus</strong> an. Die Differenz ist positiv, wenn die Winkelgeschwindigkeit am Eingang <strong>ro_p</strong> gr&ouml;sser als am Ausgang <strong>ro_n</strong> ist.
</html>"));
      
      Modelica.Blocks.Interfaces.RealOutput dw_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
      Konnektoren.RFlansch_pos ro_p annotation (extent=[-100,-10; -80,10]);
      Konnektoren.RFlansch_neg ro_n annotation (extent=[80,-10; 100,10]);
    equation 
      ro_p.M = 0;
      ro_n.M = 0;
      ro_p.w - ro_n.w = dw_aus;
    end Delta_Omega;
    annotation (Documentation(info="<html>
<h3>Drehimpuls als bilanzierf&auml;hige Gr&ouml;sse</h3>
<p>Der <font color=\"#FF0000\">Drehimpuls</font> bildet die mengenartige oder bilanzierf&auml;hige Gr&ouml;sse der Rotationsmechanik, die <font color=\"#FF0000\">Winkelgeschwindigkeit</font> ist das zugeh&ouml;rige Potential. Ein raumfestes Koordinatensystem (<font color=\"#FF0000\">Weltsystem</font>) teilt den Drehimpuls in drei getrennt zu bilanzierende \"Sorten\" auf und spaltet die Winkelgeschwindigkeit in drei Potentiale. Ein Drehmoment ist eine Drehimpulsstromst&auml;rke bez&uuml;glich eines K&ouml;rpers. Fliesst Drehimpuls zu, zeigt der Drehmomentenpfeil in die positive Richtung. Dabei spielt es keine Rolle, ob der Drehimpuls von der positiven Seite (rechth&auml;ndige Torsion) oder von der negativen (linksh&auml;ndige Torsion) her zustr&ouml;mt. Diese Zuordnungsregel gilt f&uuml;r alle drei Komponenten des Drehimpulses.</p>
<p>In der Massentr&auml;gheit wird die <font color=\"#FF0000\">Drehimpulsbilanz</font> gebildet. Reibkupplungen sind <font color=\"#FF0000\">Stromglieder</font>, die Energie dissipieren bzw. Entropie erzeugen. Federelemente wirken induktiv, werden aber in der Regel &uuml;ber die Verformung definiert.</p>
<p>Die St&auml;rke des <font color=\"#FF0000\">zugeordneten Energiestromes</font> ist gleich Winkelgeschwindigkeit mal Drehimpulsstromst&auml;rke (Drehmoment). Den zugeordneten Energiestrom nennt man auch Leistung eines Drehmoments. Die <font color=\"#FF0000\">Prozessleistung</font> (Winkelgeschwindigkeitsdifferenz mal Drehimpulsstromst&auml;rke) liefert den Energieumsatz &uuml;ber einem Stromglied. Setzt der Drehimpulsstrom Energie <font color=\"#FF0000\">frei</font>, ist die Prozessleistung <font color=\"#FF0000\">positiv</font>. Der Begriff Prozessleistung ist in der klassischen Formulierung der Mechanik, die sich prim&auml;r als Bewegungslehre versteht, unbekannt.</p>
</html>"));
  end Rotation;
  
  package Thermodynamik "reine Stoffe" 
    model ThermoErde "Verbindung zur Umwelt" 
      parameter SI.Temperature Tamb = 273 "Umgebungstemperatur";
      SI.Power IW "Staerke des Energiestromes an die Umwelt";
      SI.Energy Waus(start=0, fixed=true) "Energieaustausch mit der Umwelt";
      annotation (defaultComponentName="Erde", Diagram,
        Icon(
          Line(points=[0,80; 0,40], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Line(points=[-80,40; 80,40], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Line(points=[-60,20; 60,20], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Line(points=[-40,0; 40,0], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1)),
          Text(
            extent=[-100,-20; 100,-100],
            style(color=1, rgbcolor={255,0,0}),
            string="Tamb=%Tamb")),
        Documentation(info="<html>
Mit der <font color=\"#008800\">ThermoErde</font> kann unbeschr&auml;nkt Entropie bei einer Temperatur von <strong>Tamb</strong> = 273 K ausgetauscht werden. Der an die Umwelt abfliessende, zugeordnete Energiestrom sowie die mit der Umwelt ausgetauschte Energie werden ermittelt. Die Umgebungstemperatur sollte auf einen plausiblen Wert gestzt werden.
</html>"));
      Konnektoren.Kontakt_neg th_e annotation (extent=[-10,80; 10,100]);
    equation 
      th_e.T = Tamb;
      IW = th_e.T*th_e.IS;
      IW = der(Waus);
    end ThermoErde;
    
    model Waermespeicher "Festkoerper oder Flssigkeit bei konstantem Druck" 
      parameter SI.Mass m = 1 "Masse als Hilfsgroesse";
      parameter SI.SpecificHeatCapacity c = 4186 
        "spezifische Enthalpiekapazitaet";
      parameter SI.Temperature Ta = 293 "Anfangstemperatur";
      parameter SI.Temperature Tamb = 273 "Bezugstemperatur";
      SI.Temperature T;
      SI.Power IW "zugeordneter Energiestrom";
      SI.Enthalpy H(start= Ha, fixed=true);
      SI.Entropy S(start= Sa, fixed=true);
    protected 
      parameter SI.HeatCapacity C = m*c "Enthalpiekapazitt";
      parameter SI.Enthalpy Ha = C*(Ta-Tamb) "Enthalpie am Anfang";
      parameter SI.Entropy Sa = C*ln(Ta/Tamb) "Entropie am Anfang";
    public 
      Konnektoren.Kontakt_pos th_p annotation (extent=[-10,80; 10,100]);
    equation 
      th_p.T = T;
      IW = th_p.IS*th_p.T;
      IW = der(H);
      H = C*(T-Ta);
      th_p.IS = der(S);
      annotation (defaultComponentName="C",
        Icon(Rectangle(extent=[-80,80; 80,-80], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=7,
              rgbfillColor={255,255,255})),
                                      Text(
            extent=[-80,80; 80,-80],
            string="C",
            style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=7,
              rgbfillColor={255,255,255}))), Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Waermespeicher</font> nimmt Entropie auf. Intern werden die gespeicherte <font color=\"#FF0000\">Entropie</font>  und die <font color=\"#FF0000\">Enthalpie</font> gerechnet. Das Speicherverm&ouml;gen wird mit Hilfe der spezifischen W&auml;rmekapazit&auml;t <strong>c</strong> parametrisiert. Der hier gesetzte Wert gilt f&uuml;r Wasser.</p>
</html>"));
    end Waermespeicher;
    
    model Mehrphasenspeicher "Speicher bei konstantem Druck" 
      parameter SI.Mass m = 1 "Masse als Hilfsgroesse";
      parameter SI.SpecificHeatCapacity cfest = 2100 
        "spezifische Enthalpiekapazitaet fest";
      parameter SI.SpecificHeatCapacity cfluss = 4182 
        "spezifische Enthalpiekapazitaet fluessig";
      parameter SI.SpecificHeatCapacity cgas = 2200 
        "spezifische Enthalpiekapazitaet gasfoermig";
      parameter SI.SpecificEnthalpy q = 334000 "spez. Schmelzenthalpie";
      parameter SI.SpecificEnthalpy r = 2257000 "spez. Schmelzenthalpie";
      parameter SI.Temperature Tschmelz = 273 "Schmelztemperatur";
      parameter SI.Temperature Tverdampf = 373 "Verdampfungstemperatur";
      parameter SI.Enthalpy Ha = 0;
      parameter SI.Entropy Sa = 0;
      SI.Temperature T;
      SI.Power IW "zugeordneter Energiestrom";
      SI.Enthalpy H( start=Ha, fixed=true);
      SI.Entropy S(start= Sa, fixed=true);
      constant Integer fest=-2;
      constant Integer schmelzen=-1;
      constant Integer fluessig=0;
      constant Integer verdampfen=1;
      constant Integer gas=2;
      Integer Mode;
      Konnektoren.Kontakt_pos th_p annotation (extent=[-10,80; 10,100]);
      annotation (defaultComponentName="Stoff",
        Icon(Rectangle(extent=[-80,80; 80,-80], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=7,
              rgbfillColor={255,255,255})),
                                      Line(points=[-70,-80; -30,-60; -30,-40; 10,0;
                10,60; 70,80], style(
              color=1,
              rgbcolor={255,0,9},
              fillColor=1,
              rgbfillColor={255,0,0},
              fillPattern=1))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Mehrphasenspeicher</font> modelliert das thermische Verhalten eines Stoffes unter konstantem Druck. Intern werden die gespeicherte <font color=\"#FF0000\">Entropie</font>  und die <font color=\"#FF0000\">Enthalpie</font> gerechnet. Die Temperatur wird aus der Enthalpie abgeleitet. Enthalpie und Entropie sind f&uuml;r den fl&uuml;ssigen Zustand bei Schmelztemperatur gleich Null gesetzt worden. Das Element startet im Zustand H = 0 und S = 0. Mit Hilfe der Anfangsenthalpie kann der Anfangszustand (Temperatur und Phase) frei gew&auml;hlt werden. Die Anfangsentropie kann auf einen beliebigen Wert gesetzt werden. Die angegebenen spezifischen Enthalpiewerte gelten f&uuml;r Wasser.</p>
</html>"));
    equation 
      th_p.T = T;
      Mode = if H < -m*q then fest else if H < 0 then schmelzen else if H < m*cfluss*(Tverdampf-Tschmelz) then 
              fluessig else if H < m*(cfluss*(Tverdampf-Tschmelz)+r) then verdampfen else gas;
      IW = der(H);
       T = if Mode == fest then (H+m*q)/(m*cfest)+ Tschmelz else if Mode == schmelzen then Tschmelz else 
            if Mode == fluessig then H/(m*cfluss)+Tschmelz else 
            if Mode == verdampfen then Tverdampf else (H-m*(cfluss*(Tverdampf-Tschmelz)+r))/(m*cgas)+Tverdampf;
      IW = th_p.IS*th_p.T;
      th_p.IS = der(S);
    end Mehrphasenspeicher;
    
    model Waermeleitung "waermeleitendes Element" 
      extends Konnektoren.Energiestromglied;
      parameter SI.ThermalConductance GW = 1 "Energieleitwert";
      annotation (defaultComponentName="GW",
        Icon(
          Text(
            extent=[-80,100; 80,40],
            style(
              color=1,
              rgbcolor={255,0,9},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="%name"),
          Text(
            extent=[-80,-40; 80,-100],
            style(
              color=1,
              rgbcolor={255,0,9},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="GW=%GW"),
          Rectangle(extent=[-40,40; 20,-40], style(
              color=1,
              rgbcolor={255,0,9},
              fillColor=1,
              rgbfillColor={255,0,0},
              fillPattern=1))), DymolaStoredErrors,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Waermeleitung</font> leitet <font color=\"#FF0000\">Entropie</font>  und <font color=\"#FF0000\">Energie</font> durch. Die Energie bleibt erhalten und die Entropie nimmt maximal zu. Die Entropieproduktionsrate <strong>PiS</strong> wird bez&uuml;glich der tieferen Temperatur berechnet. Das Leitungsverm&ouml;gen wird mit Hilfe des Energieleitwerts (W&auml;rmeleitwerts) <strong>GW</strong> parametrisiert.</p>
</html>"));
    equation 
      IW = GW*dT;
    end Waermeleitung;
    
    model Prisma "waermeleitender Stab" 
      extends Konnektoren.Energiestromglied;
      parameter SI.Area A = 1 "Querschnitt";
      parameter SI.Length d = 1 "Laenge";
      parameter SI.ThermalConductivity lambda = 384 "Waermeleitfaehigkeit";
    protected 
      parameter SI.ThermalConductance GW = lambda*A/d "Energieleitwert";
    annotation (defaultComponentName="GW",
      Icon(
          Text(
            extent=[-80,100; 80,40],
            style(
              color=1,
              rgbcolor={255,0,9},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="%name"),
          Text(
            extent=[-80,-40; 80,-100],
            style(
              color=1,
              rgbcolor={255,0,9},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="A=%A"),
          Rectangle(extent=[-80,40; 80,-40], style(
              color=1,
              rgbcolor={255,0,9},
              fillColor=1,
              rgbfillColor={255,0,0},
              fillPattern=1))), DymolaStoredErrors,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Prisma</font> leitet <font color=\"#FF0000\">Entropie</font>  und <font color=\"#FF0000\">Energie</font> durch. Die Energie bleibt erhalten und die Entropie nimmt maximal zu. Die Entropieproduktionsrate <strong>PiS</strong> wird bez&uuml;glich der tieferen Temperatur berechnet. Das Leitungsverm&ouml;gen wird mit Hilfe der Geometrie und der W&auml;rmeleitf&auml;higkeit <strong>lambda</strong> parametrisiert. Der hier gesetzte Wert gilt f&uuml;r Kupfer.</p>
</html>"));
    equation 
      IW = GW*dT;
    end Prisma;
    
    model Uebergang "Waermeuebergang" 
      extends Konnektoren.Energiestromglied;
      parameter SI.Area A = 1 "Querschnitt";
      parameter SI.CoefficientOfHeatTransfer alpha =  1 "Waermeleitfaehigkeit";
    protected 
      parameter SI.ThermalConductance GW = alpha*A "Energieleitwert";
    annotation (defaultComponentName="GW",
      Icon(
          Text(
            extent=[-80,100; 80,40],
            style(
              color=1,
              rgbcolor={255,0,9},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="%name"),
          Text(
            extent=[-80,-40; 80,-100],
            style(
              color=1,
              rgbcolor={255,0,9},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="A=%A"),
          Rectangle(extent=[-80,40; -20,-40],style(
              color=1,
              rgbcolor={255,0,9},
              fillColor=1,
              rgbfillColor={255,0,0},
              fillPattern=1)),
          Rectangle(extent=[20,40; 80,-40], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255}))),
                                DymolaStoredErrors,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Uebergang</font> leitet <font color=\"#FF0000\">Entropie</font>  und <font color=\"#FF0000\">Energie</font> durch. Die Energie bleibt erhalten und die Entropie nimmt maximal zu. Die Entropieproduktionsrate <strong>PiS</strong> wird bez&uuml;glich der tieferen Temperatur berechnet. Das Leitungsverm&ouml;gen wird mit Hilfe der Fl&auml;che und des W&auml;rme&uuml;bergangskoeffizienten <strong>alpha</strong> parametrisiert.</p>
</html>"));
    equation 
      IW = GW*dT;
    end Uebergang;
    
    model Waermestrahlung "Waermestrahlung von grauen Koerpern" 
      extends Konnektoren.Energiestromglied;
      parameter SI.Area A = 1 "Querschnitt";
      parameter Real eps = 1 "Emissionszahl";
      annotation (defaultComponentName="Strahl",
       Icon(
          Text(
            extent=[-80,100; 80,40],
            style(
              color=1,
              rgbcolor={255,0,9},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="%name"),
          Text(
            extent=[-80,-40; 80,-100],
            style(
              color=1,
              rgbcolor={255,0,9},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1),
            string="A=%A"),
          Rectangle(extent=[-80,40; -40,-40],style(
              color=1,
              rgbcolor={255,0,9},
              fillColor=1,
              rgbfillColor={255,0,0},
              fillPattern=1)),
          Rectangle(extent=[40,40; 80,-40], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255})),
          Line(points=[40,20; -40,0; 40,-20], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=3,
              rgbfillColor={0,0,255},
              fillPattern=1))), DymolaStoredErrors,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Waermestrahlung</font> leitet <font color=\"#FF0000\">Entropie</font> und <font color=\"#FF0000\">Energie</font> in Form von Strahlung durch. Die Energie bleibt erhalten und die Entropie nimmt maximal zu. Die Entropieproduktionsrate <strong>PiS</strong> wird bez&uuml;glich der tieferen Temperatur berechnet. Das Modell gilt f&uuml;r graue K&ouml;rper (Emissionszahl <strong>eps</strong>) gegen eine schwarze Umwelt und einfache Geometrie (konvexe Bezugssfl&auml;che des strahlenden K&ouml;rpers <strong>A</strong>.</p>
</html>"));
    equation 
      IW = Modelica.Constants.sigma*eps*A*(th_p.T^4-th_n.T^4);
    end Waermestrahlung;
    
    model IdealesGas "Gleichgewichtszustaende des idealen Gases" 
      parameter SI.Volume Va = 1 "Anfangsvolumen Gas";
      parameter SI.Volume Vhyda = 1 "Anfangsvolumen Hydraulikteil";
      parameter SI.Pressure pa = 1e5 "Anfangsdruck";
      parameter SI.Temperature Ta = 273 "Anfangstemperatur";
      parameter SI.Energy Ua = 0 "innere Energie am Anfang";
      parameter SI.Energy Sa = 0 "Anfangsentropie";
      parameter Real f = 3 "Freiheitsgrad der Teilchen";
      SI.Volume V "Volumen Gas";
      SI.Volume Vhyd(start=Vhyda, fixed=true) "Volumen Hydraulikteil";
      SI.Pressure p "Druck im System";
      SI.Temperature T "Temperatur des Gases";
      SI.Energy W(start=0, fixed=true) "Arbeit";
      SI.Energy Q(start=Ua, fixed=true) "Waerme";
      SI.Energy U "innere Energie";
      SI.Energy F "freie Energie";
      SI.Enthalpy H "Enthalpie";
      SI.Entropy S(start=Sa, fixed=true) "Entropie";
    protected 
      parameter SI.Volume Vtot=Va+Vhyda "Gefaessvolumen";
      parameter SI.Entropy n_R=Va*pa/Ta;
    public 
      Konnektoren.Kontakt_pos th_p annotation (extent=[-100,-10; -80,10]);
      Konnektoren.Kupplung_pos h_p annotation (extent=[80,-10; 100,10]);
      annotation (defaultComponentName="Gas", Diagram,
        Icon(
          Rectangle(extent=[-80,80; 80,-80], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Ellipse(extent=[-64,58; -44,38], style(
              color=0,
              rgbcolor={0,0,0},
              gradient=3,
              fillColor=3,
              rgbfillColor={0,0,255})),
          Ellipse(extent=[36,-44; 56,-64], style(
              color=0,
              rgbcolor={0,0,0},
              gradient=3,
              fillColor=3,
              rgbfillColor={0,0,255})),
          Ellipse(extent=[42,56; 62,36], style(
              color=0,
              rgbcolor={0,0,0},
              gradient=3,
              fillColor=3,
              rgbfillColor={0,0,255})),
          Ellipse(extent=[-46,-34; -26,-54], style(
              color=0,
              rgbcolor={0,0,0},
              gradient=3,
              fillColor=3,
              rgbfillColor={0,0,255})),
          Ellipse(extent=[-34,56; -14,36], style(
              color=0,
              rgbcolor={0,0,0},
              gradient=3,
              fillColor=3,
              rgbfillColor={0,0,255})),
          Ellipse(extent=[-30,2; -10,-18], style(
              color=0,
              rgbcolor={0,0,0},
              gradient=3,
              fillColor=3,
              rgbfillColor={0,0,255})),
          Ellipse(extent=[20,22; 40,2], style(
              color=0,
              rgbcolor={0,0,0},
              gradient=3,
              fillColor=3,
              rgbfillColor={0,0,255}))),
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">ideales Gas</font> beschreibt die Gleichgewichtszust&auml;nde des idealen Gases. &Uuml;ber den Anschluss <strong>th_p</strong> wird Entropie und &uuml;ber <strong>h_p</strong> Verdr&auml;ngervolumen ausgetauscht. Aus der zugef&uuml;hrten Entropie und dem Gasvolumen <strong>V</strong> werden mit Hilfe der beiden Zustandsgleichungen Druck und Temperatur berechnet</p>
<p><i>p*V = n*R*T</i></p>
<p><i>S = S0 + n*R(ln(V/Va)+(f/2)*ln(T/Ta))</i></p>
Die &Auml;nderung der innere Energie <strong>delta_U</strong> ist gleich Arbeit und W&auml;rme. Arbeit und W&auml;rme werden aus den beiden zugeordneten Energiestr&ouml;men aufintegriert. Die Hilfsgr&ouml;ssen Enthalpie <strong>H</strong> und frei Energie <strong>F</strong> werden zus&auml;tzlich berechnet.<p></p>
</html>"));
    equation 
      Vtot = V + Vhyd;
      p = h_p.p;
      T = th_p.T;
      h_p.IV = der(Vhyd);
      p*V = n_R*T;
      th_p.IS = der(S);
      S = Sa + n_R*ln(V/Va) + (f/2)*n_R*ln(T/Ta);
      h_p.p*h_p.IV = der(W);
      th_p.T*th_p.IS = der(Q);
      U = Ua + W + Q;
      F = U - T*S;
      H = U + p*V;
    end IdealesGas;
    
    model Pumpe_IS "Eingangssignal steuert Entropiestrom" 
      extends Konnektoren.Entropiestromglied;
      Modelica.Blocks.Interfaces.RealInput IS_in 
        annotation (extent=[-10,-100; 10,-80],
                                             rotation=-270);
      annotation (Diagram, defaultComponentName="P_IS",
        Icon(
          Line(points=[0,-80; 0,-40], style(color=3, rgbcolor={0,0,255})),
            Polygon(points=[80,0; 40,30; 40,10; -80,10; -80,-10; 40,-10; 40,-30;
                80,0], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=1,
              rgbfillColor={255,0,0},
              fillPattern=1)),
          Text(
            extent=[-100,100; 100,40],
            string="%name",
            style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1))),
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Pumpe_IS</font> f&ouml;rdert einen Entropiestrom nach Vorgabe des Signaleingangs <strong>IS_in</strong>. Der Strom wird begrenzt, sobald der Betrag der Leistung den Wert <strong>Pmax</strong> &uuml;bersteigt.</p>
<p>Die Entropiestromst&auml;rke ist positiv, wenn die Entropie vom Eingang <strong>th_p</strong> zum Ausgang <strong>th_n</strong> fliesst. <font color=\"#FF0000\">Die Leistung <strong>P</strong> ist negativ, falls die Pumpe einen Entropiestrom von einem Ort mit kleiner zu einem Ort mit grosser Temperatur f&ouml;rdert.</font></p>
</html>"));
    equation 
      IS = IS_in;
    end Pumpe_IS;
    
    model Pumpe_dT "Eingangssignal steuert Temperaturdifferenz" 
      extends Konnektoren.Entropiestromglied;
      annotation (defaultComponentName="P_dT",
        Icon(
          Rectangle(extent=[-80,40; 80,-40], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Text(
            extent=[-100,100; 100,40],
            string="%name",
            style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Line(points=[0,-80; 0,-40], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=2,
              rgbfillColor={0,255,0},
              fillPattern=1)),
          Line(points=[40,0; 40,-20; 80,0; 40,20; 40,0; -40,0; -40,20; -80,0;
                -40,-20; -40,0], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1))),        Diagram,
        Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Pumpe_dT</font> erzeugt eine Temperaturdifferenz nach Vorgabe des Signaleingangs <strong>dT_in</strong>. Der Entropiestrom wird nicht begrenzt.</p>
<p>Ein positiver Signaleingang <strong>dT_in</strong> erzeugt eine <font color=\"#FF0000\">negative</font> Temperaturdifferenz (die Temperatur am Eingang <strong>th_p.T</strong> liegt dann tiefer als am Ausgang <strong>th_n.T</strong>). Die Entropiestromst&auml;rke ist wie bei den passiven Elementen positiv, wenn die Entropie vom Eingang <strong>th_p</strong> zum Ausgang <strong>th_n</strong> fliesst. <font color=\"#FF0000\">Die Leistung <strong>P</strong> ist negativ, falls die Pumpe Energie auf den Entropienstrom &uuml;bertr&auml;gt</font>.</p>
</html>"));
      Modelica.Blocks.Interfaces.RealInput dT_in 
        annotation (extent=[-10,-100; 10,-80], rotation=90);
    equation 
      dT = -dT_in;
    end Pumpe_dT;
    
    model Schalter "schaltet Entropiestrom aus" 
      extends Konnektoren.Entropiestromglied;
      parameter Real RSein(
        final unit="K2/W",
        final min=0) = 1e-5 "Widerstand bei geschlossenem Schalter";
      parameter Real GSaus(
        final unit="W/K2",
        final min=0) = 1e-5 "Leitwert bei offenem Schalter";
    protected 
      Real h "Hilfsvariable";
      Boolean aus;
      annotation (defaultComponentName="TS",
        Icon(
          Rectangle(extent=[-80,40; 80,-40], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=7,
              rgbfillColor={255,255,255})),
          Line(points=[-80,0; -20,0; 40,32], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Line(points=[80,0; 40,0], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Ellipse(extent=[-26,6; -16,-4], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1)),
          Line(points=[0,80; 0,10], style(
              color=1,
              rgbcolor={255,0,0},
              fillColor=7,
              rgbfillColor={255,255,255},
              fillPattern=1))), Documentation(info="<html>
<p>Das Element <font color=\"#008800\">Schalter</font> ist als idealer Schalter modelliert. Um Singularit&auml;ten zu vermeiden wirkt bei geschlossenem Schalter ein kleiner Widerstand <strong>RSein</strong> und bei offenem Schalter (<strong>aus</strong>) ein kleiner Leitwert <strong>GSaus</strong>.</p>
</html>"));
    public 
      Modelica.Blocks.Interfaces.BooleanInput Schalt 
        annotation (extent=[-10,80; 10,100], rotation=-90);
    equation 
      aus = Schalt;
      dT = h*(if aus then 1 else RSein);
      IS = h*(if aus then GSaus else 1);
    end Schalter;
    
    model Temperatur "Misst die Absoluttemperatur" 
      extends Modelica.Icons.RotationalSensor;
      annotation (defaultComponentName="M_T", Diagram,
        Icon(
          Line(points=[-80,0; -70,0], style(color=1, rgbcolor={255,0,0})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-48,-10; 52,-70],
            string="%name",
            style(color=1, rgbcolor={255,0,0}))),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Temperatur</font> gibt den Wert der absoluten Temperatur am Signalausgang <strong>T_aus</strong> an.
</html>"));
      Modelica.Blocks.Interfaces.RealOutput T_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
      Konnektoren.Kontakt_pos th_p annotation (extent=[-100,-10; -80,10]);
    equation 
      th_p.IS = 0;
      th_p.T = T_aus;
    end Temperatur;
    
    model Energiestrom "Misst den durchfliessenden Energiestrom" 
      extends Modelica.Icons.RotationalSensor;
      annotation (defaultComponentName="M_IW",Diagram,
        Icon(
          Line(points=[-80,0; -70,0], style(color=1, rgbcolor={255,0,0})),
          Line(points=[70,0; 80,0], style(color=1, rgbcolor={255,0,0})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-48,-10; 52,-70],
            string="%name",
            style(color=1, rgbcolor={255,0,0}))),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Energiestrom</font> gibt die St&auml;rke des durchfliessenden Energiestromes am Signalausgang <strong>IW_aus</strong> an. Die Stromst&auml;rke ist positiv, wenn die Energie vom Eingang <strong>th_p</strong> zum Ausgang <strong>th_n</strong> fliesst.
</html>"));
      Modelica.Blocks.Interfaces.RealOutput IW_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
      Konnektoren.Kontakt_pos th_p annotation (extent=[-100,-10; -80,10]);
      Konnektoren.Kontakt_neg th_n annotation (extent=[80,-10; 100,10]);
    equation 
      th_p.T = th_n.T;
      th_p.IS + th_n.IS = 0;
      th_p.IS*th_p.T = IW_aus;
    end Energiestrom;
    
    model Entropiestrom "Misst den durchfliessenden Entropiestrom" 
      extends Modelica.Icons.RotationalSensor;
      annotation (defaultComponentName="M_IS", Diagram,
        Icon(
          Line(points=[-80,0; -70,0], style(color=1, rgbcolor={255,0,0})),
          Line(points=[70,0; 80,0], style(color=1, rgbcolor={255,0,0})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-48,-10; 52,-70],
            string="%name",
            style(color=1, rgbcolor={255,0,0}))),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Entropiestrom</font> gibt die St&auml;rke des durchfliessenden Entropiestromes am Signalausgang <strong>IS_aus</strong> an. Die Stromst&auml;rke ist positiv, wenn die Entropie vom Eingang <strong>th_p</strong> zum Ausgang <strong>th_n</strong> fliesst.
</html>"));
      Modelica.Blocks.Interfaces.RealOutput IS_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
      Konnektoren.Kontakt_pos th_p annotation (extent=[-100,-10; -80,10]);
      Konnektoren.Kontakt_neg th_n annotation (extent=[80,-10; 100,10]);
    equation 
      th_p.T = th_n.T;
      th_p.IS + th_n.IS = 0;
      th_p.IS = IS_aus;
    end Entropiestrom;
    
    model Temperaturdifferenz "Misst die Temperaturdifferenz" 
      extends Modelica.Icons.RotationalSensor;
      annotation (defaultComponentName="M_dT", Diagram,
        Icon(
          Line(points=[-80,0; -70,0], style(color=1, rgbcolor={255,0,0})),
          Line(points=[70,0; 80,0], style(color=1, rgbcolor={255,0,0})),
          Line(points=[0,-70; 0,-80], style(color=3, rgbcolor={0,0,255})),
          Text(
            extent=[-48,-10; 50,-70],
            string="%name",
            style(color=1, rgbcolor={255,0,0}))),
        Documentation(info="<html>
Der Sensor <font color=\"#008800\">Temperaturdifferenz</font> gibt die Temperaturdifferenz am Signalausgang <strong>dT_aus</strong> an. Die Differenz ist positiv, wenn die Temperatur am Eingang <strong>th_p</strong> gr&ouml;sser als am Ausgang <strong>th_n</strong> ist.
</html>"));
      Modelica.Blocks.Interfaces.RealOutput dT_aus 
        annotation (extent=[-12,-100; 10,-80], rotation=-90);
      Konnektoren.Kontakt_pos th_p annotation (extent=[-100,-10; -80,10]);
      Konnektoren.Kontakt_neg th_n annotation (extent=[80,-10; 100,10]);
    equation 
      th_p.IS = 0;
      th_n.IS = 0;
      th_p.T - th_n.T = dT_aus;
    end Temperaturdifferenz;
    annotation (Documentation(info="<html>
<h3>Entropie als bilanzierf&auml;hige Gr&ouml;sse</h3>
<p>Die <font color=\"#FF0000\">Entropie</font> bildet die mengenartige oder bilanzierf&auml;hige Gr&ouml;sse der Thermodynamik, die <font color=\"#FF0000\">Temperatur</font> ist das zugeh&ouml;rige Potential. Die Entropie entspricht etwa dem, was der Laie unter W&auml;rmemenge versteht.</p>
<p>In den Speicherelementen wird die <font color=\"#FF0000\">Energiebilanz</font> und die <font color=\"#FF0000\">Entropiebilanz</font> gebildet. Widerst&auml;nde sind <font color=\"#FF0000\">Stromglieder</font>, die Entropie leiten und gleichzeitig weitere erzeugen. Dabei bleibt die Energie erhalten und die Entropie nimmt maximal zu.</p>
<p>Die St&auml;rke des <font color=\"#FF0000\">zugeordneten Energiestromes</font> ist gleich Temperatur mal Entropiestromst&auml;rke. Die <font color=\"#FF0000\">Prozessleistung</font> (Temperaturdifferenz mal Entropiestromst&auml;rke) liefert den Energieumsatz &uuml;ber einem Stromglied. Weil man traditionellerweise nicht zwischen Prozessleistung und zugeordnetem Energiestrom unterscheidet und Energie unreflektiert als Arbeitsverm&ouml;gen bezeichnet, werden viele Zusammenh&auml;nge der Thermodynamik falsch verstanden. Wie bei einem Fluss die potentielle Energie ans Wasser gebunden ist, klebt die Energie als zugeordneter Energiestrom an der Entropie. Sobald die <font color=\"#FF0000\">Entropie thermisch hinunterf&auml;llt</font>, kann der Entropiestrom <font color=\"#FF0000\">Prozessleistung freisetzen</font>. Energie ist demnach nur soweit Arbeitsverm&ouml;gen, als sie in einem Prozess freisgesetzt werden kann. Ist der Prozess nicht machbar, bildet die Energie auch kein Arbeitsverm&ouml;gen.</p>
</html>"));
  end Thermodynamik;
  annotation (Documentation(info="<html>
<h3>PhyDynSys - Physik der dynamischen Systeme mit Modelica</h3>
<p>Die Physik der dynamischen Systeme baut auf dem 
<a href=\"http://www.physikdidaktik.uni-karlsruhe.de/kpk/material.html\">Karlsruher Physikkurs</a> auf, 
benutzt die <a href=\"http://www.systemdynamics.org/\">systemdynamische Modellierungstechnik</a> und orientiert sich an der mathematischen Sprache der Kontinuumsphysik.</p>
 
<p><a href=\"http://www.modelica.org/\">Modelica</a> ist ein neuer Sprachstandard zur Modellierung und Simulation von komplexen physikalischen Systemen. Modelica hat sich teilweise aus der 
<a href=\"http://www.bondgraphs.com\">Bondgraphen</a>-Technik heraus entwickelt. Nun verwendet die Modellierungstechnik mittels Bondgraphen ein &auml;hnliches Paradigma wie die Physik der dynamischen Systeme, wobei letztere in der Strukturanalyse noch eine Stufe tiefer geht. Folglich ist Modelica die nat&uuml;rliche Sprache, um die Physik der dynamischen Systeme zu beschreiben.</font></p>
 
<p>Die Physik der dynamischen Systeme basiert auf der <font color=\"#FF0000\">Bilanz</font>, den <font color=\"#FF0000\">konstitutiven Gesetzen</font> und der klar umrissenen <font color=\"#FF0000\">Rolle der Energie</font>. Die bilanzierf&auml;higen oder mengenartigen Gr&ouml;ssen (Volumen, Masse, elektrische Ladung, Impuls, Drehimpuls, Entropie und Stoffmenge) sind prim&auml;re Gr&ouml;ssen der Physik. Prim&auml;re Gr&ouml;ssen muss man in der Natur entdecken und nicht &uuml;ber einen mathematisch verschlungenen Pfad ableiten. So gesehen ist Impuls ein anderes Wort f&uuml;r Schwung oder Wucht, Drehimpuls beschreibt den Drall und mit W&auml;rme meint man die Entropie.</p>
 
<p>Das dynamische Verhalten eines physikalischen Systems wird durch die Bilanzgleichungen und eine bestimmte Zahl von konstitutiven Gesetzen vollst&auml;ndig beschrieben. <font color=\"#FF0000\">Zugeordneter Energiestrom</font> und <font color=\"#FF0000\">Prozessleistung</font> bilden eine Art zweite Ebene.</p>
 
<p><strong>Fluss und Potenzialgr&ouml;ssen</strong></p>
<table border=\"1\" cellspacing=0 cellpadding=2>
 <tr> 
      <td width=\"150\"><strong>Gebiet</strong></td>
      <td width=\"150\"><strong>Flussgr&ouml;sse</strong></td>
      <td width=\"150\"><strong>Potentialgr&ouml;sse</strong></td>
      <td width=\"150\"><strong>RGB</strong></td>
  </tr>
  <tr> 
      <td>Hydraulik</td>
      <td><b><i>I<sub>V</sub></i></b> in m3/s</td>
      <td><b><i>p</i></b> in Pa</td>
      <td>0/0/255</td>
  </tr>
  <tr> 
      <td>Elektrizit&auml;t</td>
      <td><b><i>I</i></b> in A</td>
      <td><b><i>V</i></b> in V</td>
      <td>0/255/0</td>
  </tr>
  <tr> 
      <td>Thermodynamik</td>
      <td><b><i>I<sub>S</sub></i></b> in W/K</td>
      <td><b><i>T</i></b> in K</td>
      <td>255/0/0</td>
  </tr>
  <tr> 
      <td>Translation</td>
      <td><b><i>F</i></b> in N</td>
      <td><b><i>v</i></b> in m/s</td>
      <td>0/0/0</td>
  </tr>
  <tr> 
      <td>Rotation</td>
      <td><b><i>M</i></b> in Nm</td>
      <td><b><i>w</i></b> in 1/s</td>
      <td>135/135/135</td>
  </tr>
</table>
<p>Das Produkt aus Potentialgr&ouml;sse und Flussgr&ouml;sse (Stromst&auml;rke bez&uuml;glich eines Konnektors) ergibt immer einen zugeordneten Energiestrom (gemessen in Watt).</p>
 
<p>Diese Bibliothek steht f&uuml;r Unterrichtszwecke zur freien Verf&uuml;gung. Jegliche Haftung wird abgelehnt. Benutzer werden gebeten, sich bei untenstehend angegebener Adresse registrieren zu lassen.</p>
<dd><a href=\"http://www.zhwin.ch/~mau\">Werner Maurer</a><br>
    Z&uuml;rcher Hochschule Winterthur<br>
    Institut f&uuml;r Datenanalyse und Prozessdesign<br> 
    Postfach 805<br>
    CH-8401 Winterthur<br>
    Schweiz<br>
    email: <A HREF=\"mailto:mau@zhwin.ch\">Prof. Werner Maurer</A><br></dd>
</html>", revisions="<html>
<p>Version 1 vom 16. M&auml;rz 2006</p>
<p>Version 2 vom 10. Mai 2006</p>
</html>"), uses(Modelica(version="2.2")));
  package Kopplungen 
    "enthaelt Elemente zur Beschreibung von gekoppelten Prozessen" 
    model Erde "Verbindung zur Umwelt" 
      parameter SI.Pressure pamb = 1e5 "Umgebungsdruck";
      parameter SI.Voltage Vamb = 0 "Potential der Umgebung";
      parameter SI.Velocity vamb = 0 "Geschwindigkeit des Bezugssystems";
      parameter SI.AngularVelocity wamb = 0 
        "Winkelgeschwindigkeit des Bezugssystems";
      parameter SI.Temperature Tamb = 273 "Umgebungstemperatur";
      SI.Power IW "Staerke des Energiestromes an die Umwelt";
      SI.Energy Waus(start=0, fixed=true) "Energieaustausch mit der Umwelt";
      annotation (defaultComponentName="Erde", Diagram,
        Icon(
          Ellipse(extent=[-80,80; 80,-80], style(
              color=3,
              rgbcolor={0,0,255},
              fillColor=3,
              rgbfillColor={0,0,255})),
          Polygon(points=[34,74; -4,54; -24,18; -8,18; 4,34; 14,24; 24,24; 34,
                16; 30,40; 52,40; 56,22; 56,18; 74,32; 56,60; 34,74], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=6,
              rgbfillColor={255,255,0},
              fillPattern=1)),
          Polygon(points=[-44,2; 18,8; 66,-8; 62,-42; 18,-80; -2,-80; -12,-40;
                -42,-40; -44,2], style(
              color=0,
              rgbcolor={0,0,0},
              fillColor=6,
              rgbfillColor={255,255,0},
              fillPattern=1))),
        Documentation(info="<html>
Mit der <font color=\"#008800\">HydroErde</font> kann unbeschr&auml;nkt Volumen bei einem Druck von <strong>pamb</strong> = 1e5 Pa ausgetauscht werden. Der an die Umwelt abfliessende, zugeordnete Energiestrom sowie die mit der Umwelt ausgetauschte Energie werden ermittelt. Das Bezugsniveau f&uuml;r diese Energieberechnungen ist Vakuum.
</html>"));
      Konnektoren.Kupplung_neg h_e annotation (extent=[-100,60; -80,80]);
      Konnektoren.Stift_neg e annotation (extent=[-100,-10; -80,10]);
      Konnektoren.Kontakt_neg th_e annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.TFlansch_neg tr_e annotation (extent=[80,40; 100,60]);
      Konnektoren.RFlansch_neg ro_e annotation (extent=[80,-60; 100,-40]);
    equation 
      h_e.p = pamb;
      e.V = Vamb;
      tr_e.v = vamb;
      ro_e.w = wamb;
      th_e.T = Tamb;
      IW = h_e.p*h_e.IV + e.V*e.I + tr_e.v*tr_e.F + ro_e.w*ro_e.M + th_e.T*th_e.IS;
      IW = der(Waus);
    end Erde;
    
    model Transformator_H_H "hydraulischer Transformator" 
        parameter Real Thh=1 "Druckverstaerker";
        SI.Pressure dp1 "Druckdifferenz ueber dem Element";
        SI.Pressure dp2 "Druckdifferenz ueber dem Element";
        SI.VolumeFlowRate IV1 "Volumenstromstaerke durch Element";
        SI.VolumeFlowRate IV2 "Volumenstromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      Konnektoren.Kupplung_pos h_p1 annotation (extent=[-100,60; -80,80]);
      Konnektoren.Kupplung_neg h_n1 annotation (extent=[-100,-80; -80,-60]);
      annotation (defaultComponentName="Tf_HH", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=3, rgbcolor={
                  0,0,255})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=3, rgbcolor={0,0,
                  255})),
            Polygon(points=[60,0; 20,30; 20,10; -60,10; -60,-10; 20,-10; 20,-30; 60,
                0], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255},
              fillPattern=1))));
      Konnektoren.Kupplung_pos h_p2 annotation (extent=[80,60; 100,80]);
      Konnektoren.Kupplung_neg h_n2 annotation (extent=[80,-80; 100,-60]);
    equation 
        dp1 = h_p1.p - h_n1.p;
        0 = h_p1.IV + h_n1.IV;
        IV1 = h_p1.IV;
        dp2 = h_p2.p - h_n2.p;
        0 = h_p2.IV + h_n2.IV;
        IV2 = h_p2.IV;
        dp2 = Thh*dp1;
        IV2 = -IV1/Thh;
        P = dp1*IV1;
    end Transformator_H_H;
    
    model Transformator_H_E "hydroelektrischer Transformator" 
        parameter Real The(
        final unit="V/Pa") = 0.001 "Druck-Spannungs-Wandler";
        SI.Pressure dp "Druckdifferenz ueber dem Element";
        SI.VolumeFlowRate IV "Volumenstromstaerke durch Element";
        SI.Voltage U "Spannung ueber dem Element";
        SI.Current I "elektrische Stromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      Konnektoren.Kupplung_pos h_p  annotation (extent=[-100,60; -80,80]);
      Konnektoren.Kupplung_neg h_n  annotation (extent=[-100,-80; -80,-60]);
      annotation (defaultComponentName="Tf_HE", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=3, rgbcolor={
                  0,0,255})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=2, rgbcolor={0,
                  255,0})),
            Polygon(points=[60,0; 20,30; 20,10; -60,10; -60,-10; 20,-10; 20,-30; 60,
                0], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.Stift_pos p  annotation (extent=[80,60; 100,80]);
      Konnektoren.Stift_neg n  annotation (extent=[80,-80; 100,-60]);
    equation 
        dp = h_p.p - h_n.p;
        0 = h_p.IV + h_n.IV;
        IV = h_p.IV;
        U = p.V - n.V;
        0 = p.I + n.I;
        I = p.I;
        U = The*dp;
        I = -IV/The;
        P = dp*IV;
    end Transformator_H_E;
    
    model Transformator_H_Tr "hydromechanischer Transformator" 
        parameter Real Thtr(
        final unit="m/(s.Pa)") = 0.001 "Druck-Geschwindigkeits-Wandler";
        SI.Pressure dp "Druckdifferenz ueber dem Element";
        SI.VolumeFlowRate IV "Volumenstromstaerke durch Element";
        SI.Velocity dv "Geschwindigkeitsdifferenz ueber dem Element";
        SI.Force F "Impulsstromstaerke (Kraft) durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      Konnektoren.Kupplung_pos h_p  annotation (extent=[-100,60; -80,80]);
      Konnektoren.Kupplung_neg h_n  annotation (extent=[-100,-80; -80,-60]);
      annotation (defaultComponentName="Tf_HTr", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=3, rgbcolor={
                  0,0,255})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=0, rgbcolor={0,0,
                  0})),
            Polygon(points=[60,0; 20,30; 20,10; -60,10; -60,-10; 20,-10; 20,-30; 60,
                0], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255},
              fillPattern=1))));
      Konnektoren.TFlansch_pos tr_p annotation (extent=[80,60; 100,80]);
      Konnektoren.TFlansch_neg tr_n annotation (extent=[80,-80; 100,-60]);
    equation 
        dp = h_p.p - h_n.p;
        0 = h_p.IV + h_n.IV;
        IV = h_p.IV;
        dv = tr_p.v - tr_n.v;
        0 = tr_p.F + tr_n.F;
        F = tr_p.F;
        dv = Thtr*dp;
        F = -IV/Thtr;
        P = dp*IV;
    end Transformator_H_Tr;
    
    model Transformator_H_Ro "hydrorotatorischer Transformator" 
        parameter Real Thro(
        final unit="1/(s.Pa)") = 0.001 "Druck-Winkelgeschwindigkeits-Wandler";
        SI.Pressure dp "Druckdifferenz ueber dem Element";
        SI.VolumeFlowRate IV "Volumenstromstaerke durch Element";
        SI.AngularVelocity dw 
        "Winkelgeschwindigkeitsdifferenz ueber dem Element";
        SI.Torque M "Drehimpulsstromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      Konnektoren.Kupplung_pos h_p  annotation (extent=[-100,60; -80,80]);
      Konnektoren.Kupplung_neg h_n  annotation (extent=[-100,-80; -80,-60]);
      annotation (defaultComponentName="Tf_HRo", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=3, rgbcolor={
                  0,0,255})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=10, rgbcolor={135,
                  135,135})),
            Polygon(points=[60,0; 20,30; 20,10; -60,10; -60,-10; 20,-10; 20,-30; 60,
                0], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255},
              fillPattern=1))));
      Konnektoren.RFlansch_pos ro_p annotation (extent=[80,60; 100,80]);
      Konnektoren.RFlansch_pos ro_n annotation (extent=[80,-80; 100,-60]);
    equation 
        dp = h_p.p - h_n.p;
        0 = h_p.IV + h_n.IV;
        IV = h_p.IV;
        dw = ro_p.w - ro_n.w;
        0 = ro_p.M + ro_n.M;
        M = ro_p.M;
        dw = Thro*dp;
        M = -IV/Thro;
        P = dp*IV;
    end Transformator_H_Ro;
    
    model Transformator_H_Th "hydrothermischer Transformator" 
        parameter Real Thth(
        final unit="K/Pa") = 0.001 "Druck-Temperatur-Wandler";
        SI.Pressure dp "Druckdifferenz ueber dem Element";
        SI.VolumeFlowRate IV "Volumenstromstaerke durch Element";
        SI.Temperature dT "Temperaturdifferenz ueber dem Element";
        SI.ThermalConductance IS "Entropiestromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      Konnektoren.Kupplung_pos h_p  annotation (extent=[-100,60; -80,80]);
      Konnektoren.Kupplung_neg h_n  annotation (extent=[-100,-80; -80,-60]);
      annotation (defaultComponentName="Tf_HTh", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=3, rgbcolor={
                  0,0,255})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=1, rgbcolor={255,
                  0,0})),
            Polygon(points=[60,0; 20,30; 20,10; -60,10; -60,-10; 20,-10; 20,-30; 60,
                0], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255},
              fillPattern=1))));
      Konnektoren.Kontakt_pos th_p annotation (extent=[80,60; 100,80]);
      Konnektoren.Kontakt_neg th_n annotation (extent=[80,-80; 100,-60]);
    equation 
        dp = h_p.p - h_n.p;
        0 = h_p.IV + h_n.IV;
        IV = h_p.IV;
        dT = th_p.T - th_n.T;
        0 = th_p.IS + th_n.IS;
        IS = th_p.IS;
        dT = Thth*dp;
        IS = -IV/Thth;
        P = dp*IV;
    end Transformator_H_Th;
    
    model Transformator_E_E "elektrischer Transformator" 
        parameter Real Tee = 1 "Spannungs-Verstaerker";
        SI.Voltage U1 "Spannung ueber dem Element";
        SI.Current I1 "elektrische Stromstaerke durch Element";
        SI.Voltage U2 "Spannung ueber dem Element";
        SI.Current I2 "elektrische Stromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      annotation (defaultComponentName="Tf_EE", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=2, rgbcolor={
                  0,255,0})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=2, rgbcolor={0,
                  255,0})),
            Polygon(points=[60,0; 20,30; 20,10; -60,10; -60,-10; 20,-10; 20,-30; 60,
                0], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.Stift_pos p1 annotation (extent=[-100,60; -80,80]);
      Konnektoren.Stift_neg n1 annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.Stift_pos p2 annotation (extent=[80,60; 100,80]);
      Konnektoren.Stift_neg n2 annotation (extent=[80,-80; 100,-60]);
    equation 
        U1 = p1.V - n1.V;
        0 = p1.I + n1.I;
        I1 = p1.I;
        U2 = p2.V - n2.V;
        0 = p2.I + n2.I;
        I2 = p2.I;
        U2 = Tee*U1;
        I2 = -I1/Tee;
        P = U1*I1;
    end Transformator_E_E;
    
    model Transformator_E_Tr "elektromechanischer Transformator" 
        parameter Real Tetr(
        final unit="m/(s.V)") = 1 "Spannungs-Geschwindigkeits-Wandler";
        SI.Voltage U "Spannung ueber dem Element";
        SI.Current I "elektrische Stromstaerke durch Element";
        SI.Velocity dv "Geschwindigkeitsdifferenz ueber dem Element";
        SI.Force F "Impulsstromstaerke (Kraft) durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      annotation (defaultComponentName="Tf_ETr", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=2, rgbcolor={
                  0,255,0})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=0, rgbcolor={0,0,
                  0})),
            Polygon(points=[60,0; 20,30; 20,10; -60,10; -60,-10; 20,-10; 20,-30; 60,
                0], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.Stift_pos p  annotation (extent=[-100,60; -80,80]);
      Konnektoren.Stift_neg n  annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.TFlansch_pos tr_p annotation (extent=[80,60; 100,80]);
      Konnektoren.TFlansch_neg tr_n annotation (extent=[80,-80; 100,-60]);
    equation 
        U = p.V - n.V;
        0 = p.I + n.I;
        I = p.I;
        dv = tr_p.v - tr_n.v;
        0 = tr_p.F + tr_n.F;
        F = tr_p.F;
        dv = Tetr*U;
        F = -I/Tetr;
        P = U*I;
    end Transformator_E_Tr;
    
    model Transformator_E_Ro "elektrorotatorischer Transformator" 
        parameter Real Tero(
        final unit="1/(s.V)") = 1 "Spannungs-Winkelgeschwindigkeits-Wandler";
        SI.Voltage U "Spannung ueber dem Element";
        SI.Current I "elektrische Stromstaerke durch Element";
        SI.AngularVelocity dw 
        "Winkelgeschwindigkeitsdifferenz ueber dem Element";
        SI.Torque M "Drehimpulsstromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      annotation (defaultComponentName="Tf_ERo", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=2, rgbcolor={
                  0,255,0})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=10, rgbcolor={135,
                  135,135})),
            Polygon(points=[60,0; 20,30; 20,10; -60,10; -60,-10; 20,-10; 20,-30; 60,
                0], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.Stift_pos p  annotation (extent=[-100,60; -80,80]);
      Konnektoren.Stift_neg n  annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.RFlansch_pos ro_p annotation (extent=[80,60; 100,80]);
      Konnektoren.RFlansch_neg ro_n annotation (extent=[80,-80; 100,-60]);
    equation 
        U = p.V - n.V;
        0 = p.I + n.I;
        I = p.I;
        dw = ro_p.w - ro_n.w;
        0 = ro_p.M + ro_n.M;
        M = ro_p.M;
        dw = Tero*U;
        M = -I/Tero;
        P = U*I;
    end Transformator_E_Ro;
    
    model Transformator_E_Th "elektrothermischer Transformator" 
        parameter Real Teth(
        final unit="K/V") = 1 "Spannungs-Temperatur-Wandler";
        SI.Voltage U "Spannung ueber dem Element";
        SI.Current I "elektrische Stromstaerke durch Element";
        SI.Temperature dT "Temperaturdifferenz ueber dem Element";
        SI.ThermalConductance IS "Entropiestromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      annotation (defaultComponentName="Tf_ETh", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=2, rgbcolor={
                  0,255,0})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=1, rgbcolor={255,
                  0,0})),
            Polygon(points=[60,0; 20,30; 20,10; -60,10; -60,-10; 20,-10; 20,-30; 60,
                0], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.Stift_pos p  annotation (extent=[-100,60; -80,80]);
      Konnektoren.Stift_neg n  annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.Kontakt_pos th_p annotation (extent=[80,60; 100,80]);
      Konnektoren.Kontakt_neg th_n annotation (extent=[80,-80; 100,-60]);
    equation 
        U = p.V - n.V;
        0 = p.I + n.I;
        I = p.I;
        dT = th_p.T - th_n.T;
        0 = th_p.IS + th_n.IS;
        IS = th_p.IS;
        dT = Teth*U;
        IS = -I/Teth;
        P = U*I;
    end Transformator_E_Th;
    
    model Transformator_Tr_Tr "mechanischer Transformator" 
        parameter Real Ttrtr = 1 "Geschwindigkeits-Verstaerker";
        SI.Velocity dv1 "Geschwindigkeitsdifferenz ueber dem Element";
        SI.Force F1 "Impulsstromstaerke (Kraft) durch Element";
        SI.Velocity dv2 "Geschwindigkeitsdifferenz ueber dem Element";
        SI.Force F2 "Impulsstromstaerke (Kraft) durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      annotation (defaultComponentName="Tf_TrTr", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=0, rgbcolor={
                  0,0,0})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=0, rgbcolor={0,0,
                  0})),
            Polygon(points=[60,0; 20,30; 20,10; -60,10; -60,-10; 20,-10; 20,-30; 60,
                0], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.TFlansch_pos tr_p1 
                                    annotation (extent=[-100,60; -80,80]);
      Konnektoren.TFlansch_neg tr_n1 
                                    annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.TFlansch_pos tr_p2 
                                    annotation (extent=[80,60; 100,80]);
      Konnektoren.TFlansch_neg tr_n2 
                                    annotation (extent=[80,-80; 100,-60]);
    equation 
        dv1 = tr_p1.v - tr_n1.v;
        0 = tr_p1.F + tr_n1.F;
        F1 = tr_p1.F;
        dv2 = tr_p2.v - tr_n2.v;
        0 = tr_p2.F + tr_n2.F;
        F2 = tr_p2.F;
        dv2 = Ttrtr*dv1;
        F2 = -F1/Ttrtr;
        P = dv1*F1;
    end Transformator_Tr_Tr;
    
    model Transformator_Tr_Ro "mechanischrotatorischer Transformator" 
        parameter Real Ttrro(
        final unit="1/m") = 1 "Geschwindigkeits-Winkelgeschwindigkeits-Wandler";
        SI.Velocity dv "Geschwindigkeitsdifferenz ueber dem Element";
        SI.Force F "Impulsstromstaerke (Kraft) durch Element";
        SI.AngularVelocity dw 
        "Winkelgeschwindigkeitsdifferenz ueber dem Element";
        SI.Torque M "Drehimpulsstromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      annotation (defaultComponentName="Tf_TrRo", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=0, rgbcolor={
                  0,0,0})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=10, rgbcolor={135,
                  135,135})),
            Polygon(points=[60,0; 20,30; 20,10; -60,10; -60,-10; 20,-10; 20,-30; 60,
                0], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.TFlansch_pos tr_p annotation (extent=[-100,60; -80,80]);
      Konnektoren.TFlansch_neg tr_n annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.RFlansch_pos ro_p annotation (extent=[80,60; 100,80]);
      Konnektoren.RFlansch_neg ro_n annotation (extent=[80,-80; 100,-60]);
    equation 
        dv = tr_p.v - tr_n.v;
        0 = tr_p.F + tr_n.F;
        F = tr_p.F;
        dw = ro_p.w - ro_n.w;
        0 = ro_p.M + ro_n.M;
        M = ro_p.M;
        dw = Ttrro*dv;
        M = -F/Ttrro;
        P = dv*F;
    end Transformator_Tr_Ro;
    
    model Transformator_Tr_Th "mechanischthermischer Transformator" 
        parameter Real Ttrth(
        final unit="K.s/m") = 1 "Geschwindigkeits-Temperatur-Wandler";
        SI.Velocity dv "Geschwindigkeitsdifferenz ueber dem Element";
        SI.Force F "Impulsstromstaerke (Kraft) durch Element";
        SI.Temperature dT "Temperaturdifferenz ueber dem Element";
        SI.ThermalConductance IS "Entropiestromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      annotation (defaultComponentName="Tf_TrTh", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=0, rgbcolor={
                  0,0,0})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=1, rgbcolor={255,
                  0,0})),
            Polygon(points=[60,0; 20,30; 20,10; -60,10; -60,-10; 20,-10; 20,-30; 60,
                0], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.TFlansch_pos tr_p annotation (extent=[-100,60; -80,80]);
      Konnektoren.TFlansch_neg tr_n annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.Kontakt_pos th_p annotation (extent=[80,60; 100,80]);
      Konnektoren.Kontakt_neg th_n annotation (extent=[80,-80; 100,-60]);
    equation 
        dv = tr_p.v - tr_n.v;
        0 = tr_p.F + tr_n.F;
        F = tr_p.F;
        dT = th_p.T - th_n.T;
        0 = th_p.IS + th_n.IS;
        IS = th_p.IS;
        dT = Ttrth*dv;
        IS = -F/Ttrth;
        P = dv*F;
    end Transformator_Tr_Th;
    
    model Transformator_Ro_Ro "rotatorischer Transformator" 
        parameter Real Troro = 1 "Drehzahl-Verstaerker";
        SI.AngularVelocity dw1 
        "Winkelgeschwindigkeitsdifferenz ueber dem Element";
        SI.Torque M1 "Drehimpulsstromstaerke durch Element";
        SI.AngularVelocity dw2 
        "Winkelgeschwindigkeitsdifferenz ueber dem Element";
        SI.Torque M2 "Drehimpulsstromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      annotation (defaultComponentName="Tf_RoRo", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=10, rgbcolor=
                  {135,135,135})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=10, rgbcolor={135,
                  135,135})),
            Polygon(points=[60,0; 20,30; 20,10; -60,10; -60,-10; 20,-10; 20,-30; 60,
                0], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.RFlansch_pos ro_p1 
                                    annotation (extent=[-100,60; -80,80]);
      Konnektoren.RFlansch_neg ro_n1 
                                    annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.RFlansch_pos ro_p2 
                                    annotation (extent=[80,60; 100,80]);
      Konnektoren.RFlansch_neg ro_n2 
                                    annotation (extent=[80,-80; 100,-60]);
    equation 
        dw1 = ro_p1.w - ro_n1.w;
        0 = ro_p1.M + ro_n1.M;
        M1 = ro_p1.M;
        dw2 = ro_p2.w - ro_n2.w;
        0 = ro_p2.M + ro_n2.M;
        M2 = ro_p2.M;
        dw2 = Troro*dw1;
        M2 = -M1/Troro;
        P = dw1*M1;
    end Transformator_Ro_Ro;
    
    model Transformator_Ro_Th "rotatorischthermischer Transformator" 
        parameter Real Troth(
        final unit="K.s") = 1 "Winkelgeschwindigkeits-Temperatur-Wandler";
        SI.AngularVelocity dw 
        "Winkelgeschwindigkeitsdifferenz ueber dem Element";
        SI.Torque M "Drehimpulsstromstaerke durch Element";
        SI.Temperature dT "Temperaturdifferenz ueber dem Element";
        SI.ThermalConductance IS "Entropiestromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      annotation (defaultComponentName="Tf_RoTh", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=10, rgbcolor=
                  {135,135,135})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=1, rgbcolor={255,
                  0,0})),
            Polygon(points=[60,0; 20,30; 20,10; -60,10; -60,-10; 20,-10; 20,-30; 60,
                0], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.RFlansch_pos ro_p annotation (extent=[-100,60; -80,80]);
      Konnektoren.RFlansch_neg ro_n annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.Kontakt_pos th_p annotation (extent=[80,60; 100,80]);
      Konnektoren.Kontakt_neg th_n annotation (extent=[80,-80; 100,-60]);
    equation 
        dw = ro_p.w - ro_n.w;
        0 = ro_p.M + ro_n.M;
        M = ro_p.M;
        dT = th_p.T - th_n.T;
        0 = th_p.IS + th_n.IS;
        IS = th_p.IS;
        dT = Troth*dw;
        IS = -M/Troth;
        P = dw*M;
    end Transformator_Ro_Th;
    
    model Transformator_Th_Th "thermischer Transformator" 
        parameter Real Tthth = 1 "Temperatur-Verstaerker";
        SI.Temperature dT1 "Temperaturdifferenz ueber dem Element";
        SI.ThermalConductance IS1 "Entropiestromstaerke durch Element";
        SI.Temperature dT2 "Temperaturdifferenz ueber dem Element";
        SI.ThermalConductance IS2 "Entropiestromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      annotation (defaultComponentName="Tf_ThTh", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=1, rgbcolor={
                  255,0,0})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=1, rgbcolor={255,
                  0,0})),
            Polygon(points=[60,0; 20,30; 20,10; -60,10; -60,-10; 20,-10; 20,-30; 60,
                0], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.Kontakt_pos th_p1 
                                   annotation (extent=[-100,60; -80,80]);
      Konnektoren.Kontakt_neg th_n1 
                                   annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.Kontakt_pos th_p2 
                                   annotation (extent=[80,60; 100,80]);
      Konnektoren.Kontakt_neg th_n2 
                                   annotation (extent=[80,-80; 100,-60]);
    equation 
        dT1 = th_p1.T - th_n1.T;
        0 = th_p1.IS + th_n1.IS;
        IS1 = th_p1.IS;
        dT2 = th_p2.T - th_n2.T;
        0 = th_p2.IS + th_n2.IS;
        IS2 = th_p2.IS;
        dT2 = Tthth*dT1;
        IS2 = -IS1/Tthth;
        P = dT1*IS1;
    end Transformator_Th_Th;
    
    model Gyrator_H_E "hydroelektrischer Gyrator" 
        parameter Real Ghe(
        final unit="A/Pa") = 0.001 "Druck-Strom-Wandler";
        SI.Pressure dp "Druckdifferenz ueber dem Element";
        SI.VolumeFlowRate IV "Volumenstromstaerke durch Element";
        SI.Voltage U "Spannung ueber dem Element";
        SI.Current I "elektrische Stromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      Konnektoren.Kupplung_pos h_p  annotation (extent=[-100,60; -80,80]);
      Konnektoren.Kupplung_neg h_n  annotation (extent=[-100,-80; -80,-60]);
      annotation (defaultComponentName="Tf_HE", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=3, rgbcolor={
                  0,0,255})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=2, rgbcolor={0,
                  255,0})),
          Polygon(points=[0,-60; 30,-20; 10,-20; 10,60; -10,60; -10,-20; -30,
                -20; 0,-60], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.Stift_pos p  annotation (extent=[80,60; 100,80]);
      Konnektoren.Stift_neg n  annotation (extent=[80,-80; 100,-60]);
    equation 
        dp = h_p.p - h_n.p;
        0 = h_p.IV + h_n.IV;
        IV = h_p.IV;
        U = p.V - n.V;
        0 = p.I + n.I;
        I = p.I;
        I = Ghe*dp;
        U = -IV/Ghe;
        P = dp*IV;
    end Gyrator_H_E;
    
    model Gyrator_H_Tr "hydromechanischer Gyrator" 
        parameter Real Ghtr(
        final unit="N/Pa") = 0.001 "Druck-Kraft-Wandler";
        SI.Pressure dp "Druckdifferenz ueber dem Element";
        SI.VolumeFlowRate IV "Volumenstromstaerke durch Element";
        SI.Velocity dv "Geschwindigkeitsdifferenz ueber dem Element";
        SI.Force F "Impulsstromstaerke (Kraft) durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      Konnektoren.Kupplung_pos h_p  annotation (extent=[-100,60; -80,80]);
      Konnektoren.Kupplung_neg h_n  annotation (extent=[-100,-80; -80,-60]);
      annotation (defaultComponentName="Tf_HTr", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=3, rgbcolor={
                  0,0,255})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=0, rgbcolor={0,0,
                  0})),
          Polygon(points=[0,-60; 30,-20; 10,-20; 10,60; -10,60; -10,-20; -30,
                -20; 0,-60], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.TFlansch_pos tr_p annotation (extent=[80,60; 100,80]);
      Konnektoren.TFlansch_neg tr_n annotation (extent=[80,-80; 100,-60]);
    equation 
        dp = h_p.p - h_n.p;
        0 = h_p.IV + h_n.IV;
        IV = h_p.IV;
        dv = tr_p.v - tr_n.v;
        0 = tr_p.F + tr_n.F;
        F = tr_p.F;
        F = Ghtr*dp;
        dv = -IV/Ghtr;
        P = dp*IV;
    end Gyrator_H_Tr;
    
    model Gyrator_H_Ro "hydrorotatorischer Gyrator" 
        parameter Real Ghro(
        final unit="N.m/Pa") = 0.001 "Druck-Drehmoment-Wandler";
        SI.Pressure dp "Druckdifferenz ueber dem Element";
        SI.VolumeFlowRate IV "Volumenstromstaerke durch Element";
        SI.AngularVelocity dw 
        "Winkelgeschwindigkeitsdifferenz ueber dem Element";
        SI.Torque M "Drehimpulsstromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      Konnektoren.Kupplung_pos h_p  annotation (extent=[-100,60; -80,80]);
      Konnektoren.Kupplung_neg h_n  annotation (extent=[-100,-80; -80,-60]);
      annotation (defaultComponentName="Tf_HRo", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=3, rgbcolor={
                  0,0,255})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=10, rgbcolor={135,
                  135,135})),
          Polygon(points=[0,-60; 30,-20; 10,-20; 10,60; -10,60; -10,-20; -30,
                -20; 0,-60], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.RFlansch_pos ro_p annotation (extent=[80,60; 100,80]);
      Konnektoren.RFlansch_pos ro_n annotation (extent=[80,-80; 100,-60]);
    equation 
        dp = h_p.p - h_n.p;
        0 = h_p.IV + h_n.IV;
        IV = h_p.IV;
        dw = ro_p.w - ro_n.w;
        0 = ro_p.M + ro_n.M;
        M = ro_p.M;
        M = Ghro*dp;
        dw = -IV/Ghro;
        P = dp*IV;
    end Gyrator_H_Ro;
    
    model Gyrator_H_Th "hydrothermischer Gyrator" 
        parameter Real Ghth(
        final unit="W/(K.Pa)") = 0.001 "Druck-Entropiestrom-Wandler";
        SI.Pressure dp "Druckdifferenz ueber dem Element";
        SI.VolumeFlowRate IV "Volumenstromstaerke durch Element";
        SI.Temperature dT "Temperaturdifferenz ueber dem Element";
        SI.ThermalConductance IS "Entropiestromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      Konnektoren.Kupplung_pos h_p  annotation (extent=[-100,60; -80,80]);
      Konnektoren.Kupplung_neg h_n  annotation (extent=[-100,-80; -80,-60]);
      annotation (defaultComponentName="Tf_HTh", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=3, rgbcolor={
                  0,0,255})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=1, rgbcolor={255,
                  0,0})),
          Polygon(points=[0,-60; 30,-20; 10,-20; 10,60; -10,60; -10,-20; -30,
                -20; 0,-60], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.Kontakt_pos th_p annotation (extent=[80,60; 100,80]);
      Konnektoren.Kontakt_neg th_n annotation (extent=[80,-80; 100,-60]);
    equation 
        dp = h_p.p - h_n.p;
        0 = h_p.IV + h_n.IV;
        IV = h_p.IV;
        dT = th_p.T - th_n.T;
        0 = th_p.IS + th_n.IS;
        IS = th_p.IS;
        IS = Ghth*dp;
        dT = -IV/Ghth;
        P = dp*IV;
    end Gyrator_H_Th;
    
    model Gyrator_E_Tr "elektromechanischer Gyrator" 
        parameter Real Getr(
        final unit="N/V") = 1 "Spannungs-Kraft-Wandler";
        SI.Voltage U "Spannung ueber dem Element";
        SI.Current I "elektrische Stromstaerke durch Element";
        SI.Velocity dv "Geschwindigkeitsdifferenz ueber dem Element";
        SI.Force F "Impulsstromstaerke (Kraft) durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      annotation (defaultComponentName="Tf_ETr", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=2, rgbcolor={
                  0,255,0})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=0, rgbcolor={0,0,
                  0})),
          Polygon(points=[0,-60; 30,-20; 10,-20; 10,60; -10,60; -10,-20; -30,
                -20; 0,-60], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.Stift_pos p  annotation (extent=[-100,60; -80,80]);
      Konnektoren.Stift_neg n  annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.TFlansch_pos tr_p annotation (extent=[80,60; 100,80]);
      Konnektoren.TFlansch_neg tr_n annotation (extent=[80,-80; 100,-60]);
    equation 
        U = p.V - n.V;
        0 = p.I + n.I;
        I = p.I;
        dv = tr_p.v - tr_n.v;
        0 = tr_p.F + tr_n.F;
        F = tr_p.F;
        F = Getr*U;
        dv = -I/Getr;
        P = U*I;
    end Gyrator_E_Tr;
    
    model Gyrator_E_Ro "elektrorotatorischer Gyrator" 
        parameter Real Gero(
        final unit="N.m/V") = 1 "Spannungs-Drehmoment-Wandler";
        SI.Voltage U "Spannung ueber dem Element";
        SI.Current I "elektrische Stromstaerke durch Element";
        SI.AngularVelocity dw 
        "Winkelgeschwindigkeitsdifferenz ueber dem Element";
        SI.Torque M "Drehimpulsstromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      annotation (defaultComponentName="Tf_ERo", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=2, rgbcolor={
                  0,255,0})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=10, rgbcolor={135,
                  135,135})),
          Polygon(points=[0,-60; 30,-20; 10,-20; 10,60; -10,60; -10,-20; -30,
                -20; 0,-60], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.Stift_pos p  annotation (extent=[-100,60; -80,80]);
      Konnektoren.Stift_neg n  annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.RFlansch_pos ro_p annotation (extent=[80,60; 100,80]);
      Konnektoren.RFlansch_neg ro_n annotation (extent=[80,-80; 100,-60]);
    equation 
        U = p.V - n.V;
        0 = p.I + n.I;
        I = p.I;
        dw = ro_p.w - ro_n.w;
        0 = ro_p.M + ro_n.M;
        M = ro_p.M;
        M = Gero*U;
        dw = -I/Gero;
        P = U*I;
    end Gyrator_E_Ro;
    
    model Gyrator_E_Th "elektrothermischer Gyrator" 
        parameter Real Geth(
        final unit="W/(K.V)") = 1 "Spannungs-Entropiestrom-Wandler";
        SI.Voltage U "Spannung ueber dem Element";
        SI.Current I "elektrische Stromstaerke durch Element";
        SI.Temperature dT "Temperaturdifferenz ueber dem Element";
        SI.ThermalConductance IS "Entropiestromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      annotation (defaultComponentName="Tf_ETh", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=2, rgbcolor={
                  0,255,0})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=1, rgbcolor={255,
                  0,0})),
          Polygon(points=[0,-60; 30,-20; 10,-20; 10,60; -10,60; -10,-20; -30,
                -20; 0,-60], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.Stift_pos p  annotation (extent=[-100,60; -80,80]);
      Konnektoren.Stift_neg n  annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.Kontakt_pos th_p annotation (extent=[80,60; 100,80]);
      Konnektoren.Kontakt_neg th_n annotation (extent=[80,-80; 100,-60]);
    equation 
        U = p.V - n.V;
        0 = p.I + n.I;
        I = p.I;
        dT = th_p.T - th_n.T;
        0 = th_p.IS + th_n.IS;
        IS = th_p.IS;
        IS = Geth*U;
        dT = -I/Geth;
        P = U*I;
    end Gyrator_E_Th;
    
    model Gyrator_Tr_Ro "mechanischrotatorischer Gyrator" 
        parameter Real Gtrro(
        final unit="N.s") = 1 "Geschwindigkeits-Drehmoment-Wandler";
        SI.Velocity dv "Geschwindigkeitsdifferenz ueber dem Element";
        SI.Force F "Impulsstromstaerke (Kraft) durch Element";
        SI.AngularVelocity dw 
        "Winkelgeschwindigkeitsdifferenz ueber dem Element";
        SI.Torque M "Drehimpulsstromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      annotation (defaultComponentName="Tf_TrRo", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=0, rgbcolor={
                  0,0,0})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=10, rgbcolor={135,
                  135,135})),
          Polygon(points=[0,-60; 30,-20; 10,-20; 10,60; -10,60; -10,-20; -30,
                -20; 0,-60], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.TFlansch_pos tr_p annotation (extent=[-100,60; -80,80]);
      Konnektoren.TFlansch_neg tr_n annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.RFlansch_pos ro_p annotation (extent=[80,60; 100,80]);
      Konnektoren.RFlansch_neg ro_n annotation (extent=[80,-80; 100,-60]);
    equation 
        dv = tr_p.v - tr_n.v;
        0 = tr_p.F + tr_n.F;
        F = tr_p.F;
        dw = ro_p.w - ro_n.w;
        0 = ro_p.M + ro_n.M;
        M = ro_p.M;
        M = Gtrro*dv;
        dw = -F/Gtrro;
        P = dv*F;
    end Gyrator_Tr_Ro;
    
    model Gyrator_Tr_Th "mechanischthermischer Gyrator" 
        parameter Real Gtrth(
        final unit="W.s/(K.m)") = 1 "Geschwindigkeits-Entropiestrom-Wandler";
        SI.Velocity dv "Geschwindigkeitsdifferenz ueber dem Element";
        SI.Force F "Impulsstromstaerke (Kraft) durch Element";
        SI.Temperature dT "Temperaturdifferenz ueber dem Element";
        SI.ThermalConductance IS "Entropiestromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      annotation (defaultComponentName="Tf_TrTh", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=0, rgbcolor={
                  0,0,0})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=1, rgbcolor={255,
                  0,0})),
          Polygon(points=[0,-60; 30,-20; 10,-20; 10,60; -10,60; -10,-20; -30,
                -20; 0,-60], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.TFlansch_pos tr_p annotation (extent=[-100,60; -80,80]);
      Konnektoren.TFlansch_neg tr_n annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.Kontakt_pos th_p annotation (extent=[80,60; 100,80]);
      Konnektoren.Kontakt_neg th_n annotation (extent=[80,-80; 100,-60]);
    equation 
        dv = tr_p.v - tr_n.v;
        0 = tr_p.F + tr_n.F;
        F = tr_p.F;
        dT = th_p.T - th_n.T;
        0 = th_p.IS + th_n.IS;
        IS = th_p.IS;
        IS = Gtrth*dv;
        dT = -F/Gtrth;
        P = dv*F;
    end Gyrator_Tr_Th;
    
    model Gyrator_Ro_Th "rotatorischthermischer Gyrator" 
        parameter Real Groth(
        final unit="W.s/K") = 1 "Winkelgeschwindigkeits-Entropiestrom-Wandler";
        SI.AngularVelocity dw 
        "Winkelgeschwindigkeitsdifferenz ueber dem Element";
        SI.Torque M "Drehimpulsstromstaerke durch Element";
        SI.Temperature dT "Temperaturdifferenz ueber dem Element";
        SI.ThermalConductance IS "Entropiestromstaerke durch Element";
        SI.Power P "Prozessleistung ueber dem Element";
      annotation (defaultComponentName="Tf_RoTh", Diagram,
        Icon(
          Line(points=[-80,70; -60,70; -60,-70; -80,-70], style(color=10, rgbcolor=
                  {135,135,135})),
          Line(points=[80,70; 60,70; 60,-70; 80,-70], style(color=1, rgbcolor={255,
                  0,0})),
          Polygon(points=[0,-60; 30,-20; 10,-20; 10,60; -10,60; -10,-20; -30,
                -20; 0,-60], style(
              color=5,
              rgbcolor={255,0,255},
              fillColor=5,
              rgbfillColor={255,0,255}))));
      Konnektoren.RFlansch_pos ro_p annotation (extent=[-100,60; -80,80]);
      Konnektoren.RFlansch_neg ro_n annotation (extent=[-100,-80; -80,-60]);
      Konnektoren.Kontakt_pos th_p annotation (extent=[80,60; 100,80]);
      Konnektoren.Kontakt_neg th_n annotation (extent=[80,-80; 100,-60]);
    equation 
        dw = ro_p.w - ro_n.w;
        0 = ro_p.M + ro_n.M;
        M = ro_p.M;
        dT = th_p.T - th_n.T;
        0 = th_p.IS + th_n.IS;
        IS = th_p.IS;
        IS = Groth*dw;
        dT = -M/Groth;
        P = dw*M;
    end Gyrator_Ro_Th;
    annotation (Documentation(info="<html>
<p>Dieser Ordner enth&auml;lt alle denkbaren <font color=\"#FF0000\">Prozesskopplungen</font>. Bei einer Prozesskopplung fliesst ein Strom &uuml;ber eine Potentialdifferenz hinunter und setzt dabei Energie frei. Diese Energie wird in einem zweiten Prozess gebraucht, um einen Strom &uuml;ber eine Potentialdifferenz hinauf zu pumpen.</p>
<p> Bei einem <font color=\"#FF0000\">Transformator</font> treibt ein Prim&auml;rstrom einen sekund&auml;ren Strom an. Da alle Transformatoren in beide Richtungen betrieben werden k&ouml;nnen, ergeben f&uuml;nf Gebiete f&uuml;nfzehn verschiedene Transformatoren.</p>
<p> Bei einem <font color=\"#FF0000\">Gyrator</font> treibt eine Potenzialdifferenz einen sekund&auml;ren Strom an. Da alle Gyratoren in beide Richtungen betrieben werden k&ouml;nnen, ergeben f&uuml;nf Gebiete zehn verschiedene Gyratoren (artreine Gyratoren sind nicht definiert worden).</p>
<p> Alle Gyratoren und Transformatoren sind als reversible Systeme modelliert. Dissipation kann durch Widerst&auml;nde oder D&auml;mpfer erzeugt werden, mit denen der Sekund&auml;rkreis kurzgeschlossen wird. Durch Serie- und Parallelschaltung von Prozesskoplungen lassen sich sehr viele reale Systeme nachbilden.</p>
</html>"));
  end Kopplungen;
  
  package Systeme "enthaelt Systeme aus Elementen von verschiedenen Bereichen" 
    package Leitungen 
      model Waermeleitung "Waermeleitung in einem Stab" 
        parameter Real N=9 "Anzahl Elemente";
        parameter SI.Length l = 1 "Laenge";
        parameter SI.Length b = 0.1 "Breite";
        parameter SI.Length h = 0.1 "Hoehe";
        parameter SI.Density Rho = 8900 "Dichte";
        parameter SI.CoefficientOfHeatTransfer alpha =  1 
          "Uebergangskoeffizient";
        parameter SI.ThermalConductivity lambda = 384 "Waermeleitfaehigkeit";
        parameter SI.SpecificHeatCapacity c = 4186 
          "spezifische Enthalpiekapazitaet";
        parameter SI.Temperature Ta = 293 "Anfangstemperatur";
        parameter SI.Temperature Tamb = 273 "Bezugstemperatur";
      protected 
        parameter SI.Area Aq = b*h "Querschnitt";
        parameter SI.Area Ah = 2*(b+h)*l/N "Huellflaeche pro Element";
        parameter SI.Mass m = Rho*Aq*l/N "Masse eines Elementes";
        parameter SI.ThermalConductance GW=lambda*Aq/(N*l) 
          "Energieleitwert eines Elementes";
      protected 
        Konnektoren.Kontakt_pos th_p annotation (extent=[-100,-10; -80,10]);
        Konnektoren.Kontakt_neg th_n annotation (extent=[80,-10; 100,10]);
        Konnektoren.Kontakt_neg th_s annotation (extent=[-10,-100; 10,-80]);
        Thermodynamik.Waermeleitung GWp(GW=2*GW) 
          annotation (extent=[-60,-10; -40,10]);
        Thermodynamik.Waermeleitung GWn(GW=2*GW) 
          annotation (extent=[40,-10; 60,10]);
        Thermodynamik.Waermeleitung GWm[N - 1](GW=GW) 
          annotation (extent=[-10,-10; 10,10]);
        Thermodynamik.Waermespeicher C[N](
          m=m,
          c=c,
          Ta=Ta,
          Tamb=Tamb) annotation (extent=[10,-40; 30,-20]);
        Thermodynamik.Uebergang GWUe[N](A=Ah, alpha=alpha) 
          annotation (extent=[-30,-40; -10,-20], rotation=-90);
        annotation (Diagram);
      equation 
        connect(th_p, GWp.th_p) annotation (points=[-90,0; -59,0], style(color=
                1, rgbcolor={255,0,0}));
        connect(GWn.th_n, th_n) 
          annotation (points=[59,0; 90,0], style(color=1, rgbcolor={255,0,0}));
        connect(GWp.th_n, GWm[1].th_p);
        for i in 1:N-1 loop
          connect(GWUe[i].th_p, GWm[i].th_p);
          connect(C[i].th_p, GWm[i].th_p);
        end for;
        for i in 1:N-2 loop
          connect(GWm[i].th_n, GWm[i+1].th_p);
        end for;
        for i in 1:N loop
          connect(GWUe[i].th_n, th_s);
        end for;
        connect(GWm[N-1].th_n, GWn.th_p);
        connect(GWUe[N].th_p, GWn.th_p);
        connect(C[N].th_p, GWn.th_p);
      end Waermeleitung;
      annotation (Documentation(info="<html>
Die in PhyDynSys hinterlegten Modelle sind r&auml;umlich konzentriert. R&auml;umlich verteilte Systeme lassen sich durch Serie- und Parallelschaltungen von einzelnen Elementen nachbilden. <font color=\"#008800\">Leitungen </font> sind linienfl&uuml;chtige Systeme, die nur in eine Dimension eine zu modellierende Ausdehnung zeigen. 
</html>"));
    end Leitungen;
    
    package MechSysteme 
      model Traegheit "Klotz mit Faden haengt an Faden" 
        
        Translation.TransErde Erde annotation (extent=[-80,0; -60,20]);
        Translation.Faden Fadoben annotation (extent=[-60,40; -40,60]);
        annotation (
          Diagram,
          Documentation(info="<html>
<p>Der Begriff der <font color=\"#FF0000\">Tr&auml;gheitskraft</font> ist das wohl verbreitetste Fehlkonzept der Physik im deutschen Sprachraum. Um diesen unn&ouml;tigen und oft falsch interpretierten Begriff einzuf&uuml;hren, wird ein Klotz an einem Faden aufgeh&auml;ngt. Zieht man nun langsam an einem zweiten Faden, der an der Unterseite des Klotzes befestigt ist, reisst der obere Faden. Zieht man schnell, reisst der untere. Dies wird dann oft als ein Beweis fr die Existenz der Tr&auml;gheitskraft angesehen.</p>

<p>Der Klotz wirkt kapazitiv (tr&auml;ge Masse) und bildet gleichzeitig eine Impulsquelle (schwere Masse). Fliesst nun vom unteren Faden her ein starker Impulsstrom zu, vereinigt sich dieser mit der Quelle und bildet einen durch den oberen Faden wegfliessenden, st&auml;rkeren Impulsstrom. Weil im station&auml;ren Fall der obere Strom immer st&auml;rker ist als der untere, reisst der obere Faden. Zieht man sehr schnell am unteren Faden, machen sich die kapazitive Wirkung des Klotzes bemerkbar. Das Ph&auml;nomen ist aber ohne Faden nicht modellierbar. Die Kapazit&auml;t des Klotzes und die Induktivit&auml;t der beiden Faden bestimmen die Dynamik.<p>

<p>Wird der Geschwindigkeitssprung nach zwei Sekunden auf 2 m/s eingestellt, reisst der untere Faden, bei 0.5 m/s reisst der obere. Man beachte den Einschwingvorgang in den ersten zwei Sekunden. Die Simulationszeit kann auf vier Sekunden eingestellt werden.</p>
</html>"),Icon(
            Rectangle(extent=[-100,100; 100,60], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=7)),
            Line(points=[0,60; 0,20], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=7)),
            Rectangle(extent=[-40,30; 40,-50], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0})),
            Ellipse(extent=[-10,-80; 10,-100], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Line(points=[0,-50; 0,-80], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1))));
        Translation.Faden Fadunten annotation (extent=[0,40; 22,60]);
        Translation.Pumpe_dv Hand annotation (extent=[0,-20; -20,0]);
        Translation.Masse Klotz(m=5, Beta=-90) 
          annotation (extent=[-30,20; -10,40]);
        Modelica.Blocks.Sources.Step Geschw(height=-2, startTime=2) 
          annotation (extent=[-60,-60; -40,-40]);
      equation 
        connect(Erde.tr_e, Fadoben.tr_p) annotation (points=[-70,19; -70,50;
              -59,50], style(color=0, rgbcolor={0,0,0}));
        connect(Fadoben.tr_n, Fadunten.tr_p) annotation (points=[-41,50; 1.1,50],
            style(color=0, rgbcolor={0,0,0}));
        connect(Fadunten.tr_n, Hand.tr_p) annotation (points=[20.9,50; 48,50;
              48,-10; -1,-10], style(color=0, rgbcolor={0,0,0}));
        connect(Hand.tr_n, Erde.tr_e) annotation (points=[-19,-10; -46,-10; -46,
              20; -70,20; -70,19], style(color=0, rgbcolor={0,0,0}));
        connect(Klotz.tr_p, Fadunten.tr_p) annotation (points=[-20.1,39; -20.1,
              50; 1.1,50], style(color=0, rgbcolor={0,0,0}));
        connect(Geschw.y, Hand.dv_in) annotation (points=[-39,-50; -10,-50; -10,
              -19], style(color=74, rgbcolor={0,0,127}));
      end Traegheit;
      
      model Pendel "physisches Pendel mit Reibung" 
        Rotation.Unwucht Pendel(
          m=2,
          J0=0.2,
          r0=0.5) annotation (extent=[-20,0; 0,20]);
        Translation.TransErde Achse annotation (extent=[-82,18; -62,40]);
        annotation (Diagram, Icon(
            Ellipse(extent=[40,-40; 80,-80], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0})),
            Line(points=[-10,100; 60,-60], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Line(points=[-20,100; -20,-92; -20,-94], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Polygon(points=[-20,-92; -28,-60; -12,-60; -20,-92], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Text(
              extent=[-40,60; 60,-40],
              style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1),
              string="Phi")));
        Rotation.Drehreibung RReib(
          M_Coul=0.2,
          M_Stri=0.04,
          k_Visk=0.001) annotation (extent=[-40,-10; -60,10]);
        Rotation.RotErde Lager annotation (extent=[-90,-20; -70,0]);
      equation 
        connect(Pendel.tr_p, Achse.tr_e) annotation (points=[-10,19; -10,38.9;
              -72,38.9], style(
            color=0,
            rgbcolor={0,0,0},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(Pendel.ro_p, RReib.ro_p) annotation (points=[-19,10; -34,10;
              -34,-0.2; -41,-0.2], style(
            color=10,
            rgbcolor={135,135,135},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(RReib.ro_n, Lager.ro_e) annotation (points=[-59,0; -69.5,0;
              -69.5,-1; -80,-1], style(
            color=10,
            rgbcolor={136,136,136},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
      end Pendel;
      
      model SchiefeEbene "Walze auf schiefer Ebene" 
        parameter SI.Mass m = 5 "schwere und traege Masse";
        parameter Real Beta(
           final unit="deg") = -10 
          "Winkel zwischen Horizontalen und gewaehlter Bewegungsrichtung in Grad";
        parameter SI.Length R = 0.2 "Walzenradius";
        parameter Real mueG = 0.4 "Gleitreibungszahl";
        parameter Real mueR = 0.1 "Rollreibungszahl";
        parameter SI.Acceleration g = 9.81 "Gravitationsfeldstaerke";
        SI.Length s "Ort der Walzenachse";
      protected 
        parameter SI.MomentOfInertia J = 0.5*m*R^2 "Massentraegheitsmoment";
        parameter SI.Force FN = m*g*cos(Modelica.Constants.pi*Beta/360) 
          "Normalkraft";
        parameter SI.Force F_Coul = mueG*FN "Coulombkraft";
        parameter SI.Force F_Stri = 0.1*F_Coul 
          "Stribeckkraft, Kraftzunahme kurz vor Stillstand";
        parameter SI.Torque M_Coul = 0.5*R*mueR*FN "Coulombmoment";
        parameter SI.Torque M_Stri = 0.1*M_Coul 
          "Stribeckmoment, zunahme des Drehmomentes kurz vor Stillstand";
      public 
        Rotation.Rolle Walze(
          Beta=Beta,
          m=m,
          J=J,
          r_n=R,
          g=g,
          wa=15) 
               annotation (extent=[0,20; 20,40]);
        Rotation.RotErde EbeneRot 
                                annotation (extent=[-60,-20; -40,0]);
        Rotation.Drehreibung ReibRot(
          dphia=0,
          k_Visk=0.001,
          M_Coul=M_Coul,
          M_Stri=M_Stri) 
                        annotation (extent=[-30,20; -50,40]);
        annotation (Diagram, DymolaStoredErrors,
          Documentation(info="<html>
<p>Eine Walze (Masse <strong>m</strong>, Radius <strong>R</strong>) wird auf eine schiefe Ebene abgesetzt. Die Walze kann zu Beginn rotieren, eine Translation ausfhren oder still stehen. Auf der Berhrlinie (momentane Drehachse) wirkt eine Haft-Gleitreibungskraft und ein Haft-Gleitreibungsdrehmoment. Wenn die Ebene gegen rechts gekippt wird (Beta kleiner Null) nimmt die Geschwindigkeit der Walze zu und die Winkelgeschwindigkeit ab (vergl. <font color=\"#FF0000\">Vorzeichenregel</font> bei <font color=\"#008800\">Rotation.Rolle</font>).</p>
</html>"),Icon(
            Line(points=[100,0; -100,-100], style(color=0, rgbcolor={0,0,0})),
            Ellipse(extent=[-44,8; 16,-52], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0})),
            Line(points=[84,52; 6,16], style(color=0, rgbcolor={0,0,0})),
            Polygon(points=[64,52; 84,52; 72,38; 64,52], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Ellipse(extent=[-28,58; 52,-22], style(color=0, rgbcolor={0,0,0})),
            Polygon(points=[-34,20; -26,6; -22,20; -34,20], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Text(
              extent=[-40,-60; 40,-100],
              style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1),
              string="Beta")));
        
        Translation.TransErde EbeneTrans 
                                     annotation (extent=[40,-20; 60,0]);
        Translation.Reibung ReibTrans(
          L=0,
          k_Visk=0.001,
          F_Coul=F_Coul,
          F_Stri=F_Stri)                            annotation (extent=[40,10; 60,30]);
      equation 
        connect(ReibRot.ro_p, Walze.ro_p) 
                                        annotation (points=[-31,29.8; -14,29.8;
              -14,46; 24,46; 24,30; 10,30],
                               style(
            color=10,
            rgbcolor={135,135,135},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(ReibRot.ro_n, EbeneRot.ro_e) 
                                         annotation (points=[-49,30; -56,30; -56,-1;
              -50,-1], style(
            color=10,
            rgbcolor={136,136,136},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(ReibTrans.tr_n, EbeneTrans.tr_e) 
                                        annotation (points=[59,20; 68,20; 68,-1; 50,
              -1], style(
            color=0,
            rgbcolor={0,0,0},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        Walze.v = der(s);
        connect(Walze.tr_p, ReibTrans.tr_p) annotation (points=[10,21; 10,12;
              32,12; 32,20; 41,20], style(color=0, rgbcolor={0,0,0}));
      end SchiefeEbene;
      
      model Atwood "Atwoodsche Fallmaschine" 
        SI.Length h_links(start=1, fixed=true) "Fadenlaenge links";
        SI.Length h_rechts(start=1, fixed=true) "Fadenlaenge rechts";
        Rotation.Rolle Rolle(
          m=0.5,
          J=0.00065,
          r_p=0.05,
          r_n=0.05,
          Beta=-90) annotation (extent=[-20,60; -40,40], rotation=90);
        annotation (Diagram, Icon(
            Ellipse(extent=[-40,100; 20,40], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1)),
            Ellipse(extent=[-20,80; 0,60], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Line(points=[-40,72; -40,-20], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Line(points=[20,72; 20,-20], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Rectangle(extent=[-60,-20; -20,-60], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Rectangle(extent=[0,-20; 40,-80], style(
                color=0,
                rgbcolor={0,0,0},
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Ellipse(extent=[-30,90; 10,50], style(color=0, rgbcolor={0,0,0})),
            Rectangle(extent=[-28,60; 8,48], style(
                pattern=0,
                fillColor=7,
                rgbfillColor={255,255,255},
                fillPattern=1)),
            Polygon(points=[6,70; 4,56; 14,64; 14,64; 6,70], style(
                pattern=0,
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1))),
          Documentation(info="<html>
Mit der <font color=\"#008800\">Atwoodschen Fallmaschine </font> hat man fr&uuml;her eine verlangsamte Fallbewegung ausgemessen. Mit grossem technischen Aufwand sind strende Einflsse wie die Trgheit der Rolle oder die Lagerreibung klein gehalten worden.
</html>"));
        Rotation.RotErde ErdeRot annotation (extent=[22,38; 42,58]);
        Rotation.Drehreibung ReibRot(
          dphia=0,
          M_Coul=0.01,
          M_Stri=0.003,
          k_Visk=0.0001) annotation (extent=[-10,58; 10,78]);
        Translation.TransErde Erde annotation (extent=[-82,56; -62,76]);
        Translation.Masse m_links(Beta=-90) 
          annotation (extent=[-56,-42; -36,-22]);
        Translation.Masse m_rechts(Beta=-90, m=1.1) 
          annotation (extent=[-22,-42; -2,-22]);
        Translation.Faden Fad_links(Epsilon=0.005) 
          annotation (extent=[-56,0; -36,20], rotation=-90);
        Translation.Faden Fad_rechts(Epsilon=0.005) 
          annotation (extent=[-22,0; -2,20], rotation=-90);
      equation 
        connect(Rolle.ro_p, ReibRot.ro_p) annotation (points=[-30,50; -26,50;
              -26,74; -9,74; -9,67.8],  style(
            color=10,
            rgbcolor={135,135,135},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(ReibRot.ro_n, ErdeRot.ro_e) annotation (points=[9,68; 32,68; 32,
              57], style(
            color=10,
            rgbcolor={136,136,136},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(Erde.tr_e, Rolle.tr_m) annotation (points=[-72,75; -54,75; -54,
              80; -30,80; -30,59], style(
            color=0,
            rgbcolor={0,0,0},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        m_links.v = der(h_links);
        m_rechts.v = der(h_rechts);
        connect(Rolle.tr_p, Fad_links.tr_p) annotation (points=[-39,50; -46,50;
              -46,19], style(
            color=0,
            rgbcolor={0,0,0},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(Fad_links.tr_n, m_links.tr_p) annotation (points=[-46,1; -46,
              -23; -46.1,-23], style(
            color=0,
            rgbcolor={0,0,0},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(Rolle.tr_n, Fad_rechts.tr_p) annotation (points=[-21,50; -12,50;
              -12,19], style(
            color=0,
            rgbcolor={0,0,0},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(Fad_rechts.tr_n, m_rechts.tr_p) annotation (points=[-12,1; -12,
              -11; -12,-23; -12.1,-23], style(
            color=0,
            rgbcolor={0,0,0},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
      end Atwood;
      
      model Radfahrer "Radfahrer im Wind" 
        
        Translation.TransErde Erde annotation (extent=[-100,-22; -80,-2]);
        annotation (Diagram, Icon(
            Ellipse(extent=[-80,-20; -20,-80], style(
                color=0,
                rgbcolor={0,0,0},
                thickness=4,
                fillColor=7,
                rgbfillColor={255,255,255})),
            Ellipse(extent=[-56,-44; -42,-58], style(
                color=0,
                rgbcolor={0,0,0},
                thickness=4,
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Ellipse(extent=[20,-20; 80,-80], style(
                color=0,
                rgbcolor={0,0,0},
                thickness=4,
                fillColor=7,
                rgbfillColor={255,255,255})),
            Ellipse(extent=[44,-44; 58,-58], style(
                color=0,
                rgbcolor={0,0,0},
                thickness=4,
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Line(points=[-44,-50; 4,-50; 36,-10; -18,-10; -52,-50], style(
                color=0,
                rgbcolor={0,0,0},
                thickness=4,
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Line(points=[50,-50; 30,14], style(
                color=0,
                rgbcolor={0,0,0},
                thickness=4,
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Ellipse(extent=[0,46; -30,-26], style(
                color=0,
                rgbcolor={0,0,0},
                thickness=4,
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Line(points=[-14,-20; 10,-30; 0,-48; 12,-52], style(
                color=0,
                rgbcolor={0,0,0},
                thickness=4,
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Line(points=[-12,34; 10,12; 36,12], style(
                color=0,
                rgbcolor={0,0,0},
                thickness=4,
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Ellipse(extent=[-28,70; -4,46], style(
                color=0,
                rgbcolor={0,0,0},
                thickness=4,
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Polygon(points=[-40,70; 6,70; -16,78; -40,70], style(
                color=0,
                rgbcolor={0,0,0},
                thickness=4,
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1))),
          Documentation(info="<html>
Der <font color=\"#008800\">Radfahrer</font> f&auml;hrt im ersten Zeitabschnitt gegen und im zweiten mit dem Wind. Weil der antreibende Impulsstrom, dessen St&auml;rke zwischen Strasse und Rad auch Haftreibungskraft heisst, konstant gehalten wird, leistet der Radfahrer bei Rckenwind mehr als bei Gegenwind. Ein brauchbareres Modell wrde im unteren Geschwindigkeitsbereich den Impulsstrom und im oberen die Pumpleistung konstant lassen. Die Simulationszeit sollte auf etwa 200 Sekunden eingestellt werden.
</html>"));
        Translation.Masse Fahrer(m=80, Beta=0) annotation (extent=[-20,-2; 0,18]);
        Translation.Luftwiderstand Luftwiderstand(L=0) 
                                             annotation (extent=[20,18; 40,38]);
        Modelica.Blocks.Sources.Constant cWA(k=0.25) 
          annotation (extent=[80,40; 60,60]);
        Modelica.Blocks.Sources.Constant Rho(k=1.22) 
          annotation (extent=[-10,40; 10,60]);
        Translation.Reibung RollReib(
          L=0,
          F_Coul=5,
          F_Stri=1,
          k_Visk=0.001) annotation (extent=[-40,-60; -60,-40]);
        Translation.Pumpe_Ip Antrieb(L=0) annotation (extent=[-60,22; -40,42]);
        Modelica.Blocks.Sources.Constant Kraft(k=50) 
          annotation (extent=[-64,-24; -44,-4]);
        Translation.Pumpe_dv Wind 
          annotation (extent=[54,10; 34,-10], rotation=-90);
        Modelica.Blocks.Sources.Step v_Wind(
          height=4,
          offset=-2,
          startTime=100) annotation (extent=[86,-10; 66,10]);
      equation 
        connect(Fahrer.tr_p, Luftwiderstand.tr_p) 
                                        annotation (points=[-10.1,17; -10.1,28; 21,28],
            style(color=0, rgbcolor={0,0,0}));
        connect(cWA.y, Luftwiderstand.cWA_in) 
                                    annotation (points=[59,50; 36,50; 36,37], style(
              color=74, rgbcolor={0,0,127}));
        connect(Rho.y, Luftwiderstand.Rho_in) 
                                    annotation (points=[11,50; 24,50; 24,37], style(
              color=74, rgbcolor={0,0,127}));
        connect(RollReib.tr_n, Erde.tr_e) annotation (points=[-59,-50; -76,-50; -76,
              10; -90,10; -90,-3], style(color=0, rgbcolor={0,0,0}));
        connect(Fahrer.tr_p, RollReib.tr_p) annotation (points=[-10.1,17; 20,17; 20,
              -50; -41,-50], style(color=0, rgbcolor={0,0,0}));
        connect(Erde.tr_e, Antrieb.tr_p) annotation (points=[-90,-3; -90,32;
              -59,32], style(color=0, rgbcolor={0,0,0}));
        connect(Antrieb.tr_n, Fahrer.tr_p) annotation (points=[-41,32; -10,32;
              -10,18; -10.1,17],
            style(color=0, rgbcolor={0,0,0}));
        connect(Kraft.y, Antrieb.F_in) annotation (points=[-43,-14; -34,-14;
              -34,6; -50,6; -50,23], style(color=74, rgbcolor={0,0,127}));
        connect(v_Wind.y, Wind.dv_in) annotation (points=[65,0; 59,0; 59,
              5.51073e-016; 53,5.51073e-016], style(color=74, rgbcolor={0,0,127}));
        connect(Luftwiderstand.tr_n, Wind.tr_n) annotation (points=[39,28; 44,
              28; 44,9], style(color=0, rgbcolor={0,0,0}));
        connect(Wind.tr_p, Erde.tr_e) annotation (points=[44,-9; 44,-64; -80,
              -64; -80,4; -90,4; -90,-3], style(color=0, rgbcolor={0,0,0}));
      end Radfahrer;
      
      model A4 "Senkrechter Start einer A4-Rakete" 
        Translation.Rakete A4_V2(
          m0=3825,
          mB=8610,
          Im0=138,
          c=2100) annotation (extent=[-40,18; -20,38]);
        Translation.Atmosphaere Atm annotation (extent=[18,20; 38,40]);
        Translation.TransErde Erde annotation (extent=[-10,-88; 10,-68]);
        annotation (
          Diagram,
          Icon(
            Rectangle(extent=[-20,40; 20,-60], style(
                pattern=0,
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Polygon(points=[-20,40; 0,100; 20,40; -20,40], style(
                pattern=0,
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Polygon(points=[-20,-20; -40,-40; -40,-100; -20,-60; -20,-20],
                style(
                pattern=0,
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1)),
            Polygon(points=[40,-40; 20,-20; 20,-60; 40,-100; 40,-40], style(
                pattern=0,
                fillColor=0,
                rgbfillColor={0,0,0},
                fillPattern=1))),
          Documentation(info="<html>
<p>Nach Jahren der Entwicklung gelang am 03. Oktober 1942 der erste erfolgreiche Start einer A4 vom Prfstand VII in Peenemnde. In 296 Sekunden flog das Gert 190 km weit in die Danziger Bucht. 
Die Gipfelhhe betrug 84.5 km, die Geschwindigkeit 1.340 m/sec. Im Gegensatz zu damals wird hier ein senkrechter Flug simuliert. Solche Flge htten den 2. Weltkrieg schneller beendet.</p>
</html>"));
        Translation.Strecke M_s 
          annotation (extent=[-60,14; -40,-6], rotation=90);
        Translation.Luftwiderstand Wid 
          annotation (extent=[52,34; 72,14], rotation=90);
        Modelica.Blocks.Sources.Constant cW_A(k=2.1) 
          annotation (extent=[0,-30; 20,-10]);
      equation 
        connect(M_s.tr_p, A4_V2.tr_p) annotation (points=[-50,13; -50,44; -30,
              44; -30,37], style(
            color=0,
            rgbcolor={0,0,0},
            pattern=0,
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(M_s.tr_n, Erde.tr_e) annotation (points=[-50,-5; -50,-69; 0,-69],
            style(
            color=0,
            rgbcolor={0,0,0},
            pattern=0,
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(M_s.s_aus, Atm.h_in) annotation (points=[-41,4.1; 10,4.1; 10,30;
              19,30], style(
            color=74,
            rgbcolor={0,0,127},
            pattern=0,
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(Atm.Rho_aus, Wid.Rho_in) annotation (points=[37,30; 53,30],
            style(
            color=74,
            rgbcolor={0,0,127},
            pattern=0,
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(A4_V2.tr_p, Wid.tr_p) annotation (points=[-30,37; -30,44; 62,44;
              62,33], style(
            color=0,
            rgbcolor={0,0,0},
            pattern=0,
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(Wid.tr_n, Erde.tr_e) annotation (points=[62,15; 62,-69; 0,-69],
            style(
            color=0,
            rgbcolor={0,0,0},
            pattern=0,
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(cW_A.y, Wid.cWA_in) annotation (points=[21,-20; 46,-20; 46,18;
              53,18], style(
            color=74,
            rgbcolor={0,0,127},
            pattern=0,
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
      end A4;
      
      model Katze "Katze faellt immer auf die Fuesse" 
        SI.Angle phi_h "Drehwinkel hinten";
        SI.Angle phi_v "Drehwinkel vorn";
        Rotation.VarTraegheit J_hinten(J=0.01) 
          annotation (extent=[-60,-20; -40,0]);
        Rotation.VarTraegheit J_vorn(J=0.01) annotation (extent=[20,-20; 40,0]);
        Rotation.Pumpe_IL P_IL annotation (extent=[-20,20; 0,0]);
        annotation (Diagram, Documentation(info="<html>
Eine Katze kann dank ihrer Beweglichkeit Drehimpuls zwischen Vorder- und Hinterteil austauschen und gleichzeitig das Massentr&auml;gheitsmoment dieser beiden K&ouml;rperh&auml;lften ver&auml;ndern. Mit einer doppelten Piroutte gelingt ihr im freien Fall eine halbe Drehung. Die Katze ist so eingestellt, dass sie f&uuml;r die halbe Drehung eine Sekunde ben&ouml;tigt.
</html>"));
        Modelica.Blocks.Sources.Sine dJ_hinten(
          amplitude=0.007,
          freqHz=0.5,
          phase=1.570796) annotation (extent=[-100,-60; -80,-40]);
        Modelica.Blocks.Sources.Sine dJ_vorn(
          amplitude=0.007,
          freqHz=0.5,
          phase=-1.570796) annotation (extent=[-12,-60; 8,-40]);
        Modelica.Blocks.Sources.Sine M(
          amplitude=0.007,
          freqHz=1,
          phase=1.570796) annotation (extent=[-44,28; -24,48]);
      equation 
        connect(J_hinten.ro_p, P_IL.ro_p) annotation (points=[-50,-1; -50,10.2;
              -19,10.2], style(
            color=10,
            rgbcolor={135,135,135},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(P_IL.ro_n, J_vorn.ro_p) annotation (points=[-1,10; 30,10; 30,-1],
            style(
            color=10,
            rgbcolor={136,136,136},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(dJ_hinten.y, J_hinten.J_ex) annotation (points=[-79,-50; -68,
              -50; -68,-10; -59,-10], style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(dJ_vorn.y, J_vorn.J_ex) annotation (points=[9,-50; 16,-50; 16,
              -10; 21,-10], style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(M.y, P_IL.M_in) annotation (points=[-23,38; -10,38; -10,19],
            style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        J_hinten.w = der(phi_h);
        J_vorn.w = der(phi_v);
      end Katze;
    end MechSysteme;
    
    package ElektroSysteme     
    end ElektroSysteme;
    
    package ThermoSysteme 
      model Gasprozesse "vier Grundprozesse mit dem idealem Gas" 
        Kopplungen.Erde Umgebung 
                             annotation (extent=[-10,-80; 10,-60], rotation=-90);
        Thermodynamik.IdealesGas Gas_isobar annotation (extent=[-60,60; -40,80]);
        Thermodynamik.Pumpe_IS WP_p 
          annotation (extent=[-98,40; -78,60], rotation=90);
        Thermodynamik.IdealesGas Gas_isochor 
          annotation (extent=[-60,20; -40,40]);
        Thermodynamik.Pumpe_IS WP_V 
          annotation (extent=[-84,0; -64,20], rotation=90);
        annotation (Diagram, Documentation(info="<html>
<p>Die vier grundlegenden Prozesse mit dem idealen Gas werden parallel gerechnet. Bei den beiden Heizprozessen wird je ein konstanter Entropiestrom zugef&uuml;hrt, bei den beiden Kompressionsprozessen fliesst je ein konstanter Volumenstrom zu. Beim isobaren Heizen verbindet ein Kurzschluss die Hydraulikseite mit der Umgebung, beim isochoren Heizen ist der Hydraulikanschluss unterbrochen. Beim isothermen Pressen verbindet ein Kurzschluss die thermische Seite mit der Umgebung, beim isentropen Pressen ist der thermische Anschluss unterbrochen.</p>
</html>"));
        Modelica.Blocks.Sources.Constant IS(k=5) 
          annotation (extent=[-22,-20; -42,0]);
        Thermodynamik.IdealesGas Gas_isotherm annotation (extent=[40,60; 60,80]);
        Thermodynamik.IdealesGas Gas_isentrop annotation (extent=[40,20; 60,40]);
        Modelica.Blocks.Sources.Constant IV(k=0.005) 
          annotation (extent=[20,-20; 40,0]);
        Hydrodynamik.Pumpe_IV HP_T 
          annotation (extent=[80,0; 60,20], rotation=90);
        Hydrodynamik.Pumpe_IV HP_S 
          annotation (extent=[100,40; 80,60], rotation=90);
        Hydrodynamik.LaminarerWiderstand RV(RV=1000) 
          annotation (extent=[-20,6; 0,26], rotation=-90);
        Thermodynamik.Waermeleitung GW(GW=1e4) 
          annotation (extent=[-2,30; 18,50], rotation=-90);
      equation 
        connect(WP_p.th_n, Gas_isobar.th_p) annotation (points=[-88,59; -88,70;
              -59,70], style(
            color=1,
            rgbcolor={255,0,0},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(WP_V.th_n, Gas_isochor.th_p) annotation (points=[-74,19; -74,30;
              -59,30], style(
            color=1,
            rgbcolor={255,0,0},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(WP_V.th_p, Umgebung.th_e) 
                                      annotation (points=[-74,1; -74,-42; -7,
              -42; -7,-61], style(
            color=1,
            rgbcolor={255,0,0},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(WP_p.th_p, Umgebung.th_e) 
                                      annotation (points=[-88,41; -88,-52; -7,
              -52; -7,-61], style(
            color=1,
            rgbcolor={255,0,0},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(WP_V.IS_in, IS.y) annotation (points=[-65,10; -60,10; -60,-10;
              -43,-10], style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(IS.y, WP_p.IS_in) annotation (points=[-43,-10; -54,-10; -54,6;
              -34,6; -34,50; -79,50], style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(Umgebung.h_e, HP_T.h_p) 
                                    annotation (points=[7,-61; 7,-40; 70,-40; 
              70,1], style(
            color=3,
            rgbcolor={0,0,255},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(HP_T.h_n, Gas_isentrop.h_p) annotation (points=[70,19; 70,30;
              59,30], style(
            color=3,
            rgbcolor={0,0,255},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(Umgebung.h_e, HP_S.h_p) 
                                    annotation (points=[7,-61; 7,-52; 90,-52; 
              90,41], style(
            color=3,
            rgbcolor={0,0,255},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(HP_S.h_n,Gas_isotherm. h_p) annotation (points=[90,59; 90,70;
              59,70], style(
            color=3,
            rgbcolor={0,0,255},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(IV.y, HP_S.IV_in) annotation (points=[41,-10; 48,-10; 48,10; 24,
              10; 24,50; 81,50], style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(IV.y, HP_T.IV_in) annotation (points=[41,-10; 56,-10; 56,10; 61,
              10], style(
            color=74,
            rgbcolor={0,0,127},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(Gas_isobar.h_p, RV.h_p) annotation (points=[-41,70; -10,70; -10,
              25], style(
            color=3,
            rgbcolor={0,0,255},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(RV.h_n, Umgebung.h_e) 
                                  annotation (points=[-10,7; -10,-34; 7,-34; 7,
              -61], style(
            color=3,
            rgbcolor={0,0,255},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(GW.th_p,Gas_isotherm. th_p) annotation (points=[8,49; 8,70; 41,
              70], style(
            color=1,
            rgbcolor={255,0,0},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
        connect(GW.th_n, Umgebung.th_e) 
                                    annotation (points=[8,31; 8,-28; -7,-28; -7,
              -61], style(
            color=1,
            rgbcolor={255,0,0},
            fillColor=0,
            rgbfillColor={0,0,0},
            fillPattern=1));
      end Gasprozesse;
    end ThermoSysteme;
  end Systeme;
end PhyDynSys2;
